// Copyright 2019, VIXL authors
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//   * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//   * Neither the name of ARM Limited nor the names of its contributors may be
//     used to endorse or promote products derived from this software without
//     specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

namespace vixl {
namespace aarch64 {

// Recursively construct a uint32_t encoded bit pattern from a string literal.
// The string characters are mapped as two-bit symbols '0'=>0, '1'=>1, 'x'=>2.
// The remaining symbol, 3, is used to mark the end of the pattern, allowing
// its length to be found. For example, the pattern "1x01"_b is encoded in a
// uint32_t as 0b11_01_00_01. The maximum pattern string length is 15
// characters, encoded as 3 in the most significant bits, followed by 15 2-bit
// symbols.
constexpr uint32_t str_to_two_bit_pattern(const char* x, size_t s, uint32_t a) {
  if (s == 0) return a;
  uint32_t r = (x[0] == 'x') ? 2 : (x[0] - '0');
  return str_to_two_bit_pattern(x + 1, s - 1, (a << 2) | r);
}

constexpr uint32_t operator"" _b(const char* x, size_t s) {
  return str_to_two_bit_pattern(x, s, DecodeNode::kEndOfPattern);
}

// This decode table is derived from the AArch64 ISA XML specification,
// available from https://developer.arm.com/products/architecture/a-profile/

// clang-format off
static const DecodeMapping kDecodeMapping[] = {
  { "_gggyqx",
    {23, 22, 20, 19, 18, 17, 16},
    { {"0111001"_b, "fcvtnu_asimdmiscfp16_r"},
      {"0x00001"_b, "fcvtnu_asimdmisc_r"},
      {"1111001"_b, "fcvtpu_asimdmiscfp16_r"},
      {"1x00001"_b, "fcvtpu_asimdmisc_r"},
      {"xx10000"_b, "umaxv_asimdall_only"},
      {"xx10001"_b, "uminv_asimdall_only"},
    },
  },

  { "_ggvztl",
    {30},
    { {"0"_b, "bl_only_branch_imm"},
      {"1"_b, "_qpzynz"},
    },
  },

  { "_ghmzhr",
    {20, 19, 18, 17, 16, 13, 12},
    { {"0000000"_b, "rbit_32_dp_1src"},
      {"0000001"_b, "clz_32_dp_1src"},
    },
  },

  { "_ghnljt",
    {23, 22, 20, 19, 18, 17, 16},
    { {"0000000"_b, "fcvtns_64s_float2int"},
      {"0000001"_b, "fcvtnu_64s_float2int"},
      {"0000010"_b, "scvtf_s64_float2int"},
      {"0000011"_b, "ucvtf_s64_float2int"},
      {"0000100"_b, "fcvtas_64s_float2int"},
      {"0000101"_b, "fcvtau_64s_float2int"},
      {"0001000"_b, "fcvtps_64s_float2int"},
      {"0001001"_b, "fcvtpu_64s_float2int"},
      {"0010000"_b, "fcvtms_64s_float2int"},
      {"0010001"_b, "fcvtmu_64s_float2int"},
      {"0011000"_b, "fcvtzs_64s_float2int"},
      {"0011001"_b, "fcvtzu_64s_float2int"},
      {"0100000"_b, "fcvtns_64d_float2int"},
      {"0100001"_b, "fcvtnu_64d_float2int"},
      {"0100010"_b, "scvtf_d64_float2int"},
      {"0100011"_b, "ucvtf_d64_float2int"},
      {"0100100"_b, "fcvtas_64d_float2int"},
      {"0100101"_b, "fcvtau_64d_float2int"},
      {"0100110"_b, "fmov_64d_float2int"},
      {"0100111"_b, "fmov_d64_float2int"},
      {"0101000"_b, "fcvtps_64d_float2int"},
      {"0101001"_b, "fcvtpu_64d_float2int"},
      {"0110000"_b, "fcvtms_64d_float2int"},
      {"0110001"_b, "fcvtmu_64d_float2int"},
      {"0111000"_b, "fcvtzs_64d_float2int"},
      {"0111001"_b, "fcvtzu_64d_float2int"},
      {"1001110"_b, "fmov_64vx_float2int"},
      {"1001111"_b, "fmov_v64i_float2int"},
      {"1100000"_b, "fcvtns_64h_float2int"},
      {"1100001"_b, "fcvtnu_64h_float2int"},
      {"1100010"_b, "scvtf_h64_float2int"},
      {"1100011"_b, "ucvtf_h64_float2int"},
      {"1100100"_b, "fcvtas_64h_float2int"},
      {"1100101"_b, "fcvtau_64h_float2int"},
      {"1100110"_b, "fmov_64h_float2int"},
      {"1100111"_b, "fmov_h64_float2int"},
      {"1101000"_b, "fcvtps_64h_float2int"},
      {"1101001"_b, "fcvtpu_64h_float2int"},
      {"1110000"_b, "fcvtms_64h_float2int"},
      {"1110001"_b, "fcvtmu_64h_float2int"},
      {"1111000"_b, "fcvtzs_64h_float2int"},
      {"1111001"_b, "fcvtzu_64h_float2int"},
    },
  },

  { "_gjprmg",
    {11},
    { {"0"_b, "_llpsqq"},
    },
  },

  { "_gjsnly",
    {16, 13, 12},
    { {"000"_b, "rev16_64_dp_1src"},
      {"001"_b, "cls_64_dp_1src"},
      {"100"_b, "pacib_64p_dp_1src"},
      {"101"_b, "autib_64p_dp_1src"},
      {"110"_b, "_ksvxxm"},
      {"111"_b, "_xsgxyy"},
    },
  },

  { "_gjylrt",
    {20, 19, 18, 17, 16},
    { {"00000"_b, "fcvtns_32h_float2int"},
      {"00001"_b, "fcvtnu_32h_float2int"},
      {"00010"_b, "scvtf_h32_float2int"},
      {"00011"_b, "ucvtf_h32_float2int"},
      {"00100"_b, "fcvtas_32h_float2int"},
      {"00101"_b, "fcvtau_32h_float2int"},
      {"00110"_b, "fmov_32h_float2int"},
      {"00111"_b, "fmov_h32_float2int"},
      {"01000"_b, "fcvtps_32h_float2int"},
      {"01001"_b, "fcvtpu_32h_float2int"},
      {"10000"_b, "fcvtms_32h_float2int"},
      {"10001"_b, "fcvtmu_32h_float2int"},
      {"11000"_b, "fcvtzs_32h_float2int"},
      {"11001"_b, "fcvtzu_32h_float2int"},
    },
  },

  { "_gkhhjm",
    {30, 23, 22},
    { {"000"_b, "sbfm_32m_bitfield"},
      {"100"_b, "ubfm_32m_bitfield"},
    },
  },

  { "_gkkpjz",
    {23, 22, 20, 19, 18, 17, 16},
    { {"0111001"_b, "fcvtmu_asisdmiscfp16_r"},
      {"0x00001"_b, "fcvtmu_asisdmisc_r"},
      {"1111001"_b, "fcvtzu_asisdmiscfp16_r"},
      {"1x00001"_b, "fcvtzu_asisdmisc_r"},
      {"xx00000"_b, "neg_asisdmisc_r"},
    },
  },

  { "_gkpvxz",
    {10},
    { {"0"_b, "blraa_64p_branch_reg"},
      {"1"_b, "blrab_64p_branch_reg"},
    },
  },

  { "_gkpzhr",
    {30, 23, 22, 13, 12, 11, 10},
    { {"000xxxx"_b, "fnmsub_s_floatdp3"},
      {"001xxxx"_b, "fnmsub_d_floatdp3"},
      {"011xxxx"_b, "fnmsub_h_floatdp3"},
      {"10001x0"_b, "fmul_asisdelem_rh_h"},
      {"10x0101"_b, "sqshrn_asisdshf_n"},
      {"10x0111"_b, "sqrshrn_asisdshf_n"},
      {"11x01x0"_b, "fmul_asisdelem_r_sd"},
      {"1xx11x0"_b, "sqdmull_asisdelem_l"},
    },
  },

  { "_gkxgsn",
    {30, 23, 22, 11, 10},
    { {"00000"_b, "stlur_32_ldapstl_unscaled"},
      {"00100"_b, "ldapur_32_ldapstl_unscaled"},
      {"01000"_b, "ldapursw_64_ldapstl_unscaled"},
      {"10000"_b, "stlur_64_ldapstl_unscaled"},
      {"10100"_b, "ldapur_64_ldapstl_unscaled"},
    },
  },

  { "_glgrjy",
    {23, 22, 20, 19, 18, 17, 16},
    { {"0000000"_b, "not_asimdmisc_r"},
      {"0100000"_b, "rbit_asimdmisc_r"},
    },
  },

  { "_glhxyj",
    {17},
    { {"0"_b, "ld3_asisdlsop_bx3_r3b"},
      {"1"_b, "ld3_asisdlsop_b3_i3b"},
    },
  },

  { "_glkzlv",
    {20, 19, 18, 17, 16},
    { {"00000"_b, "rev16_asimdmisc_r"},
    },
  },

  { "_gmjhll",
    {17},
    { {"0"_b, "st1_asisdlsep_r4_r4"},
      {"1"_b, "st1_asisdlsep_i4_i4"},
    },
  },

  { "_gmrxlp",
    {30},
    { {"0"_b, "orr_32_log_shift"},
      {"1"_b, "ands_32_log_shift"},
    },
  },

  { "_gmrxqq",
    {30, 23, 22},
    { {"000"_b, "stp_q_ldstpair_off"},
      {"001"_b, "ldp_q_ldstpair_off"},
      {"010"_b, "stp_q_ldstpair_pre"},
      {"011"_b, "ldp_q_ldstpair_pre"},
    },
  },

  { "_gmsgqz",
    {30, 23, 22},
    { {"100"_b, "eor3_vvv16_crypto4"},
      {"101"_b, "sm3ss1_vvv4_crypto4"},
      {"110"_b, "xar_vvv2_crypto3_imm6"},
    },
  },

  { "_gmvjgn",
    {23},
    { {"0"_b, "fmax_asimdsame_only"},
      {"1"_b, "fmin_asimdsame_only"},
    },
  },

  { "_gmvrxn",
    {18, 17, 12},
    { {"000"_b, "st4_asisdlso_d4_4d"},
    },
  },

  { "_gmvtss",
    {30},
    { {"0"_b, "ldr_q_loadlit"},
    },
  },

  { "_gngjxr",
    {20, 19, 18, 17, 16},
    { {"00000"_b, "cadd_z_zz"},
      {"00001"_b, "sqcadd_z_zz"},
    },
  },

  { "_gnqhsl",
    {23, 22, 20, 19, 18, 17, 16},
    { {"0010000"_b, "punpklo_p_p"},
      {"0010001"_b, "punpkhi_p_p"},
      {"xx0xxxx"_b, "zip1_p_pp"},
      {"xx10100"_b, "rev_p_p"},
    },
  },

  { "_gnqjhz",
    {20, 19, 18, 17, 16, 13, 12},
    { {"0000000"_b, "rev16_32_dp_1src"},
      {"0000001"_b, "cls_32_dp_1src"},
    },
  },

  { "_gntpyh",
    {23, 13, 12, 11, 10},
    { {"00010"_b, "_gqspys"},
      {"00110"_b, "_ymgrgx"},
      {"01001"_b, "fcmge_asisdsame_only"},
      {"01011"_b, "facge_asisdsame_only"},
      {"01110"_b, "_kjyphv"},
      {"10010"_b, "_myjqrl"},
      {"10101"_b, "fabd_asisdsame_only"},
      {"10110"_b, "_vlsmsn"},
      {"11001"_b, "fcmgt_asisdsame_only"},
      {"11011"_b, "facgt_asisdsame_only"},
      {"11110"_b, "_pxtsvn"},
    },
  },

  { "_gnxgxs",
    {30, 18},
    { {"00"_b, "_krlpjl"},
    },
  },

  { "_gnytkh",
    {1, 0},
    { {"11"_b, "braaz_64_branch_reg"},
    },
  },

  { "_gpxltv",
    {23, 18, 17, 16},
    { {"0000"_b, "uqxtnt_z_zz"},
    },
  },

  { "_gqspys",
    {22, 20, 19, 18, 17, 16},
    { {"111001"_b, "fcvtau_asisdmiscfp16_r"},
      {"x00001"_b, "fcvtau_asisdmisc_r"},
      {"x10000"_b, "fmaxnmp_asisdpair_only_sd"},
    },
  },

  { "_gqykqv",
    {23, 22, 12},
    { {"000"_b, "_rjmyyl"},
      {"001"_b, "_zqltpy"},
      {"010"_b, "_hstvrp"},
      {"011"_b, "_yhqyzj"},
      {"110"_b, "_mxtskk"},
      {"111"_b, "_qmjqhq"},
    },
  },

  { "_grqnlm",
    {30, 23, 22, 13, 12, 11, 10},
    { {"000xxxx"_b, "fnmadd_s_floatdp3"},
      {"001xxxx"_b, "fnmadd_d_floatdp3"},
      {"011xxxx"_b, "fnmadd_h_floatdp3"},
      {"10001x0"_b, "fmla_asisdelem_rh_h"},
      {"10x0001"_b, "sshr_asisdshf_r"},
      {"10x0101"_b, "ssra_asisdshf_r"},
      {"10x1001"_b, "srshr_asisdshf_r"},
      {"10x1101"_b, "srsra_asisdshf_r"},
      {"11x01x0"_b, "fmla_asisdelem_r_sd"},
      {"1xx11x0"_b, "sqdmlal_asisdelem_l"},
    },
  },

  { "_grrjlh",
    {30},
    { {"1"_b, "_jlqxvj"},
    },
  },

  { "_grxzzg",
    {23, 22},
    { {"00"_b, "tbx_asimdtbl_l2_2"},
    },
  },

  { "_gsgzpg",
    {17},
    { {"0"_b, "ld2_asisdlso_h2_2h"},
    },
  },

  { "_gshrzq",
    {22, 20, 11},
    { {"010"_b, "decb_r_rs"},
      {"110"_b, "dech_r_rs"},
    },
  },

  { "_gskkxk",
    {17},
    { {"0"_b, "st1_asisdlso_h1_1h"},
    },
  },

  { "_gsttpm",
    {12},
    { {"0"_b, "ld3_asisdlsop_dx3_r3d"},
    },
  },

  { "_gszlvl",
    {30},
    { {"0"_b, "_tvsszp"},
      {"1"_b, "_njtngm"},
    },
  },

  { "_gszxkp",
    {13, 12},
    { {"11"_b, "cmgt_asisdsame_only"},
    },
  },

  { "_gtjskz",
    {30, 23, 22, 13, 12, 11, 10},
    { {"1011011"_b, "bfmmla_asimdsame2_e"},
      {"x011111"_b, "bfdot_asimdsame2_d"},
      {"x111111"_b, "bfmlal_asimdsame2_f"},
      {"xxx0xx1"_b, "fcmla_asimdsame2_c"},
      {"xxx1x01"_b, "fcadd_asimdsame2_c"},
    },
  },

  { "_gttglx",
    {17},
    { {"0"_b, "st4_asisdlso_h4_4h"},
    },
  },

  { "_gtvhmp",
    {30, 13},
    { {"00"_b, "_rjyrnt"},
      {"01"_b, "_mzhsrq"},
      {"10"_b, "_xtzlzy"},
      {"11"_b, "_kqxhzx"},
    },
  },

  { "_gtxpgx",
    {30, 23, 13, 4},
    { {"0000"_b, "prfw_i_p_bz_s_x32_scaled"},
      {"0010"_b, "prfd_i_p_bz_s_x32_scaled"},
      {"010x"_b, "ld1h_z_p_bz_s_x32_scaled"},
      {"011x"_b, "ldff1h_z_p_bz_s_x32_scaled"},
      {"1000"_b, "prfw_i_p_bz_d_x32_scaled"},
      {"1010"_b, "prfd_i_p_bz_d_x32_scaled"},
      {"110x"_b, "ld1h_z_p_bz_d_x32_scaled"},
      {"111x"_b, "ldff1h_z_p_bz_d_x32_scaled"},
    },
  },

  { "_gvjgyp",
    {23, 22, 13, 12, 11, 10},
    { {"0001x0"_b, "fmls_asimdelem_rh_h"},
      {"0x0101"_b, "shl_asimdshf_r"},
      {"0x1101"_b, "sqshl_asimdshf_r"},
      {"1000x0"_b, "fmlsl_asimdelem_lh"},
      {"1x01x0"_b, "fmls_asimdelem_r_sd"},
      {"xx10x0"_b, "smlsl_asimdelem_l"},
      {"xx11x0"_b, "sqdmlsl_asimdelem_l"},
    },
  },

  { "_gvstrp",
    {17},
    { {"0"_b, "ld2_asisdlsop_bx2_r2b"},
      {"1"_b, "ld2_asisdlsop_b2_i2b"},
    },
  },

  { "_gvykrp",
    {30, 23, 22, 13, 12, 11, 10},
    { {"10001x0"_b, "fmulx_asisdelem_rh_h"},
      {"10x0001"_b, "sqshrun_asisdshf_n"},
      {"10x0011"_b, "sqrshrun_asisdshf_n"},
      {"10x0101"_b, "uqshrn_asisdshf_n"},
      {"10x0111"_b, "uqrshrn_asisdshf_n"},
      {"11x01x0"_b, "fmulx_asisdelem_r_sd"},
    },
  },

  { "_gxlvsg",
    {13},
    { {"0"_b, "_vpxvjs"},
      {"1"_b, "_lpslrz"},
    },
  },

  { "_gxmnkl",
    {23, 22},
    { {"10"_b, "cdot_z_zzzi_s"},
      {"11"_b, "cdot_z_zzzi_d"},
    },
  },

  { "_gxnlxg",
    {20, 19, 18, 17, 16},
    { {"00001"_b, "uqxtn_asisdmisc_n"},
    },
  },

  { "_gxslgq",
    {23, 22, 20, 19, 17, 16},
    { {"000010"_b, "scvtf_s32_float2fix"},
      {"000011"_b, "ucvtf_s32_float2fix"},
      {"001100"_b, "fcvtzs_32s_float2fix"},
      {"001101"_b, "fcvtzu_32s_float2fix"},
      {"010010"_b, "scvtf_d32_float2fix"},
      {"010011"_b, "ucvtf_d32_float2fix"},
      {"011100"_b, "fcvtzs_32d_float2fix"},
      {"011101"_b, "fcvtzu_32d_float2fix"},
      {"110010"_b, "scvtf_h32_float2fix"},
      {"110011"_b, "ucvtf_h32_float2fix"},
      {"111100"_b, "fcvtzs_32h_float2fix"},
      {"111101"_b, "fcvtzu_32h_float2fix"},
    },
  },

  { "_gygnsz",
    {17},
    { {"0"_b, "ld2_asisdlsop_hx2_r2h"},
      {"1"_b, "ld2_asisdlsop_h2_i2h"},
    },
  },

  { "_gymljg",
    {23},
    { {"0"_b, "fmulx_asimdsame_only"},
    },
  },

  { "_gyrjrm",
    {20, 19, 18, 17, 16},
    { {"00000"_b, "cpy_z_p_v"},
      {"00001"_b, "compact_z_p_z"},
      {"00010"_b, "lasta_v_p_z"},
      {"00011"_b, "lastb_v_p_z"},
      {"00100"_b, "revb_z_z"},
      {"00101"_b, "revh_z_z"},
      {"00110"_b, "revw_z_z"},
      {"00111"_b, "rbit_z_p_z"},
      {"01000"_b, "clasta_z_p_zz"},
      {"01001"_b, "clastb_z_p_zz"},
      {"01010"_b, "clasta_v_p_z"},
      {"01011"_b, "clastb_v_p_z"},
      {"01100"_b, "splice_z_p_zz_des"},
      {"01101"_b, "splice_z_p_zz_con"},
    },
  },

  { "_gznnvh",
    {23, 22, 20, 19, 18, 17, 16},
    { {"0111001"_b, "frinta_asimdmiscfp16_r"},
      {"0x00001"_b, "frinta_asimdmisc_r"},
      {"xx00000"_b, "cmge_asimdmisc_z"},
    },
  },

  { "_gzqvnk",
    {23, 12, 4, 3, 2, 1, 0},
    { {"1000000"_b, "ctermeq_rr"},
      {"1010000"_b, "ctermne_rr"},
      {"x10xxxx"_b, "whilewr_p_rr"},
      {"x11xxxx"_b, "whilerw_p_rr"},
    },
  },

  { "_gzvgmh",
    {18, 17, 12},
    { {"0x0"_b, "ld4_asisdlsop_dx4_r4d"},
      {"100"_b, "ld4_asisdlsop_dx4_r4d"},
      {"110"_b, "ld4_asisdlsop_d4_i4d"},
    },
  },

  { "_gzylzp",
    {17},
    { {"0"_b, "st3_asisdlsop_hx3_r3h"},
      {"1"_b, "st3_asisdlsop_h3_i3h"},
    },
  },

  { "_hggmnk",
    {13, 12},
    { {"10"_b, "lslv_32_dp_2src"},
    },
  },

  { "_hgxqpp",
    {18, 17},
    { {"00"_b, "st3_asisdlso_s3_3s"},
    },
  },

  { "_hgxtqy",
    {30, 23, 22, 13},
    { {"0001"_b, "ldnt1w_z_p_ar_s_x32_unscaled"},
      {"0010"_b, "ld1rsh_z_p_bi_s64"},
      {"0011"_b, "ld1rsh_z_p_bi_s32"},
      {"0110"_b, "ld1rsb_z_p_bi_s64"},
      {"0111"_b, "ld1rsb_z_p_bi_s32"},
      {"1000"_b, "ldnt1sw_z_p_ar_d_64_unscaled"},
      {"1010"_b, "ld1sw_z_p_bz_d_64_unscaled"},
      {"1011"_b, "ldff1sw_z_p_bz_d_64_unscaled"},
    },
  },

  { "_hhhqjk",
    {4, 3, 2, 1, 0},
    { {"11111"_b, "_pqpzkt"},
    },
  },

  { "_hhkhkk",
    {30, 23, 11, 10},
    { {"1001"_b, "_lkvynm"},
    },
  },

  { "_hhkqtn",
    {20, 19, 18, 17, 16},
    { {"00000"_b, "lasta_r_p_z"},
      {"00001"_b, "lastb_r_p_z"},
      {"01000"_b, "cpy_z_p_r"},
      {"10000"_b, "clasta_r_p_z"},
      {"10001"_b, "clastb_r_p_z"},
    },
  },

  { "_hhnjjk",
    {9, 8, 7, 6, 5},
    { {"11111"_b, "pacdzb_64z_dp_1src"},
    },
  },

  { "_hhymvj",
    {20, 19, 18, 17, 16, 13, 12},
    { {"0000011"_b, "sqabs_asisdmisc_r"},
      {"0000100"_b, "sqxtn_asisdmisc_n"},
    },
  },

  { "_hjgylh",
    {30, 23, 22},
    { {"000"_b, "str_s_ldst_pos"},
      {"001"_b, "ldr_s_ldst_pos"},
      {"100"_b, "str_d_ldst_pos"},
      {"101"_b, "ldr_d_ldst_pos"},
    },
  },

  { "_hjqtrt",
    {12},
    { {"0"_b, "st1_asisdlsop_dx1_r1d"},
    },
  },

  { "_hjtvvm",
    {13, 12},
    { {"00"_b, "sdiv_64_dp_2src"},
      {"10"_b, "rorv_64_dp_2src"},
    },
  },

  { "_hljrqn",
    {22},
    { {"0"_b, "str_32_ldst_regoff"},
      {"1"_b, "ldr_32_ldst_regoff"},
    },
  },

  { "_hlshjk",
    {23, 22},
    { {"00"_b, "fmlal_asimdsame_f"},
      {"10"_b, "fmlsl_asimdsame_f"},
    },
  },

  { "_hmsgpj",
    {13, 12, 10},
    { {"000"_b, "_hthxvr"},
      {"100"_b, "ptrue_p_s"},
      {"101"_b, "_kkvrzq"},
      {"110"_b, "_xxjrsy"},
    },
  },

  { "_hmtmlq",
    {4},
    { {"0"_b, "nor_p_p_pp_z"},
      {"1"_b, "nand_p_p_pp_z"},
    },
  },

  { "_hmtxlh",
    {9, 8, 7, 6, 5, 1, 0},
    { {"1111111"_b, "retaa_64e_branch_reg"},
    },
  },

  { "_hmxlny",
    {13, 12, 11, 10},
    { {"0000"_b, "addhn_asimddiff_n"},
      {"0001"_b, "sshl_asimdsame_only"},
      {"0010"_b, "_lyghyg"},
      {"0011"_b, "sqshl_asimdsame_only"},
      {"0100"_b, "sabal_asimddiff_l"},
      {"0101"_b, "srshl_asimdsame_only"},
      {"0110"_b, "_htgzzx"},
      {"0111"_b, "sqrshl_asimdsame_only"},
      {"1000"_b, "subhn_asimddiff_n"},
      {"1001"_b, "smax_asimdsame_only"},
      {"1010"_b, "_sqpjtr"},
      {"1011"_b, "smin_asimdsame_only"},
      {"1100"_b, "sabdl_asimddiff_l"},
      {"1101"_b, "sabd_asimdsame_only"},
      {"1110"_b, "_rnrzsj"},
      {"1111"_b, "saba_asimdsame_only"},
    },
  },

  { "_hngpgx",
    {23, 10, 4},
    { {"000"_b, "_vxsjgg"},
    },
  },

  { "_hngpxg",
    {1, 0},
    { {"00"_b, "br_64_branch_reg"},
    },
  },

  { "_hnjrmp",
    {4},
    { {"0"_b, "cmplo_p_p_zi"},
      {"1"_b, "cmpls_p_p_zi"},
    },
  },

  { "_hnzzkj",
    {30, 18},
    { {"00"_b, "_gxslgq"},
    },
  },

  { "_hpgqlp",
    {9, 8, 7, 6, 5},
    { {"00000"_b, "fmov_s_floatimm"},
    },
  },

  { "_hqhzgj",
    {17},
    { {"0"_b, "ld2_asisdlso_b2_2b"},
    },
  },

  { "_hqlskj",
    {18, 17},
    { {"00"_b, "ld1_asisdlse_r1_1v"},
    },
  },

  { "_hqnxvt",
    {13, 12, 11, 10},
    { {"0000"_b, "saddl_asimddiff_l"},
      {"0001"_b, "shadd_asimdsame_only"},
      {"0010"_b, "_rykykh"},
      {"0011"_b, "sqadd_asimdsame_only"},
      {"0100"_b, "saddw_asimddiff_w"},
      {"0101"_b, "srhadd_asimdsame_only"},
      {"0110"_b, "_glkzlv"},
      {"0111"_b, "_rnktts"},
      {"1000"_b, "ssubl_asimddiff_l"},
      {"1001"_b, "shsub_asimdsame_only"},
      {"1010"_b, "_rgztzl"},
      {"1011"_b, "sqsub_asimdsame_only"},
      {"1100"_b, "ssubw_asimddiff_w"},
      {"1101"_b, "cmgt_asimdsame_only"},
      {"1110"_b, "_nyxxks"},
      {"1111"_b, "cmge_asimdsame_only"},
    },
  },

  { "_hqsvmh",
    {18, 17},
    { {"00"_b, "st4_asisdlso_s4_4s"},
    },
  },

  { "_hrhzqy",
    {17},
    { {"0"_b, "ld4_asisdlse_r4"},
    },
  },

  { "_hrktgs",
    {12},
    { {"0"_b, "st2_asisdlsop_dx2_r2d"},
    },
  },

  { "_hrllsn",
    {18, 17, 16},
    { {"000"_b, "fadd_z_p_zz"},
      {"001"_b, "fsub_z_p_zz"},
      {"010"_b, "fmul_z_p_zz"},
      {"011"_b, "fsubr_z_p_zz"},
      {"100"_b, "fmaxnm_z_p_zz"},
      {"101"_b, "fminnm_z_p_zz"},
      {"110"_b, "fmax_z_p_zz"},
      {"111"_b, "fmin_z_p_zz"},
    },
  },

  { "_hrxyts",
    {23, 22, 20, 19, 18, 13},
    { {"00000x"_b, "orr_z_zi"},
      {"01000x"_b, "eor_z_zi"},
      {"10000x"_b, "and_z_zi"},
      {"11000x"_b, "dupm_z_i"},
      {"xx1xx0"_b, "fcpy_z_p_i"},
    },
  },

  { "_hsjynv",
    {30},
    { {"0"_b, "bl_only_branch_imm"},
    },
  },

  { "_hstvrp",
    {20, 19, 18, 17, 16, 13},
    { {"000000"_b, "fmov_d_floatdp1"},
      {"000010"_b, "fneg_d_floatdp1"},
      {"000100"_b, "fcvt_sd_floatdp1"},
      {"000110"_b, "bfcvt_bs_floatdp1"},
      {"001000"_b, "frintn_d_floatdp1"},
      {"001010"_b, "frintm_d_floatdp1"},
      {"001100"_b, "frinta_d_floatdp1"},
      {"001110"_b, "frintx_d_floatdp1"},
      {"010000"_b, "frint32z_d_floatdp1"},
      {"010010"_b, "frint64z_d_floatdp1"},
    },
  },

  { "_hsvgnt",
    {23, 22, 4, 3, 2, 1, 0},
    { {"0000001"_b, "svc_ex_exception"},
      {"0000010"_b, "hvc_ex_exception"},
      {"0000011"_b, "smc_ex_exception"},
      {"0100000"_b, "hlt_ex_exception"},
    },
  },

  { "_htgzzx",
    {20, 18, 17, 16},
    { {"0000"_b, "_mqgtsq"},
    },
  },

  { "_hthxvr",
    {23, 22, 9},
    { {"010"_b, "pfirst_p_p_p"},
    },
  },

  { "_htmthz",
    {22, 20, 19, 18, 17, 16, 13, 12},
    { {"01111100"_b, "_msztzv"},
    },
  },

  { "_htnmls",
    {22, 13, 12},
    { {"000"_b, "ldapr_32l_memop"},
    },
  },

  { "_htplsj",
    {4},
    { {"0"_b, "cmpeq_p_p_zz"},
      {"1"_b, "cmpne_p_p_zz"},
    },
  },

  { "_htppjj",
    {30, 23, 22},
    { {"000"_b, "msub_64a_dp_3src"},
    },
  },

  { "_htqpks",
    {30, 20, 19, 18, 17, 16, 13},
    { {"000000x"_b, "add_z_zi"},
      {"000001x"_b, "sub_z_zi"},
      {"000011x"_b, "subr_z_zi"},
      {"000100x"_b, "sqadd_z_zi"},
      {"000101x"_b, "uqadd_z_zi"},
      {"000110x"_b, "sqsub_z_zi"},
      {"000111x"_b, "uqsub_z_zi"},
      {"0010000"_b, "smax_z_zi"},
      {"0010010"_b, "umax_z_zi"},
      {"0010100"_b, "smin_z_zi"},
      {"0010110"_b, "umin_z_zi"},
      {"0100000"_b, "mul_z_zi"},
      {"011000x"_b, "dup_z_i"},
      {"0110010"_b, "fdup_z_i"},
      {"1xxxxx0"_b, "fnmad_z_p_zzz"},
      {"1xxxxx1"_b, "fnmsb_z_p_zzz"},
    },
  },

  { "_hvvyhl",
    {23, 22, 20, 19, 18, 17, 16},
    { {"0x00001"_b, "frint32z_asimdmisc_r"},
      {"1111000"_b, "fcmlt_asimdmiscfp16_fz"},
      {"1x00000"_b, "fcmlt_asimdmisc_fz"},
    },
  },

  { "_hvyjnk",
    {11},
    { {"0"_b, "sqrdmulh_z_zzi_h"},
    },
  },

  { "_hxglyp",
    {17},
    { {"0"_b, "ld4_asisdlsep_r4_r"},
      {"1"_b, "ld4_asisdlsep_i4_i"},
    },
  },

  { "_hxmjhn",
    {30, 23, 22, 19, 16},
    { {"10010"_b, "aese_b_cryptoaes"},
      {"xxx00"_b, "cls_asimdmisc_r"},
      {"xxx01"_b, "sqxtn_asimdmisc_n"},
    },
  },

  { "_hxnmsl",
    {30, 23, 22, 20, 13},
    { {"00001"_b, "ld2w_z_p_bi_contiguous"},
      {"000x0"_b, "ld2w_z_p_br_contiguous"},
      {"00101"_b, "ld4w_z_p_bi_contiguous"},
      {"001x0"_b, "ld4w_z_p_br_contiguous"},
      {"01001"_b, "ld2d_z_p_bi_contiguous"},
      {"010x0"_b, "ld2d_z_p_br_contiguous"},
      {"01101"_b, "ld4d_z_p_bi_contiguous"},
      {"011x0"_b, "ld4d_z_p_br_contiguous"},
      {"10011"_b, "st2w_z_p_bi_contiguous"},
      {"100x0"_b, "st1w_z_p_bz_d_x32_scaled"},
      {"10111"_b, "st4w_z_p_bi_contiguous"},
      {"101x0"_b, "st1w_z_p_bz_s_x32_scaled"},
      {"10x01"_b, "st1w_z_p_bi"},
      {"11011"_b, "st2d_z_p_bi_contiguous"},
      {"110x0"_b, "st1d_z_p_bz_d_x32_scaled"},
      {"11111"_b, "st4d_z_p_bi_contiguous"},
      {"11x01"_b, "st1d_z_p_bi"},
    },
  },

  { "_hxrtsq",
    {23, 22, 12},
    { {"000"_b, "_gxlvsg"},
      {"001"_b, "_kxhjtk"},
      {"010"_b, "_hyxhpl"},
      {"011"_b, "_kvgjzh"},
      {"110"_b, "_tpsylx"},
      {"111"_b, "_zhpxqz"},
    },
  },

  { "_hxzlmm",
    {30, 23, 22},
    { {"000"_b, "stxp_sp32_ldstexcl"},
      {"001"_b, "ldxp_lp32_ldstexcl"},
      {"100"_b, "stxp_sp64_ldstexcl"},
      {"101"_b, "ldxp_lp64_ldstexcl"},
    },
  },

  { "_hykhmt",
    {20, 19, 18, 17, 16},
    { {"00000"_b, "saddv_r_p_z"},
      {"00001"_b, "uaddv_r_p_z"},
      {"01000"_b, "smaxv_r_p_z"},
      {"01001"_b, "umaxv_r_p_z"},
      {"01010"_b, "sminv_r_p_z"},
      {"01011"_b, "uminv_r_p_z"},
      {"1000x"_b, "movprfx_z_p_z"},
      {"11000"_b, "orv_r_p_z"},
      {"11001"_b, "eorv_r_p_z"},
      {"11010"_b, "andv_r_p_z"},
    },
  },

  { "_hyxhpl",
    {13},
    { {"0"_b, "_yrrppk"},
      {"1"_b, "_pnxggm"},
    },
  },

  { "_hyymjs",
    {18, 17, 12},
    { {"0x0"_b, "ld2_asisdlsop_dx2_r2d"},
      {"100"_b, "ld2_asisdlsop_dx2_r2d"},
      {"110"_b, "ld2_asisdlsop_d2_i2d"},
    },
  },

  { "_hzkglv",
    {30, 23, 22, 13},
    { {"0000"_b, "ld1b_z_p_br_u8"},
      {"0001"_b, "ldff1b_z_p_br_u8"},
      {"0010"_b, "ld1b_z_p_br_u32"},
      {"0011"_b, "ldff1b_z_p_br_u32"},
      {"0100"_b, "ld1sw_z_p_br_s64"},
      {"0101"_b, "ldff1sw_z_p_br_s64"},
      {"0110"_b, "ld1h_z_p_br_u32"},
      {"0111"_b, "ldff1h_z_p_br_u32"},
      {"1001"_b, "stnt1b_z_p_br_contiguous"},
      {"1011"_b, "st3b_z_p_br_contiguous"},
      {"10x0"_b, "st1b_z_p_br"},
      {"1101"_b, "stnt1h_z_p_br_contiguous"},
      {"1111"_b, "st3h_z_p_br_contiguous"},
      {"11x0"_b, "st1h_z_p_br"},
    },
  },

  { "_hzllgl",
    {17},
    { {"0"_b, "st1_asisdlse_r4_4v"},
    },
  },

  { "_hzmlps",
    {19},
    { {"0"_b, "_rpqgjl"},
      {"1"_b, "sys_cr_systeminstrs"},
    },
  },

  { "_hzxjsp",
    {23, 22, 20, 19, 16, 13, 10},
    { {"0000000"_b, "_shgkvq"},
      {"0000001"_b, "_vytxll"},
      {"0000010"_b, "_hqsvmh"},
      {"0000011"_b, "_gmvrxn"},
      {"0100000"_b, "_ygyxvx"},
      {"0100001"_b, "_tszvvk"},
      {"0100010"_b, "_tyjqvt"},
      {"0100011"_b, "_ylqnqt"},
      {"100xx00"_b, "st2_asisdlsop_sx2_r2s"},
      {"100xx01"_b, "_hrktgs"},
      {"100xx10"_b, "st4_asisdlsop_sx4_r4s"},
      {"100xx11"_b, "_mmrtvz"},
      {"1010x00"_b, "st2_asisdlsop_sx2_r2s"},
      {"1010x01"_b, "_lmtnzv"},
      {"1010x10"_b, "st4_asisdlsop_sx4_r4s"},
      {"1010x11"_b, "_qrykhm"},
      {"1011000"_b, "st2_asisdlsop_sx2_r2s"},
      {"1011001"_b, "_nyssqn"},
      {"1011010"_b, "st4_asisdlsop_sx4_r4s"},
      {"1011011"_b, "_kpqgsn"},
      {"1011100"_b, "_knpsmq"},
      {"1011101"_b, "_jzyzjh"},
      {"1011110"_b, "_vhhktl"},
      {"1011111"_b, "_yjxvkp"},
      {"110xx00"_b, "ld2_asisdlsop_sx2_r2s"},
      {"110xx01"_b, "_zppjvk"},
      {"110xx10"_b, "ld4_asisdlsop_sx4_r4s"},
      {"110xx11"_b, "_kqjmvy"},
      {"1110x00"_b, "ld2_asisdlsop_sx2_r2s"},
      {"1110x01"_b, "_ptkrvg"},
      {"1110x10"_b, "ld4_asisdlsop_sx4_r4s"},
      {"1110x11"_b, "_kjryvx"},
      {"1111000"_b, "ld2_asisdlsop_sx2_r2s"},
      {"1111001"_b, "_mlvpxh"},
      {"1111010"_b, "ld4_asisdlsop_sx4_r4s"},
      {"1111011"_b, "_xqjrgk"},
      {"1111100"_b, "_msgqps"},
      {"1111101"_b, "_hyymjs"},
      {"1111110"_b, "_qsnqpz"},
      {"1111111"_b, "_gzvgmh"},
    },
  },

  { "_jggvph",
    {30},
    { {"0"_b, "bic_64_log_shift"},
      {"1"_b, "eon_64_log_shift"},
    },
  },

  { "_jgmlpk",
    {4},
    { {"0"_b, "match_p_p_zz"},
      {"1"_b, "nmatch_p_p_zz"},
    },
  },

  { "_jgyhrh",
    {4},
    { {"0"_b, "cmplo_p_p_zi"},
      {"1"_b, "cmpls_p_p_zi"},
    },
  },

  { "_jhkglp",
    {30, 23, 22},
    { {"110"_b, "xar_vvv2_crypto3_imm6"},
    },
  },

  { "_jhllmn",
    {4},
    { {"0"_b, "cmpge_p_p_zz"},
      {"1"_b, "cmpgt_p_p_zz"},
    },
  },

  { "_jhqlkv",
    {30, 23, 22},
    { {"000"_b, "stxr_sr32_ldstexcl"},
      {"001"_b, "ldxr_lr32_ldstexcl"},
      {"010"_b, "stllr_sl32_ldstexcl"},
      {"011"_b, "ldlar_lr32_ldstexcl"},
      {"100"_b, "stxr_sr64_ldstexcl"},
      {"101"_b, "ldxr_lr64_ldstexcl"},
      {"110"_b, "stllr_sl64_ldstexcl"},
      {"111"_b, "ldlar_lr64_ldstexcl"},
    },
  },

  { "_jhytlg",
    {30, 23, 22, 13, 11, 10},
    { {"000010"_b, "str_b_ldst_regoff"},
      {"000110"_b, "str_bl_ldst_regoff"},
      {"001010"_b, "ldr_b_ldst_regoff"},
      {"001110"_b, "ldr_bl_ldst_regoff"},
      {"010x10"_b, "str_q_ldst_regoff"},
      {"011x10"_b, "ldr_q_ldst_regoff"},
      {"100x10"_b, "str_h_ldst_regoff"},
      {"101x10"_b, "ldr_h_ldst_regoff"},
    },
  },

  { "_jkkqvy",
    {22, 20, 11},
    { {"100"_b, "uqinch_z_zs"},
      {"101"_b, "uqdech_z_zs"},
      {"110"_b, "dech_z_zs"},
    },
  },

  { "_jkpsxk",
    {20},
    { {"0"_b, "_kyygzs"},
      {"1"_b, "msr_sr_systemmove"},
    },
  },

  { "_jkqktg",
    {20, 19, 18, 17, 16},
    { {"00000"_b, "sqneg_asimdmisc_r"},
    },
  },

  { "_jkrlsg",
    {23, 22},
    { {"00"_b, "fmsub_s_floatdp3"},
      {"01"_b, "fmsub_d_floatdp3"},
      {"11"_b, "fmsub_h_floatdp3"},
    },
  },

  { "_jksztq",
    {22, 20, 19, 13, 12},
    { {"0x100"_b, "sri_asisdshf_r"},
      {"0x101"_b, "sli_asisdshf_r"},
      {"0x110"_b, "sqshlu_asisdshf_r"},
      {"0x111"_b, "uqshl_asisdshf_r"},
      {"10x00"_b, "sri_asisdshf_r"},
      {"10x01"_b, "sli_asisdshf_r"},
      {"10x10"_b, "sqshlu_asisdshf_r"},
      {"10x11"_b, "uqshl_asisdshf_r"},
      {"11100"_b, "sri_asisdshf_r"},
      {"11101"_b, "sli_asisdshf_r"},
      {"11110"_b, "sqshlu_asisdshf_r"},
      {"11111"_b, "uqshl_asisdshf_r"},
      {"x1000"_b, "sri_asisdshf_r"},
      {"x1001"_b, "sli_asisdshf_r"},
      {"x1010"_b, "sqshlu_asisdshf_r"},
      {"x1011"_b, "uqshl_asisdshf_r"},
    },
  },

  { "_jkxlnq",
    {30},
    { {"0"_b, "bl_only_branch_imm"},
      {"1"_b, "_nhzyvv"},
    },
  },

  { "_jlqjzr",
    {30, 23},
    { {"00"_b, "adds_64s_addsub_imm"},
      {"10"_b, "subs_64s_addsub_imm"},
    },
  },

  { "_jlqxvj",
    {23, 22},
    { {"01"_b, "_mplgqv"},
      {"10"_b, "xar_vvv2_crypto3_imm6"},
      {"11"_b, "_ljhtkq"},
    },
  },

  { "_jlrrlt",
    {11, 10, 4},
    { {"000"_b, "whilege_p_p_rr"},
      {"001"_b, "whilegt_p_p_rr"},
      {"010"_b, "whilelt_p_p_rr"},
      {"011"_b, "whilele_p_p_rr"},
      {"100"_b, "whilehs_p_p_rr"},
      {"101"_b, "whilehi_p_p_rr"},
      {"110"_b, "whilelo_p_p_rr"},
      {"111"_b, "whilels_p_p_rr"},
    },
  },

  { "_jlrvpl",
    {17},
    { {"0"_b, "st2_asisdlse_r2"},
    },
  },

  { "_jmgkrl",
    {30},
    { {"0"_b, "orn_32_log_shift"},
      {"1"_b, "bics_32_log_shift"},
    },
  },

  { "_jmvgsp",
    {22, 20, 11},
    { {"100"_b, "sqinch_z_zs"},
      {"101"_b, "sqdech_z_zs"},
      {"110"_b, "inch_z_zs"},
    },
  },

  { "_jmxstz",
    {13, 12, 11, 10},
    { {"0000"_b, "sqdecp_z_p_z"},
      {"0010"_b, "sqdecp_r_p_r_sx"},
      {"0011"_b, "sqdecp_r_p_r_x"},
    },
  },

  { "_jmyslr",
    {17},
    { {"0"_b, "ld1_asisdlsep_r4_r4"},
      {"1"_b, "ld1_asisdlsep_i4_i4"},
    },
  },

  { "_jnjlsh",
    {12},
    { {"0"_b, "st1_asisdlsop_dx1_r1d"},
    },
  },

  { "_jnmgrh",
    {30, 19, 18, 17, 16},
    { {"11000"_b, "ins_asimdins_iv_v"},
      {"1x100"_b, "ins_asimdins_iv_v"},
      {"1xx10"_b, "ins_asimdins_iv_v"},
      {"1xxx1"_b, "ins_asimdins_iv_v"},
    },
  },

  { "_jplmmr",
    {23, 22, 20, 19, 16, 13, 12},
    { {"0111100"_b, "fcvtas_asisdmiscfp16_r"},
      {"0111101"_b, "scvtf_asisdmiscfp16_r"},
      {"0x00100"_b, "fcvtas_asisdmisc_r"},
      {"0x00101"_b, "scvtf_asisdmisc_r"},
      {"0x10000"_b, "fmaxnmp_asisdpair_only_h"},
      {"0x10001"_b, "faddp_asisdpair_only_h"},
      {"0x10011"_b, "fmaxp_asisdpair_only_h"},
      {"1111000"_b, "fcmgt_asisdmiscfp16_fz"},
      {"1111001"_b, "fcmeq_asisdmiscfp16_fz"},
      {"1111010"_b, "fcmlt_asisdmiscfp16_fz"},
      {"1111101"_b, "frecpe_asisdmiscfp16_r"},
      {"1111111"_b, "frecpx_asisdmiscfp16_r"},
      {"1x00000"_b, "fcmgt_asisdmisc_fz"},
      {"1x00001"_b, "fcmeq_asisdmisc_fz"},
      {"1x00010"_b, "fcmlt_asisdmisc_fz"},
      {"1x00101"_b, "frecpe_asisdmisc_r"},
      {"1x00111"_b, "frecpx_asisdmisc_r"},
      {"1x10000"_b, "fminnmp_asisdpair_only_h"},
      {"1x10011"_b, "fminp_asisdpair_only_h"},
    },
  },

  { "_jpvljz",
    {23, 22},
    { {"01"_b, "fcmeq_asimdsamefp16_only"},
    },
  },

  { "_jpxgqh",
    {30, 23, 22},
    { {"000"_b, "sbfm_32m_bitfield"},
      {"100"_b, "ubfm_32m_bitfield"},
    },
  },

  { "_jqjnrv",
    {18, 17},
    { {"00"_b, "st1_asisdlso_s1_1s"},
    },
  },

  { "_jqnglz",
    {23, 22, 20, 19, 11},
    { {"00010"_b, "ucvtf_asisdshf_c"},
      {"001x0"_b, "ucvtf_asisdshf_c"},
      {"01xx0"_b, "ucvtf_asisdshf_c"},
    },
  },

  { "_jqnhrj",
    {12, 10},
    { {"00"_b, "_mzynlp"},
      {"01"_b, "_mvglql"},
      {"10"_b, "_tylqpt"},
      {"11"_b, "_lrjyhr"},
    },
  },

  { "_jqplxx",
    {20, 19, 18, 17, 16, 13, 12},
    { {"1111100"_b, "_xpvpqq"},
    },
  },

  { "_jqtltz",
    {13},
    { {"0"_b, "mul_asimdelem_r"},
      {"1"_b, "smull_asimdelem_l"},
    },
  },

  { "_jqxqql",
    {22, 20, 11},
    { {"000"_b, "uqincw_z_zs"},
      {"001"_b, "uqdecw_z_zs"},
      {"010"_b, "decw_z_zs"},
      {"100"_b, "uqincd_z_zs"},
      {"101"_b, "uqdecd_z_zs"},
      {"110"_b, "decd_z_zs"},
    },
  },

  { "_jrgzxt",
    {18, 17},
    { {"00"_b, "ld3_asisdlse_r3"},
    },
  },

  { "_jrlynj",
    {11, 10},
    { {"00"_b, "_gzqvnk"},
    },
  },

  { "_jrnlzs",
    {13, 12, 11},
    { {"000"_b, "fminnmp_asimdsamefp16_only"},
      {"010"_b, "fabd_asimdsamefp16_only"},
      {"100"_b, "fcmgt_asimdsamefp16_only"},
      {"101"_b, "facgt_asimdsamefp16_only"},
      {"110"_b, "fminp_asimdsamefp16_only"},
    },
  },

  { "_jrnxzh",
    {12},
    { {"0"_b, "cmla_z_zzz"},
      {"1"_b, "sqrdcmlah_z_zzz"},
    },
  },

  { "_jrsptt",
    {13, 12},
    { {"00"_b, "sqadd_asisdsame_only"},
      {"10"_b, "sqsub_asisdsame_only"},
      {"11"_b, "cmge_asisdsame_only"},
    },
  },

  { "_jryylt",
    {30, 23, 22, 19, 18, 17, 16},
    { {"00000x1"_b, "smov_asimdins_w_w"},
      {"0000x10"_b, "smov_asimdins_w_w"},
      {"00010xx"_b, "smov_asimdins_w_w"},
      {"0001110"_b, "smov_asimdins_w_w"},
      {"000x10x"_b, "smov_asimdins_w_w"},
      {"000x111"_b, "smov_asimdins_w_w"},
      {"10000x1"_b, "smov_asimdins_x_x"},
      {"1000x10"_b, "smov_asimdins_x_x"},
      {"10010xx"_b, "smov_asimdins_x_x"},
      {"1001110"_b, "smov_asimdins_x_x"},
      {"100x10x"_b, "smov_asimdins_x_x"},
      {"100x111"_b, "smov_asimdins_x_x"},
    },
  },

  { "_jsygzs",
    {30, 23, 22, 12, 11, 10},
    { {"0000xx"_b, "add_64_addsub_ext"},
      {"000100"_b, "add_64_addsub_ext"},
      {"1000xx"_b, "sub_64_addsub_ext"},
      {"100100"_b, "sub_64_addsub_ext"},
    },
  },

  { "_jtqlhs",
    {22},
    { {"0"_b, "str_64_ldst_regoff"},
      {"1"_b, "ldr_64_ldst_regoff"},
    },
  },

  { "_jvhnxl",
    {23},
    { {"0"_b, "fcmge_asimdsame_only"},
      {"1"_b, "fcmgt_asimdsame_only"},
    },
  },

  { "_jvpqrp",
    {23, 22},
    { {"00"_b, "fmla_asisdelem_rh_h"},
      {"1x"_b, "fmla_asisdelem_r_sd"},
    },
  },

  { "_jvvzjq",
    {23, 22},
    { {"00"_b, "fcsel_s_floatsel"},
      {"01"_b, "fcsel_d_floatsel"},
      {"11"_b, "fcsel_h_floatsel"},
    },
  },

  { "_jxrlyh",
    {12},
    { {"0"_b, "_mtgksl"},
    },
  },

  { "_jxszhy",
    {23, 22, 11},
    { {"000"_b, "_rqhryp"},
    },
  },

  { "_jxtgtx",
    {30, 23, 22},
    { {"000"_b, "str_b_ldst_pos"},
      {"001"_b, "ldr_b_ldst_pos"},
      {"010"_b, "str_q_ldst_pos"},
      {"011"_b, "ldr_q_ldst_pos"},
      {"100"_b, "str_h_ldst_pos"},
      {"101"_b, "ldr_h_ldst_pos"},
    },
  },

  { "_jxyskn",
    {13, 12, 11, 10},
    { {"0000"_b, "uqincp_z_p_z"},
      {"0010"_b, "uqincp_r_p_r_uw"},
      {"0011"_b, "uqincp_r_p_r_x"},
    },
  },

  { "_jxzrxm",
    {20, 19, 18, 17, 16},
    { {"00000"_b, "usqadd_asisdmisc_r"},
    },
  },

  { "_jymnkk",
    {23, 22, 12, 11, 10},
    { {"01000"_b, "bfdot_z_zzzi"},
      {"100x0"_b, "fmlalb_z_zzzi_s"},
      {"100x1"_b, "fmlalt_z_zzzi_s"},
      {"110x0"_b, "bfmlalb_z_zzzi"},
      {"110x1"_b, "bfmlalt_z_zzzi"},
    },
  },

  { "_jyxszq",
    {30, 4},
    { {"0x"_b, "b_only_branch_imm"},
      {"10"_b, "b_only_condbranch"},
    },
  },

  { "_jzjvtv",
    {19, 18, 17, 16, 4},
    { {"00000"_b, "brkbs_p_p_p_z"},
    },
  },

  { "_jzkqhn",
    {23, 22, 12, 11, 10},
    { {"10000"_b, "fmlslb_z_zzz"},
      {"10001"_b, "fmlslt_z_zzz"},
    },
  },

  { "_jzyzjh",
    {18, 17, 12},
    { {"0x0"_b, "st2_asisdlsop_dx2_r2d"},
      {"100"_b, "st2_asisdlsop_dx2_r2d"},
      {"110"_b, "st2_asisdlsop_d2_i2d"},
    },
  },

  { "_kgmqkh",
    {30, 23, 22, 13},
    { {"0000"_b, "ld1w_z_p_ai_s"},
      {"0001"_b, "ldff1w_z_p_ai_s"},
      {"0010"_b, "ld1rw_z_p_bi_u32"},
      {"0011"_b, "ld1rw_z_p_bi_u64"},
      {"0110"_b, "ld1rsb_z_p_bi_s16"},
      {"0111"_b, "ld1rd_z_p_bi_u64"},
      {"1000"_b, "ld1w_z_p_ai_d"},
      {"1001"_b, "ldff1w_z_p_ai_d"},
      {"1010"_b, "ld1w_z_p_bz_d_64_scaled"},
      {"1011"_b, "ldff1w_z_p_bz_d_64_scaled"},
      {"1100"_b, "ld1d_z_p_ai_d"},
      {"1101"_b, "ldff1d_z_p_ai_d"},
      {"1110"_b, "ld1d_z_p_bz_d_64_scaled"},
      {"1111"_b, "ldff1d_z_p_bz_d_64_scaled"},
    },
  },

  { "_kgpgly",
    {23, 22, 10},
    { {"100"_b, "smlslb_z_zzzi_s"},
      {"101"_b, "smlslt_z_zzzi_s"},
      {"110"_b, "smlslb_z_zzzi_d"},
      {"111"_b, "smlslt_z_zzzi_d"},
    },
  },

  { "_khjvqq",
    {22, 11},
    { {"00"_b, "sqrdmulh_z_zzi_s"},
      {"10"_b, "sqrdmulh_z_zzi_d"},
    },
  },

  { "_kjghlk",
    {23, 22, 20, 19, 13, 11},
    { {"0000x0"_b, "orr_asimdimm_l_sl"},
      {"00x100"_b, "ssra_asimdshf_r"},
      {"00x110"_b, "srsra_asimdshf_r"},
      {"010x00"_b, "ssra_asimdshf_r"},
      {"010x10"_b, "srsra_asimdshf_r"},
      {"011100"_b, "ssra_asimdshf_r"},
      {"011110"_b, "srsra_asimdshf_r"},
      {"0x1000"_b, "ssra_asimdshf_r"},
      {"0x1010"_b, "srsra_asimdshf_r"},
    },
  },

  { "_kjngjl",
    {23, 22},
    { {"00"_b, "tbx_asimdtbl_l1_1"},
    },
  },

  { "_kjpxvh",
    {20, 19, 18},
    { {"000"_b, "_yyrkmn"},
    },
  },

  { "_kjqynn",
    {4},
    { {"0"_b, "cmphs_p_p_zi"},
      {"1"_b, "cmphi_p_p_zi"},
    },
  },

  { "_kjrxpx",
    {23, 22, 20, 19, 18, 17, 16},
    { {"0111001"_b, "ucvtf_asimdmiscfp16_r"},
      {"0x00001"_b, "ucvtf_asimdmisc_r"},
      {"1111000"_b, "fcmle_asimdmiscfp16_fz"},
      {"1111001"_b, "frsqrte_asimdmiscfp16_r"},
      {"1x00000"_b, "fcmle_asimdmisc_fz"},
      {"1x00001"_b, "frsqrte_asimdmisc_r"},
    },
  },

  { "_kjryvx",
    {12},
    { {"0"_b, "ld4_asisdlsop_dx4_r4d"},
    },
  },

  { "_kjyphv",
    {20, 19, 18, 17, 16},
    { {"10000"_b, "fmaxp_asisdpair_only_sd"},
    },
  },

  { "_kkgpjl",
    {20, 19, 18, 17},
    { {"0000"_b, "_msqkyy"},
    },
  },

  { "_kkgzst",
    {23, 22, 13, 12, 11, 10},
    { {"0001x0"_b, "fmla_asimdelem_rh_h"},
      {"0x0001"_b, "sshr_asimdshf_r"},
      {"0x0101"_b, "ssra_asimdshf_r"},
      {"0x1001"_b, "srshr_asimdshf_r"},
      {"0x1101"_b, "srsra_asimdshf_r"},
      {"1000x0"_b, "fmlal_asimdelem_lh"},
      {"1x01x0"_b, "fmla_asimdelem_r_sd"},
      {"xx10x0"_b, "smlal_asimdelem_l"},
      {"xx11x0"_b, "sqdmlal_asimdelem_l"},
    },
  },

  { "_kkmjyr",
    {0},
    { {"1"_b, "blrabz_64_branch_reg"},
    },
  },

  { "_kkmxxx",
    {30},
    { {"0"_b, "bl_only_branch_imm"},
      {"1"_b, "_jqplxx"},
    },
  },

  { "_kknjng",
    {23, 22, 20, 19, 11},
    { {"00010"_b, "ssra_asisdshf_r"},
      {"001x0"_b, "ssra_asisdshf_r"},
      {"01xx0"_b, "ssra_asisdshf_r"},
    },
  },

  { "_kktglv",
    {30, 13, 12},
    { {"000"_b, "_njvkjq"},
      {"001"_b, "_rpzykx"},
      {"010"_b, "_zzvxvh"},
      {"011"_b, "_yqxnzl"},
      {"100"_b, "_gxmnkl"},
      {"110"_b, "_lkxgjy"},
      {"111"_b, "_vjmklj"},
    },
  },

  { "_kkvrzq",
    {23, 22, 9, 8, 7, 6, 5},
    { {"0000000"_b, "pfalse_p"},
    },
  },

  { "_klkgqk",
    {23, 22, 20, 19, 18, 17, 16},
    { {"0111001"_b, "fcvtms_asimdmiscfp16_r"},
      {"0x00001"_b, "fcvtms_asimdmisc_r"},
      {"1111001"_b, "fcvtzs_asimdmiscfp16_r"},
      {"1x00001"_b, "fcvtzs_asimdmisc_r"},
      {"xx00000"_b, "abs_asimdmisc_r"},
      {"xx10001"_b, "addv_asimdall_only"},
    },
  },

  { "_klnhpj",
    {9, 8, 7, 6, 5, 1, 0},
    { {"1111111"_b, "eretab_64e_branch_reg"},
    },
  },

  { "_klthpn",
    {30, 23, 22, 11, 10},
    { {"01000"_b, "csel_64_condsel"},
      {"01001"_b, "csinc_64_condsel"},
      {"11000"_b, "csinv_64_condsel"},
      {"11001"_b, "csneg_64_condsel"},
    },
  },

  { "_kmhtqp",
    {30},
    { {"0"_b, "bl_only_branch_imm"},
    },
  },

  { "_kmkpnj",
    {17},
    { {"0"_b, "ld3_asisdlso_h3_3h"},
    },
  },

  { "_knkjnz",
    {30, 23, 22, 20, 13},
    { {"00001"_b, "ld1sh_z_p_bi_s32"},
      {"00011"_b, "ldnf1sh_z_p_bi_s32"},
      {"00101"_b, "ld1w_z_p_bi_u64"},
      {"00111"_b, "ldnf1w_z_p_bi_u64"},
      {"01001"_b, "ld1sb_z_p_bi_s32"},
      {"01011"_b, "ldnf1sb_z_p_bi_s32"},
      {"01101"_b, "ld1d_z_p_bi_u64"},
      {"01111"_b, "ldnf1d_z_p_bi_u64"},
      {"100x0"_b, "st1w_z_p_bz_d_x32_scaled"},
      {"100x1"_b, "st1w_z_p_bz_d_64_scaled"},
      {"101x0"_b, "st1w_z_p_bz_s_x32_scaled"},
      {"101x1"_b, "st1w_z_p_ai_s"},
      {"110x0"_b, "st1d_z_p_bz_d_x32_scaled"},
      {"110x1"_b, "st1d_z_p_bz_d_64_scaled"},
    },
  },

  { "_knpsmq",
    {18, 17},
    { {"0x"_b, "st2_asisdlsop_sx2_r2s"},
      {"10"_b, "st2_asisdlsop_sx2_r2s"},
      {"11"_b, "st2_asisdlsop_s2_i2s"},
    },
  },

  { "_kpmvkn",
    {30, 23, 22, 11, 10},
    { {"00000"_b, "stur_b_ldst_unscaled"},
      {"00001"_b, "str_b_ldst_immpost"},
      {"00011"_b, "str_b_ldst_immpre"},
      {"00100"_b, "ldur_b_ldst_unscaled"},
      {"00101"_b, "ldr_b_ldst_immpost"},
      {"00111"_b, "ldr_b_ldst_immpre"},
      {"01000"_b, "stur_q_ldst_unscaled"},
      {"01001"_b, "str_q_ldst_immpost"},
      {"01011"_b, "str_q_ldst_immpre"},
      {"01100"_b, "ldur_q_ldst_unscaled"},
      {"01101"_b, "ldr_q_ldst_immpost"},
      {"01111"_b, "ldr_q_ldst_immpre"},
      {"10000"_b, "stur_h_ldst_unscaled"},
      {"10001"_b, "str_h_ldst_immpost"},
      {"10011"_b, "str_h_ldst_immpre"},
      {"10100"_b, "ldur_h_ldst_unscaled"},
      {"10101"_b, "ldr_h_ldst_immpost"},
      {"10111"_b, "ldr_h_ldst_immpre"},
    },
  },

  { "_kpqgsn",
    {12},
    { {"0"_b, "st4_asisdlsop_dx4_r4d"},
    },
  },

  { "_kpxtsp",
    {6, 5},
    { {"00"_b, "cfinv_m_pstate"},
      {"01"_b, "xaflag_m_pstate"},
      {"10"_b, "axflag_m_pstate"},
    },
  },

  { "_kpyqyv",
    {12},
    { {"0"_b, "_vjxqhp"},
    },
  },

  { "_kqjmvy",
    {12},
    { {"0"_b, "ld4_asisdlsop_dx4_r4d"},
    },
  },

  { "_kqkhtz",
    {9, 8, 7, 6, 5},
    { {"11111"_b, "autiza_64z_dp_1src"},
    },
  },

  { "_kqvljp",
    {18, 17, 16},
    { {"000"_b, "fabd_z_p_zz"},
      {"001"_b, "fscale_z_p_zz"},
      {"010"_b, "fmulx_z_p_zz"},
      {"100"_b, "fdivr_z_p_zz"},
      {"101"_b, "fdiv_z_p_zz"},
    },
  },

  { "_kqxhzx",
    {20, 19, 18, 16, 12, 11, 10},
    { {"0000xxx"_b, "_zmzxjm"},
      {"0010xxx"_b, "_tmshps"},
      {"0011xxx"_b, "_tsksxr"},
      {"0110100"_b, "_pnzphx"},
      {"0111100"_b, "_xpkkpn"},
      {"1000xxx"_b, "_psqpkp"},
      {"1001xxx"_b, "_phxkzh"},
      {"1100xxx"_b, "_vsvrgt"},
    },
  },

  { "_kqzmtr",
    {30, 23, 22, 20, 13},
    { {"00001"_b, "ld1b_z_p_bi_u16"},
      {"00011"_b, "ldnf1b_z_p_bi_u16"},
      {"00101"_b, "ld1b_z_p_bi_u64"},
      {"00111"_b, "ldnf1b_z_p_bi_u64"},
      {"01001"_b, "ld1h_z_p_bi_u16"},
      {"01011"_b, "ldnf1h_z_p_bi_u16"},
      {"01101"_b, "ld1h_z_p_bi_u64"},
      {"01111"_b, "ldnf1h_z_p_bi_u64"},
      {"101x1"_b, "st1b_z_p_ai_s"},
      {"110x0"_b, "st1h_z_p_bz_d_x32_scaled"},
      {"110x1"_b, "st1h_z_p_bz_d_64_scaled"},
      {"111x0"_b, "st1h_z_p_bz_s_x32_scaled"},
      {"111x1"_b, "st1h_z_p_ai_s"},
    },
  },

  { "_krhrrr",
    {12, 10},
    { {"00"_b, "_xyzpvp"},
      {"01"_b, "_nlyntn"},
      {"10"_b, "_zhkjzg"},
      {"11"_b, "_zmpzkg"},
    },
  },

  { "_krlpjl",
    {23, 22, 20, 19, 17, 16},
    { {"000010"_b, "scvtf_s64_float2fix"},
      {"000011"_b, "ucvtf_s64_float2fix"},
      {"001100"_b, "fcvtzs_64s_float2fix"},
      {"001101"_b, "fcvtzu_64s_float2fix"},
      {"010010"_b, "scvtf_d64_float2fix"},
      {"010011"_b, "ucvtf_d64_float2fix"},
      {"011100"_b, "fcvtzs_64d_float2fix"},
      {"011101"_b, "fcvtzu_64d_float2fix"},
      {"110010"_b, "scvtf_h64_float2fix"},
      {"110011"_b, "ucvtf_h64_float2fix"},
      {"111100"_b, "fcvtzs_64h_float2fix"},
      {"111101"_b, "fcvtzu_64h_float2fix"},
    },
  },

  { "_kstltt",
    {18, 17, 12},
    { {"0x0"_b, "ld3_asisdlsop_dx3_r3d"},
      {"100"_b, "ld3_asisdlsop_dx3_r3d"},
      {"110"_b, "ld3_asisdlsop_d3_i3d"},
    },
  },

  { "_ksvxxm",
    {9, 8, 7, 6, 5},
    { {"11111"_b, "pacizb_64z_dp_1src"},
    },
  },

  { "_ktnjrx",
    {30, 23, 22, 13, 12, 11, 10},
    { {"000xxxx"_b, "fnmadd_s_floatdp3"},
      {"001xxxx"_b, "fnmadd_d_floatdp3"},
      {"011xxxx"_b, "fnmadd_h_floatdp3"},
      {"10001x0"_b, "fmls_asisdelem_rh_h"},
      {"10x0101"_b, "shl_asisdshf_r"},
      {"10x1101"_b, "sqshl_asisdshf_r"},
      {"11x01x0"_b, "fmls_asisdelem_r_sd"},
      {"1xx11x0"_b, "sqdmlsl_asisdelem_l"},
    },
  },

  { "_ktrkrp",
    {17},
    { {"0"_b, "st3_asisdlso_h3_3h"},
    },
  },

  { "_ktyppm",
    {11, 10},
    { {"00"_b, "asr_z_zw"},
      {"01"_b, "lsr_z_zw"},
      {"11"_b, "lsl_z_zw"},
    },
  },

  { "_kvgjzh",
    {9, 8, 7, 6, 5},
    { {"00000"_b, "fmov_d_floatimm"},
    },
  },

  { "_kvmrng",
    {23, 22},
    { {"00"_b, "tbl_asimdtbl_l1_1"},
    },
  },

  { "_kvnqhn",
    {22, 20, 11},
    { {"000"_b, "sqincw_r_rs_sx"},
      {"001"_b, "sqdecw_r_rs_sx"},
      {"010"_b, "sqincw_r_rs_x"},
      {"011"_b, "sqdecw_r_rs_x"},
      {"100"_b, "sqincd_r_rs_sx"},
      {"101"_b, "sqdecd_r_rs_sx"},
      {"110"_b, "sqincd_r_rs_x"},
      {"111"_b, "sqdecd_r_rs_x"},
    },
  },

  { "_kvyysq",
    {12, 9, 8, 7, 6, 5},
    { {"100000"_b, "_sjrqth"},
    },
  },

  { "_kxhjtk",
    {9, 8, 7, 6, 5},
    { {"00000"_b, "fmov_s_floatimm"},
    },
  },

  { "_kxjgsz",
    {23, 22, 20, 19, 11},
    { {"00000"_b, "movi_asimdimm_m_sm"},
    },
  },

  { "_kxkyqr",
    {17},
    { {"0"_b, "ld4_asisdlsop_hx4_r4h"},
      {"1"_b, "ld4_asisdlsop_h4_i4h"},
    },
  },

  { "_kxprqm",
    {13, 12, 11, 10},
    { {"0000"_b, "raddhn_asimddiff_n"},
      {"0001"_b, "ushl_asimdsame_only"},
      {"0010"_b, "_mmknzp"},
      {"0011"_b, "uqshl_asimdsame_only"},
      {"0100"_b, "uabal_asimddiff_l"},
      {"0101"_b, "urshl_asimdsame_only"},
      {"0110"_b, "_glgrjy"},
      {"0111"_b, "uqrshl_asimdsame_only"},
      {"1000"_b, "rsubhn_asimddiff_n"},
      {"1001"_b, "umax_asimdsame_only"},
      {"1010"_b, "_pxlnhs"},
      {"1011"_b, "umin_asimdsame_only"},
      {"1100"_b, "uabdl_asimddiff_l"},
      {"1101"_b, "uabd_asimdsame_only"},
      {"1110"_b, "_jkqktg"},
      {"1111"_b, "uaba_asimdsame_only"},
    },
  },

  { "_kxsysq",
    {30},
    { {"0"_b, "tbnz_only_testbranch"},
    },
  },

  { "_kxvvkq",
    {30, 23, 13},
    { {"000"_b, "ld1b_z_p_bz_s_x32_unscaled"},
      {"001"_b, "ldff1b_z_p_bz_s_x32_unscaled"},
      {"010"_b, "ld1h_z_p_bz_s_x32_unscaled"},
      {"011"_b, "ldff1h_z_p_bz_s_x32_unscaled"},
      {"100"_b, "ld1b_z_p_bz_d_x32_unscaled"},
      {"101"_b, "ldff1b_z_p_bz_d_x32_unscaled"},
      {"110"_b, "ld1h_z_p_bz_d_x32_unscaled"},
      {"111"_b, "ldff1h_z_p_bz_d_x32_unscaled"},
    },
  },

  { "_kyjxrr",
    {30, 13},
    { {"00"_b, "_qtxpky"},
      {"01"_b, "_hnjrmp"},
      {"11"_b, "_vzjvtv"},
    },
  },

  { "_kykymg",
    {30},
    { {"1"_b, "_rsyhtj"},
    },
  },

  { "_kypqpy",
    {30, 23, 22, 13, 12, 11, 10},
    { {"1010000"_b, "sm3partw1_vvv4_cryptosha512_3"},
      {"1010001"_b, "sm3partw2_vvv4_cryptosha512_3"},
      {"1010010"_b, "sm4ekey_vvv4_cryptosha512_3"},
    },
  },

  { "_kyspnn",
    {22},
    { {"0"_b, "sqdmullb_z_zzi_s"},
      {"1"_b, "sqdmullb_z_zzi_d"},
    },
  },

  { "_kyxqgg",
    {20, 19, 18, 17, 16, 13, 12},
    { {"0000000"_b, "stgm_64bulk_ldsttags"},
    },
  },

  { "_kyxrqg",
    {10},
    { {"0"_b, "uabalb_z_zzz"},
      {"1"_b, "uabalt_z_zzz"},
    },
  },

  { "_kyygzs",
    {19},
    { {"0"_b, "_nnkyzr"},
      {"1"_b, "sys_cr_systeminstrs"},
    },
  },

  { "_kyyzks",
    {13, 12},
    { {"00"_b, "sdiv_32_dp_2src"},
      {"10"_b, "rorv_32_dp_2src"},
    },
  },

  { "_kzmvpk",
    {23, 22, 10},
    { {"100"_b, "smlalb_z_zzzi_s"},
      {"101"_b, "smlalt_z_zzzi_s"},
      {"110"_b, "smlalb_z_zzzi_d"},
      {"111"_b, "smlalt_z_zzzi_d"},
    },
  },

  { "_kzrklp",
    {17},
    { {"0"_b, "ld4_asisdlso_b4_4b"},
    },
  },

  { "_lgglzy",
    {30, 23, 22, 19, 16},
    { {"10010"_b, "aesimc_b_cryptoaes"},
      {"x0x01"_b, "fcvtl_asimdmisc_l"},
      {"xxx00"_b, "sqabs_asimdmisc_r"},
    },
  },

  { "_lhmlrj",
    {30, 23, 22, 20, 19},
    { {"0xxxx"_b, "bl_only_branch_imm"},
      {"10001"_b, "sysl_rc_systeminstrs"},
      {"1001x"_b, "mrs_rs_systemmove"},
    },
  },

  { "_lhpgsn",
    {13, 12, 10},
    { {"000"_b, "sqdmulh_asisdelem_r"},
      {"010"_b, "sqrdmulh_asisdelem_r"},
      {"101"_b, "_mxkgnq"},
      {"111"_b, "_sgnknz"},
    },
  },

  { "_lhtyjq",
    {23, 22, 20, 19, 18, 16, 13},
    { {"0000000"_b, "_gskkxk"},
      {"0000001"_b, "_ktrkrp"},
      {"0100000"_b, "_nmtkjv"},
      {"0100001"_b, "_kmkpnj"},
      {"100xxx0"_b, "st1_asisdlsop_hx1_r1h"},
      {"100xxx1"_b, "st3_asisdlsop_hx3_r3h"},
      {"1010xx0"_b, "st1_asisdlsop_hx1_r1h"},
      {"1010xx1"_b, "st3_asisdlsop_hx3_r3h"},
      {"10110x0"_b, "st1_asisdlsop_hx1_r1h"},
      {"10110x1"_b, "st3_asisdlsop_hx3_r3h"},
      {"1011100"_b, "st1_asisdlsop_hx1_r1h"},
      {"1011101"_b, "st3_asisdlsop_hx3_r3h"},
      {"1011110"_b, "_mgmgqh"},
      {"1011111"_b, "_gzylzp"},
      {"110xxx0"_b, "ld1_asisdlsop_hx1_r1h"},
      {"110xxx1"_b, "ld3_asisdlsop_hx3_r3h"},
      {"1110xx0"_b, "ld1_asisdlsop_hx1_r1h"},
      {"1110xx1"_b, "ld3_asisdlsop_hx3_r3h"},
      {"11110x0"_b, "ld1_asisdlsop_hx1_r1h"},
      {"11110x1"_b, "ld3_asisdlsop_hx3_r3h"},
      {"1111100"_b, "ld1_asisdlsop_hx1_r1h"},
      {"1111101"_b, "ld3_asisdlsop_hx3_r3h"},
      {"1111110"_b, "_mrkkps"},
      {"1111111"_b, "_xygxsv"},
    },
  },

  { "_lhvtrp",
    {23, 22, 20, 19, 13, 11},
    { {"0000x0"_b, "orr_asimdimm_l_hl"},
      {"00x100"_b, "sqshrn_asimdshf_n"},
      {"00x101"_b, "sqrshrn_asimdshf_n"},
      {"010x00"_b, "sqshrn_asimdshf_n"},
      {"010x01"_b, "sqrshrn_asimdshf_n"},
      {"011100"_b, "sqshrn_asimdshf_n"},
      {"011101"_b, "sqrshrn_asimdshf_n"},
      {"0x1000"_b, "sqshrn_asimdshf_n"},
      {"0x1001"_b, "sqrshrn_asimdshf_n"},
    },
  },

  { "_ljhtkq",
    {20, 19, 18, 17, 16, 13, 12, 11},
    { {"00000000"_b, "_yvyxkx"},
    },
  },

  { "_ljljkv",
    {30, 23, 22, 13, 12, 11, 10},
    { {"0001100"_b, "and_z_zz"},
      {"0001110"_b, "eor3_z_zzz"},
      {"0001111"_b, "bsl_z_zzz"},
      {"0011100"_b, "orr_z_zz"},
      {"0011110"_b, "bcax_z_zzz"},
      {"0011111"_b, "bsl1n_z_zzz"},
      {"0101100"_b, "eor_z_zz"},
      {"0101111"_b, "bsl2n_z_zzz"},
      {"0111100"_b, "bic_z_zz"},
      {"0111111"_b, "nbsl_z_zzz"},
      {"0xx0000"_b, "add_z_zz"},
      {"0xx0001"_b, "sub_z_zz"},
      {"0xx0100"_b, "sqadd_z_zz"},
      {"0xx0101"_b, "uqadd_z_zz"},
      {"0xx0110"_b, "sqsub_z_zz"},
      {"0xx0111"_b, "uqsub_z_zz"},
      {"0xx1101"_b, "xar_z_zzi"},
      {"10x0010"_b, "mla_z_zzzi_h"},
      {"10x0011"_b, "mls_z_zzzi_h"},
      {"10x0100"_b, "sqrdmlah_z_zzzi_h"},
      {"10x0101"_b, "sqrdmlsh_z_zzzi_h"},
      {"1100000"_b, "sdot_z_zzzi_s"},
      {"1100001"_b, "udot_z_zzzi_s"},
      {"1100010"_b, "mla_z_zzzi_s"},
      {"1100011"_b, "mls_z_zzzi_s"},
      {"1100100"_b, "sqrdmlah_z_zzzi_s"},
      {"1100101"_b, "sqrdmlsh_z_zzzi_s"},
      {"1100110"_b, "usdot_z_zzzi_s"},
      {"1100111"_b, "sudot_z_zzzi_s"},
      {"11010x0"_b, "sqdmlalb_z_zzzi_s"},
      {"11010x1"_b, "sqdmlalt_z_zzzi_s"},
      {"11011x0"_b, "sqdmlslb_z_zzzi_s"},
      {"11011x1"_b, "sqdmlslt_z_zzzi_s"},
      {"1110000"_b, "sdot_z_zzzi_d"},
      {"1110001"_b, "udot_z_zzzi_d"},
      {"1110010"_b, "mla_z_zzzi_d"},
      {"1110011"_b, "mls_z_zzzi_d"},
      {"1110100"_b, "sqrdmlah_z_zzzi_d"},
      {"1110101"_b, "sqrdmlsh_z_zzzi_d"},
      {"11110x0"_b, "sqdmlalb_z_zzzi_d"},
      {"11110x1"_b, "sqdmlalt_z_zzzi_d"},
      {"11111x0"_b, "sqdmlslb_z_zzzi_d"},
      {"11111x1"_b, "sqdmlslt_z_zzzi_d"},
    },
  },

  { "_ljxhnq",
    {12},
    { {"0"_b, "ld1_asisdlsop_dx1_r1d"},
    },
  },

  { "_lkttgy",
    {10},
    { {"0"_b, "saba_z_zzz"},
      {"1"_b, "uaba_z_zzz"},
    },
  },

  { "_lkvynm",
    {22, 20, 19, 13, 12},
    { {"0x100"_b, "ushr_asisdshf_r"},
      {"0x101"_b, "usra_asisdshf_r"},
      {"0x110"_b, "urshr_asisdshf_r"},
      {"0x111"_b, "ursra_asisdshf_r"},
      {"10x00"_b, "ushr_asisdshf_r"},
      {"10x01"_b, "usra_asisdshf_r"},
      {"10x10"_b, "urshr_asisdshf_r"},
      {"10x11"_b, "ursra_asisdshf_r"},
      {"11100"_b, "ushr_asisdshf_r"},
      {"11101"_b, "usra_asisdshf_r"},
      {"11110"_b, "urshr_asisdshf_r"},
      {"11111"_b, "ursra_asisdshf_r"},
      {"x1000"_b, "ushr_asisdshf_r"},
      {"x1001"_b, "usra_asisdshf_r"},
      {"x1010"_b, "urshr_asisdshf_r"},
      {"x1011"_b, "ursra_asisdshf_r"},
    },
  },

  { "_lkxgjy",
    {23, 22},
    { {"10"_b, "cmla_z_zzzi_h"},
      {"11"_b, "cmla_z_zzzi_s"},
    },
  },

  { "_llnzlv",
    {20, 19, 18, 17, 16},
    { {"00000"_b, "sqneg_asisdmisc_r"},
    },
  },

  { "_llpsqq",
    {13, 12, 10},
    { {"001"_b, "_zjjxjl"},
      {"100"_b, "ptrues_p_s"},
      {"110"_b, "_njngkk"},
    },
  },

  { "_llqjlh",
    {10},
    { {"0"_b, "_lhtyjq"},
    },
  },

  { "_llvrrk",
    {23, 18, 17, 16},
    { {"0000"_b, "sqxtnb_z_zz"},
    },
  },

  { "_llxlqz",
    {20, 19, 18, 17, 16},
    { {"00000"_b, "cmge_asisdmisc_z"},
    },
  },

  { "_lmtnzv",
    {12},
    { {"0"_b, "st2_asisdlsop_dx2_r2d"},
    },
  },

  { "_lmyxhr",
    {9, 4},
    { {"00"_b, "_gnqhsl"},
    },
  },

  { "_lnjpjs",
    {18, 17},
    { {"0x"_b, "ld3_asisdlsop_sx3_r3s"},
      {"10"_b, "ld3_asisdlsop_sx3_r3s"},
      {"11"_b, "ld3_asisdlsop_s3_i3s"},
    },
  },

  { "_lnkqjp",
    {18, 17, 12},
    { {"000"_b, "ld3_asisdlso_d3_3d"},
    },
  },

  { "_lnnyzt",
    {23, 22},
    { {"01"_b, "fmax_asimdsamefp16_only"},
      {"11"_b, "fmin_asimdsamefp16_only"},
    },
  },

  { "_lnpvky",
    {23, 22, 19, 13, 12},
    { {"00100"_b, "sha1h_ss_cryptosha2"},
      {"00101"_b, "sha1su1_vv_cryptosha2"},
      {"00110"_b, "sha256su0_vv_cryptosha2"},
      {"xx011"_b, "suqadd_asisdmisc_r"},
    },
  },

  { "_lpkqzl",
    {30, 23, 22, 12, 11, 10},
    { {"0000xx"_b, "adds_64s_addsub_ext"},
      {"000100"_b, "adds_64s_addsub_ext"},
      {"1000xx"_b, "subs_64s_addsub_ext"},
      {"100100"_b, "subs_64s_addsub_ext"},
    },
  },

  { "_lpslrz",
    {4, 3, 2, 1, 0},
    { {"00000"_b, "fcmp_s_floatcmp"},
      {"01000"_b, "fcmp_sz_floatcmp"},
      {"10000"_b, "fcmpe_s_floatcmp"},
      {"11000"_b, "fcmpe_sz_floatcmp"},
    },
  },

  { "_lpsvyy",
    {30, 13},
    { {"00"_b, "_jlrrlt"},
      {"01"_b, "_jrlynj"},
      {"10"_b, "fmla_z_p_zzz"},
      {"11"_b, "fmls_z_p_zzz"},
    },
  },

  { "_lpsxhz",
    {22, 20, 19, 18, 17, 16, 13, 12},
    { {"01111101"_b, "ld64b_64l_memop"},
    },
  },

  { "_lqmksm",
    {30, 23, 22, 20, 13, 4},
    { {"00001x"_b, "ld1row_z_p_bi_u32"},
      {"000x0x"_b, "ld1row_z_p_br_contiguous"},
      {"01001x"_b, "ld1rod_z_p_bi_u64"},
      {"010x0x"_b, "ld1rod_z_p_br_contiguous"},
      {"110x00"_b, "str_p_bi"},
    },
  },

  { "_lqnvvj",
    {22, 13, 12},
    { {"000"_b, "swp_32_memop"},
      {"100"_b, "swpl_32_memop"},
    },
  },

  { "_lrjyhr",
    {23, 22, 20, 19, 13, 11},
    { {"0000x0"_b, "bic_asimdimm_l_hl"},
      {"00x100"_b, "uqshrn_asimdshf_n"},
      {"00x101"_b, "uqrshrn_asimdshf_n"},
      {"010x00"_b, "uqshrn_asimdshf_n"},
      {"010x01"_b, "uqrshrn_asimdshf_n"},
      {"011100"_b, "uqshrn_asimdshf_n"},
      {"011101"_b, "uqrshrn_asimdshf_n"},
      {"0x1000"_b, "uqshrn_asimdshf_n"},
      {"0x1001"_b, "uqrshrn_asimdshf_n"},
    },
  },

  { "_lrntmz",
    {13, 12, 11, 10},
    { {"0000"_b, "saddlb_z_zz"},
      {"0001"_b, "saddlt_z_zz"},
      {"0010"_b, "uaddlb_z_zz"},
      {"0011"_b, "uaddlt_z_zz"},
      {"0100"_b, "ssublb_z_zz"},
      {"0101"_b, "ssublt_z_zz"},
      {"0110"_b, "usublb_z_zz"},
      {"0111"_b, "usublt_z_zz"},
      {"1100"_b, "sabdlb_z_zz"},
      {"1101"_b, "sabdlt_z_zz"},
      {"1110"_b, "uabdlb_z_zz"},
      {"1111"_b, "uabdlt_z_zz"},
    },
  },

  { "_lrqkvp",
    {30, 23, 22, 13, 12, 11, 10},
    { {"0000000"_b, "ldadd_32_memop"},
      {"0000100"_b, "ldclr_32_memop"},
      {"0001000"_b, "ldeor_32_memop"},
      {"0001100"_b, "ldset_32_memop"},
      {"000xx10"_b, "str_32_ldst_regoff"},
      {"0010000"_b, "ldaddl_32_memop"},
      {"0010100"_b, "ldclrl_32_memop"},
      {"0011000"_b, "ldeorl_32_memop"},
      {"0011100"_b, "ldsetl_32_memop"},
      {"001xx10"_b, "ldr_32_ldst_regoff"},
      {"0100000"_b, "ldadda_32_memop"},
      {"0100100"_b, "ldclra_32_memop"},
      {"0101000"_b, "ldeora_32_memop"},
      {"0101100"_b, "ldseta_32_memop"},
      {"010xx10"_b, "ldrsw_64_ldst_regoff"},
      {"0110000"_b, "ldaddal_32_memop"},
      {"0110100"_b, "ldclral_32_memop"},
      {"0111000"_b, "ldeoral_32_memop"},
      {"0111100"_b, "ldsetal_32_memop"},
      {"1000000"_b, "ldadd_64_memop"},
      {"1000100"_b, "ldclr_64_memop"},
      {"1001000"_b, "ldeor_64_memop"},
      {"1001100"_b, "ldset_64_memop"},
      {"100xx10"_b, "str_64_ldst_regoff"},
      {"1010000"_b, "ldaddl_64_memop"},
      {"1010100"_b, "ldclrl_64_memop"},
      {"1011000"_b, "ldeorl_64_memop"},
      {"1011100"_b, "ldsetl_64_memop"},
      {"101xx10"_b, "ldr_64_ldst_regoff"},
      {"10xxx01"_b, "ldraa_64_ldst_pac"},
      {"10xxx11"_b, "ldraa_64w_ldst_pac"},
      {"1100000"_b, "ldadda_64_memop"},
      {"1100100"_b, "ldclra_64_memop"},
      {"1101000"_b, "ldeora_64_memop"},
      {"1101100"_b, "ldseta_64_memop"},
      {"110xx10"_b, "prfm_p_ldst_regoff"},
      {"1110000"_b, "ldaddal_64_memop"},
      {"1110100"_b, "ldclral_64_memop"},
      {"1111000"_b, "ldeoral_64_memop"},
      {"1111100"_b, "ldsetal_64_memop"},
      {"11xxx01"_b, "ldrab_64_ldst_pac"},
      {"11xxx11"_b, "ldrab_64w_ldst_pac"},
    },
  },

  { "_lspzrv",
    {30, 23, 13},
    { {"000"_b, "ld1sb_z_p_bz_s_x32_unscaled"},
      {"001"_b, "ldff1sb_z_p_bz_s_x32_unscaled"},
      {"010"_b, "ld1sh_z_p_bz_s_x32_unscaled"},
      {"011"_b, "ldff1sh_z_p_bz_s_x32_unscaled"},
      {"100"_b, "ld1sb_z_p_bz_d_x32_unscaled"},
      {"101"_b, "ldff1sb_z_p_bz_d_x32_unscaled"},
      {"110"_b, "ld1sh_z_p_bz_d_x32_unscaled"},
      {"111"_b, "ldff1sh_z_p_bz_d_x32_unscaled"},
    },
  },

  { "_ltvrrg",
    {30},
    { {"0"_b, "bl_only_branch_imm"},
      {"1"_b, "_htmthz"},
    },
  },

  { "_lvshqt",
    {23, 22},
    { {"00"_b, "_qtkpxg"},
    },
  },

  { "_lxgltj",
    {30, 23, 22},
    { {"000"_b, "stlxr_sr32_ldstexcl"},
      {"001"_b, "ldaxr_lr32_ldstexcl"},
      {"010"_b, "stlr_sl32_ldstexcl"},
      {"011"_b, "ldar_lr32_ldstexcl"},
      {"100"_b, "stlxr_sr64_ldstexcl"},
      {"101"_b, "ldaxr_lr64_ldstexcl"},
      {"110"_b, "stlr_sl64_ldstexcl"},
      {"111"_b, "ldar_lr64_ldstexcl"},
    },
  },

  { "_lxhlkx",
    {12, 11, 10},
    { {"000"_b, "ftmad_z_zzi"},
    },
  },

  { "_lxmyjh",
    {30, 23, 11, 10},
    { {"0000"_b, "_lqnvvj"},
      {"0010"_b, "_tmthqm"},
      {"0100"_b, "_rxjrmn"},
      {"0110"_b, "_ypqgyp"},
      {"1000"_b, "_zpsymj"},
      {"1001"_b, "ldraa_64_ldst_pac"},
      {"1010"_b, "_rsyzrs"},
      {"1011"_b, "ldraa_64w_ldst_pac"},
      {"1100"_b, "_nrrmtx"},
      {"1101"_b, "ldrab_64_ldst_pac"},
      {"1110"_b, "_tgqsyg"},
      {"1111"_b, "ldrab_64w_ldst_pac"},
    },
  },

  { "_lxqynh",
    {23, 22, 19, 18, 17, 16},
    { {"0000x1"_b, "dup_asimdins_dr_r"},
      {"000x10"_b, "dup_asimdins_dr_r"},
      {"0010xx"_b, "dup_asimdins_dr_r"},
      {"001110"_b, "dup_asimdins_dr_r"},
      {"00x10x"_b, "dup_asimdins_dr_r"},
      {"00x111"_b, "dup_asimdins_dr_r"},
      {"01xxxx"_b, "fmla_asimdsamefp16_only"},
      {"11xxxx"_b, "fmls_asimdsamefp16_only"},
    },
  },

  { "_lxvnxm",
    {23, 22, 12},
    { {"100"_b, "fmlsl2_asimdelem_lh"},
      {"xx1"_b, "sqrdmlah_asimdelem_r"},
    },
  },

  { "_lyghyg",
    {20, 18, 17},
    { {"000"_b, "_hxmjhn"},
    },
  },

  { "_lylpyx",
    {10},
    { {"0"_b, "sabalb_z_zzz"},
      {"1"_b, "sabalt_z_zzz"},
    },
  },

  { "_lynsgm",
    {13},
    { {"0"_b, "_ttplgp"},
    },
  },

  { "_lytkrx",
    {12, 11, 10},
    { {"000"_b, "dup_z_zi"},
      {"010"_b, "tbl_z_zz_2"},
      {"011"_b, "tbx_z_zz"},
      {"100"_b, "tbl_z_zz_1"},
      {"110"_b, "_ylnsvy"},
    },
  },

  { "_lyzxhr",
    {23, 22, 20, 19, 18, 17, 16, 13, 12, 11},
    { {"0011111001"_b, "_smplhv"},
    },
  },

  { "_lzpykk",
    {30, 23, 22},
    { {"000"_b, "bfm_32m_bitfield"},
    },
  },

  { "_mgmgqh",
    {17},
    { {"0"_b, "st1_asisdlsop_hx1_r1h"},
      {"1"_b, "st1_asisdlsop_h1_i1h"},
    },
  },

  { "_mgmkyq",
    {23},
    { {"0"_b, "fmaxp_asimdsame_only"},
      {"1"_b, "fminp_asimdsame_only"},
    },
  },

  { "_mgqvvn",
    {9, 8, 7, 6, 5},
    { {"11111"_b, "pacdza_64z_dp_1src"},
    },
  },

  { "_mgsvlj",
    {13, 12},
    { {"00"_b, "udiv_32_dp_2src"},
      {"10"_b, "asrv_32_dp_2src"},
    },
  },

  { "_mhrjvp",
    {30, 13},
    { {"00"_b, "_vxhgzz"},
      {"01"_b, "_lytkrx"},
      {"10"_b, "_rlyvpn"},
      {"11"_b, "_yvptvx"},
    },
  },

  { "_mjqvxq",
    {23, 22, 13, 12, 11, 10},
    { {"0001x0"_b, "fmul_asimdelem_rh_h"},
      {"0x0001"_b, "shrn_asimdshf_n"},
      {"0x0011"_b, "rshrn_asimdshf_n"},
      {"0x0101"_b, "sqshrn_asimdshf_n"},
      {"0x0111"_b, "sqrshrn_asimdshf_n"},
      {"0x1001"_b, "sshll_asimdshf_l"},
      {"1x01x0"_b, "fmul_asimdelem_r_sd"},
      {"xx00x0"_b, "mul_asimdelem_r"},
      {"xx10x0"_b, "smull_asimdelem_l"},
      {"xx11x0"_b, "sqdmull_asimdelem_l"},
    },
  },

  { "_mjxzks",
    {4},
    { {"0"_b, "ccmp_64_condcmp_reg"},
    },
  },

  { "_mkgsly",
    {19, 18, 17, 16, 4},
    { {"00000"_b, "brkas_p_p_p_z"},
      {"10000"_b, "brkns_p_p_pp"},
    },
  },

  { "_mkklrm",
    {18, 17},
    { {"00"_b, "ld3_asisdlso_s3_3s"},
    },
  },

  { "_mkskxj",
    {30, 23, 22, 13},
    { {"0000"_b, "ld1sh_z_p_br_s32"},
      {"0001"_b, "ldff1sh_z_p_br_s32"},
      {"0010"_b, "ld1w_z_p_br_u64"},
      {"0011"_b, "ldff1w_z_p_br_u64"},
      {"0100"_b, "ld1sb_z_p_br_s32"},
      {"0101"_b, "ldff1sb_z_p_br_s32"},
      {"0110"_b, "ld1d_z_p_br_u64"},
      {"0111"_b, "ldff1d_z_p_br_u64"},
      {"1001"_b, "st2w_z_p_br_contiguous"},
      {"1011"_b, "st4w_z_p_br_contiguous"},
      {"10x0"_b, "st1w_z_p_br"},
      {"1100"_b, "str_z_bi"},
      {"1101"_b, "st2d_z_p_br_contiguous"},
      {"1110"_b, "st1d_z_p_br"},
      {"1111"_b, "st4d_z_p_br_contiguous"},
    },
  },

  { "_mlnqrm",
    {30},
    { {"0"_b, "_nhzrqr"},
      {"1"_b, "_zpmkvt"},
    },
  },

  { "_mlvpxh",
    {12},
    { {"0"_b, "ld2_asisdlsop_dx2_r2d"},
    },
  },

  { "_mlxtxs",
    {10},
    { {"0"_b, "ssra_z_zi"},
      {"1"_b, "usra_z_zi"},
    },
  },

  { "_mlyynz",
    {12},
    { {"0"_b, "st3_asisdlsop_dx3_r3d"},
    },
  },

  { "_mmhkmp",
    {18, 17},
    { {"0x"_b, "ld1_asisdlsop_sx1_r1s"},
      {"10"_b, "ld1_asisdlsop_sx1_r1s"},
      {"11"_b, "ld1_asisdlsop_s1_i1s"},
    },
  },

  { "_mmknzp",
    {20, 19, 18, 17, 16},
    { {"00000"_b, "clz_asimdmisc_r"},
      {"00001"_b, "uqxtn_asimdmisc_n"},
    },
  },

  { "_mmmjkx",
    {20, 19, 18, 17, 16, 13, 12},
    { {"0000000"_b, "rev_32_dp_1src"},
    },
  },

  { "_mmrtvz",
    {12},
    { {"0"_b, "st4_asisdlsop_dx4_r4d"},
    },
  },

  { "_mnmtql",
    {10},
    { {"0"_b, "srsra_z_zi"},
      {"1"_b, "ursra_z_zi"},
    },
  },

  { "_mnxmst",
    {23, 22, 20, 19, 18, 17, 16},
    { {"0111001"_b, "fcvtns_asimdmiscfp16_r"},
      {"0x00001"_b, "fcvtns_asimdmisc_r"},
      {"1111001"_b, "fcvtps_asimdmiscfp16_r"},
      {"1x00001"_b, "fcvtps_asimdmisc_r"},
      {"xx00000"_b, "cmlt_asimdmisc_z"},
      {"xx10000"_b, "smaxv_asimdall_only"},
      {"xx10001"_b, "sminv_asimdall_only"},
    },
  },

  { "_mpgrgp",
    {30, 22, 13, 12, 11, 10},
    { {"000001"_b, "rmif_only_rmif"},
      {"01xx00"_b, "ccmn_64_condcmp_reg"},
      {"01xx10"_b, "ccmn_64_condcmp_imm"},
      {"11xx00"_b, "ccmp_64_condcmp_reg"},
      {"11xx10"_b, "ccmp_64_condcmp_imm"},
    },
  },

  { "_mplgqv",
    {11, 10},
    { {"00"_b, "sm3tt1a_vvv4_crypto3_imm2"},
      {"01"_b, "sm3tt1b_vvv4_crypto3_imm2"},
      {"10"_b, "sm3tt2a_vvv4_crypto3_imm2"},
      {"11"_b, "sm3tt2b_vvv_crypto3_imm2"},
    },
  },

  { "_mplskr",
    {13, 12},
    { {"00"_b, "add_asisdsame_only"},
      {"11"_b, "sqdmulh_asisdsame_only"},
    },
  },

  { "_mpstrr",
    {23, 22, 8, 7, 6, 5, 4, 3, 2, 1, 0},
    { {"00000000000"_b, "setffr_f"},
    },
  },

  { "_mpvsng",
    {30},
    { {"0"_b, "_vvtnrv"},
      {"1"_b, "_yykhjv"},
    },
  },

  { "_mpyhkm",
    {30, 23, 22, 13, 12, 11, 10},
    { {"000xxxx"_b, "fnmsub_s_floatdp3"},
      {"001xxxx"_b, "fnmsub_d_floatdp3"},
      {"011xxxx"_b, "fnmsub_h_floatdp3"},
      {"10x1001"_b, "scvtf_asisdshf_c"},
      {"10x1111"_b, "fcvtzs_asisdshf_c"},
      {"1xx00x0"_b, "sqdmulh_asisdelem_r"},
      {"1xx01x0"_b, "sqrdmulh_asisdelem_r"},
    },
  },

  { "_mpyklp",
    {23, 22, 20, 19, 16, 13, 10},
    { {"0000000"_b, "_jqjnrv"},
      {"0000001"_b, "_yqmqzp"},
      {"0000010"_b, "_hgxqpp"},
      {"0000011"_b, "_rvzhhx"},
      {"0100000"_b, "_nnllqy"},
      {"0100001"_b, "_vhmsgj"},
      {"0100010"_b, "_mkklrm"},
      {"0100011"_b, "_lnkqjp"},
      {"100xx00"_b, "st1_asisdlsop_sx1_r1s"},
      {"100xx01"_b, "_yxmkzr"},
      {"100xx10"_b, "st3_asisdlsop_sx3_r3s"},
      {"100xx11"_b, "_mlyynz"},
      {"1010x00"_b, "st1_asisdlsop_sx1_r1s"},
      {"1010x01"_b, "_jnjlsh"},
      {"1010x10"_b, "st3_asisdlsop_sx3_r3s"},
      {"1010x11"_b, "_svrnxq"},
      {"1011000"_b, "st1_asisdlsop_sx1_r1s"},
      {"1011001"_b, "_hjqtrt"},
      {"1011010"_b, "st3_asisdlsop_sx3_r3s"},
      {"1011011"_b, "_vqlytp"},
      {"1011100"_b, "_qqpqnm"},
      {"1011101"_b, "_thvvzp"},
      {"1011110"_b, "_srglgl"},
      {"1011111"_b, "_qzrjss"},
      {"110xx00"_b, "ld1_asisdlsop_sx1_r1s"},
      {"110xx01"_b, "_ljxhnq"},
      {"110xx10"_b, "ld3_asisdlsop_sx3_r3s"},
      {"110xx11"_b, "_nkrqgn"},
      {"1110x00"_b, "ld1_asisdlsop_sx1_r1s"},
      {"1110x01"_b, "_vmplgv"},
      {"1110x10"_b, "ld3_asisdlsop_sx3_r3s"},
      {"1110x11"_b, "_gsttpm"},
      {"1111000"_b, "ld1_asisdlsop_sx1_r1s"},
      {"1111001"_b, "_xmqvpl"},
      {"1111010"_b, "ld3_asisdlsop_sx3_r3s"},
      {"1111011"_b, "_stqmps"},
      {"1111100"_b, "_mmhkmp"},
      {"1111101"_b, "_srvnql"},
      {"1111110"_b, "_lnjpjs"},
      {"1111111"_b, "_kstltt"},
    },
  },

  { "_mpzqxm",
    {23, 22, 20, 19, 18, 16, 13},
    { {"0000000"_b, "_vpkhvh"},
      {"0000001"_b, "_gttglx"},
      {"0100000"_b, "_gsgzpg"},
      {"0100001"_b, "_ynqsgl"},
      {"100xxx0"_b, "st2_asisdlsop_hx2_r2h"},
      {"100xxx1"_b, "st4_asisdlsop_hx4_r4h"},
      {"1010xx0"_b, "st2_asisdlsop_hx2_r2h"},
      {"1010xx1"_b, "st4_asisdlsop_hx4_r4h"},
      {"10110x0"_b, "st2_asisdlsop_hx2_r2h"},
      {"10110x1"_b, "st4_asisdlsop_hx4_r4h"},
      {"1011100"_b, "st2_asisdlsop_hx2_r2h"},
      {"1011101"_b, "st4_asisdlsop_hx4_r4h"},
      {"1011110"_b, "_sjsltg"},
      {"1011111"_b, "_xrpmzt"},
      {"110xxx0"_b, "ld2_asisdlsop_hx2_r2h"},
      {"110xxx1"_b, "ld4_asisdlsop_hx4_r4h"},
      {"1110xx0"_b, "ld2_asisdlsop_hx2_r2h"},
      {"1110xx1"_b, "ld4_asisdlsop_hx4_r4h"},
      {"11110x0"_b, "ld2_asisdlsop_hx2_r2h"},
      {"11110x1"_b, "ld4_asisdlsop_hx4_r4h"},
      {"1111100"_b, "ld2_asisdlsop_hx2_r2h"},
      {"1111101"_b, "ld4_asisdlsop_hx4_r4h"},
      {"1111110"_b, "_gygnsz"},
      {"1111111"_b, "_kxkyqr"},
    },
  },

  { "_mqgtsq",
    {30, 23, 22, 19},
    { {"1001"_b, "aesd_b_cryptoaes"},
      {"xxx0"_b, "cnt_asimdmisc_r"},
    },
  },

  { "_mqkjxj",
    {30},
    { {"0"_b, "bl_only_branch_imm"},
      {"1"_b, "_lyzxhr"},
    },
  },

  { "_mqrzzk",
    {22, 20, 11},
    { {"000"_b, "sqincw_z_zs"},
      {"001"_b, "sqdecw_z_zs"},
      {"010"_b, "incw_z_zs"},
      {"100"_b, "sqincd_z_zs"},
      {"101"_b, "sqdecd_z_zs"},
      {"110"_b, "incd_z_zs"},
    },
  },

  { "_mrhtxt",
    {23, 22, 20, 9},
    { {"0000"_b, "brkpb_p_p_pp"},
      {"0100"_b, "brkpbs_p_p_pp"},
    },
  },

  { "_mrkkps",
    {17},
    { {"0"_b, "ld1_asisdlsop_hx1_r1h"},
      {"1"_b, "ld1_asisdlsop_h1_i1h"},
    },
  },

  { "_mrmpgh",
    {30, 23, 22, 13, 12, 11, 10},
    { {"000xxxx"_b, "stlxp_sp32_ldstexcl"},
      {"001xxxx"_b, "ldaxp_lp32_ldstexcl"},
      {"0101111"_b, "casl_c32_ldstexcl"},
      {"0111111"_b, "casal_c32_ldstexcl"},
      {"100xxxx"_b, "stlxp_sp64_ldstexcl"},
      {"101xxxx"_b, "ldaxp_lp64_ldstexcl"},
      {"1101111"_b, "casl_c64_ldstexcl"},
      {"1111111"_b, "casal_c64_ldstexcl"},
    },
  },

  { "_mrqqlp",
    {30, 11, 10},
    { {"000"_b, "_gqykqv"},
      {"001"_b, "_xgvgmk"},
      {"010"_b, "_tjpjng"},
      {"011"_b, "_pjkylt"},
      {"101"_b, "_yrgnqz"},
      {"110"_b, "_hhymvj"},
      {"111"_b, "_xpmvjv"},
    },
  },

  { "_msgqps",
    {18, 17},
    { {"0x"_b, "ld2_asisdlsop_sx2_r2s"},
      {"10"_b, "ld2_asisdlsop_sx2_r2s"},
      {"11"_b, "ld2_asisdlsop_s2_i2s"},
    },
  },

  { "_msnsjp",
    {23, 20, 19, 18, 17, 16},
    { {"000001"_b, "fcvtxn_asisdmisc_n"},
    },
  },

  { "_msqkyy",
    {16, 13, 12},
    { {"000"_b, "rbit_64_dp_1src"},
      {"001"_b, "clz_64_dp_1src"},
      {"100"_b, "pacia_64p_dp_1src"},
      {"101"_b, "autia_64p_dp_1src"},
      {"110"_b, "_sqgxzn"},
      {"111"_b, "_kqkhtz"},
    },
  },

  { "_mstthg",
    {13, 12, 11, 10},
    { {"0000"_b, "umull_asimddiff_l"},
      {"0001"_b, "_qptvrm"},
      {"0010"_b, "_qqzrhz"},
      {"0011"_b, "_yxhrpk"},
      {"0101"_b, "_vsqpzr"},
      {"0110"_b, "_kjrxpx"},
      {"0111"_b, "_qnvgmh"},
      {"1001"_b, "_jvhnxl"},
      {"1010"_b, "_zyzzhm"},
      {"1011"_b, "_slhpgp"},
      {"1101"_b, "_mgmkyq"},
      {"1110"_b, "_qvlytr"},
      {"1111"_b, "_qtmjkr"},
    },
  },

  { "_msztzv",
    {23, 11, 10, 4, 3, 2, 1},
    { {"0000000"_b, "_vvprhx"},
      {"0101111"_b, "_nqysxy"},
      {"0111111"_b, "_kkmjyr"},
      {"1000000"_b, "_ypjyqh"},
    },
  },

  { "_mtgksl",
    {23, 22, 20, 19, 18, 16, 13},
    { {"0000000"_b, "_vnrnmg"},
      {"0000001"_b, "_hzllgl"},
      {"0100000"_b, "_hrhzqy"},
      {"0100001"_b, "_qtjzhs"},
      {"100xxx0"_b, "st4_asisdlsep_r4_r"},
      {"100xxx1"_b, "st1_asisdlsep_r4_r4"},
      {"1010xx0"_b, "st4_asisdlsep_r4_r"},
      {"1010xx1"_b, "st1_asisdlsep_r4_r4"},
      {"10110x0"_b, "st4_asisdlsep_r4_r"},
      {"10110x1"_b, "st1_asisdlsep_r4_r4"},
      {"1011100"_b, "st4_asisdlsep_r4_r"},
      {"1011101"_b, "st1_asisdlsep_r4_r4"},
      {"1011110"_b, "_nzkhrj"},
      {"1011111"_b, "_gmjhll"},
      {"110xxx0"_b, "ld4_asisdlsep_r4_r"},
      {"110xxx1"_b, "ld1_asisdlsep_r4_r4"},
      {"1110xx0"_b, "ld4_asisdlsep_r4_r"},
      {"1110xx1"_b, "ld1_asisdlsep_r4_r4"},
      {"11110x0"_b, "ld4_asisdlsep_r4_r"},
      {"11110x1"_b, "ld1_asisdlsep_r4_r4"},
      {"1111100"_b, "ld4_asisdlsep_r4_r"},
      {"1111101"_b, "ld1_asisdlsep_r4_r4"},
      {"1111110"_b, "_hxglyp"},
      {"1111111"_b, "_jmyslr"},
    },
  },

  { "_mthzvm",
    {30, 23, 13, 12, 11, 10},
    { {"100001"_b, "ushr_asisdshf_r"},
      {"100101"_b, "usra_asisdshf_r"},
      {"101001"_b, "urshr_asisdshf_r"},
      {"101101"_b, "ursra_asisdshf_r"},
    },
  },

  { "_mtjrtt",
    {13, 12},
    { {"00"_b, "subps_64s_dp_2src"},
    },
  },

  { "_mtlhnl",
    {23, 22, 20, 19, 13, 11},
    { {"0000x0"_b, "movi_asimdimm_l_sl"},
      {"00x100"_b, "sshr_asimdshf_r"},
      {"00x110"_b, "srshr_asimdshf_r"},
      {"010x00"_b, "sshr_asimdshf_r"},
      {"010x10"_b, "srshr_asimdshf_r"},
      {"011100"_b, "sshr_asimdshf_r"},
      {"011110"_b, "srshr_asimdshf_r"},
      {"0x1000"_b, "sshr_asimdshf_r"},
      {"0x1010"_b, "srshr_asimdshf_r"},
    },
  },

  { "_mtnpmr",
    {13, 12, 11, 10},
    { {"0000"_b, "smull_asimddiff_l"},
      {"0001"_b, "_ypznsm"},
      {"0010"_b, "_sgztlj"},
      {"0011"_b, "_nsnyxt"},
      {"0100"_b, "sqdmull_asimddiff_l"},
      {"0101"_b, "_plltlx"},
      {"0110"_b, "_qtystr"},
      {"0111"_b, "_gymljg"},
      {"1000"_b, "pmull_asimddiff_l"},
      {"1001"_b, "_rpmrkq"},
      {"1010"_b, "_hvvyhl"},
      {"1011"_b, "_hlshjk"},
      {"1101"_b, "_gmvjgn"},
      {"1110"_b, "_rsyjqj"},
      {"1111"_b, "_yvlhjg"},
    },
  },

  { "_mtzgpn",
    {30},
    { {"0"_b, "cbz_32_compbranch"},
    },
  },

  { "_mvglql",
    {23, 22, 20, 19, 13, 11},
    { {"0000x0"_b, "mvni_asimdimm_l_hl"},
      {"00x100"_b, "sqshrun_asimdshf_n"},
      {"00x101"_b, "sqrshrun_asimdshf_n"},
      {"00x110"_b, "ushll_asimdshf_l"},
      {"010x00"_b, "sqshrun_asimdshf_n"},
      {"010x01"_b, "sqrshrun_asimdshf_n"},
      {"010x10"_b, "ushll_asimdshf_l"},
      {"011100"_b, "sqshrun_asimdshf_n"},
      {"011101"_b, "sqrshrun_asimdshf_n"},
      {"011110"_b, "ushll_asimdshf_l"},
      {"0x1000"_b, "sqshrun_asimdshf_n"},
      {"0x1001"_b, "sqrshrun_asimdshf_n"},
      {"0x1010"_b, "ushll_asimdshf_l"},
    },
  },

  { "_mvgsjr",
    {20, 19, 18, 17, 16},
    { {"00000"_b, "usqadd_asimdmisc_r"},
      {"00001"_b, "shll_asimdmisc_s"},
      {"10000"_b, "uaddlv_asimdall_only"},
    },
  },

  { "_mvzvpk",
    {30},
    { {"0"_b, "orn_64_log_shift"},
      {"1"_b, "bics_64_log_shift"},
    },
  },

  { "_mxgykv",
    {19, 18, 17, 16},
    { {"0000"_b, "cntp_r_p_p"},
      {"1000"_b, "_lynsgm"},
      {"1001"_b, "_jxyskn"},
      {"1010"_b, "_jmxstz"},
      {"1011"_b, "_yjzknm"},
      {"1100"_b, "_zmtkvx"},
      {"1101"_b, "_yhmlxk"},
    },
  },

  { "_mxkgnq",
    {23, 22, 20, 19, 11},
    { {"00010"_b, "scvtf_asisdshf_c"},
      {"001x0"_b, "scvtf_asisdshf_c"},
      {"01xx0"_b, "scvtf_asisdshf_c"},
    },
  },

  { "_mxnzyr",
    {19, 16},
    { {"00"_b, "_nhxxmh"},
      {"10"_b, "_qgymsy"},
      {"11"_b, "_gjprmg"},
    },
  },

  { "_mxtskk",
    {20, 19, 18, 17, 16, 13},
    { {"000000"_b, "fmov_h_floatdp1"},
      {"000010"_b, "fneg_h_floatdp1"},
      {"000100"_b, "fcvt_sh_floatdp1"},
      {"001000"_b, "frintn_h_floatdp1"},
      {"001010"_b, "frintm_h_floatdp1"},
      {"001100"_b, "frinta_h_floatdp1"},
      {"001110"_b, "frintx_h_floatdp1"},
    },
  },

  { "_mxvjxx",
    {20, 19, 18, 16},
    { {"0000"_b, "_nshjhk"},
    },
  },

  { "_myjqrl",
    {22, 20, 19, 18, 17, 16},
    { {"111000"_b, "fcmge_asisdmiscfp16_fz"},
      {"x00000"_b, "fcmge_asisdmisc_fz"},
      {"x10000"_b, "fminnmp_asisdpair_only_sd"},
    },
  },

  { "_mykjss",
    {17},
    { {"0"_b, "st2_asisdlsop_bx2_r2b"},
      {"1"_b, "st2_asisdlsop_b2_i2b"},
    },
  },

  { "_mylphg",
    {30, 13, 4},
    { {"000"_b, "cmpge_p_p_zw"},
      {"001"_b, "cmpgt_p_p_zw"},
      {"010"_b, "cmplt_p_p_zw"},
      {"011"_b, "cmple_p_p_zw"},
      {"1xx"_b, "fcmla_z_p_zzz"},
    },
  },

  { "_myrshl",
    {4},
    { {"0"_b, "ccmn_32_condcmp_imm"},
    },
  },

  { "_myxhpq",
    {12},
    { {"0"_b, "udot_asimdelem_d"},
      {"1"_b, "sqrdmlsh_asimdelem_r"},
    },
  },

  { "_mzhsrq",
    {4},
    { {"0"_b, "cmplt_p_p_zi"},
      {"1"_b, "cmple_p_p_zi"},
    },
  },

  { "_mzqzhq",
    {23, 22, 20, 19, 11},
    { {"00000"_b, "mvni_asimdimm_m_sm"},
    },
  },

  { "_mzynlp",
    {23, 22, 13},
    { {"100"_b, "fmlal2_asimdelem_lh"},
      {"xx1"_b, "umull_asimdelem_l"},
    },
  },

  { "_ngttyj",
    {30, 23, 22, 13},
    { {"0000"_b, "ld1b_z_p_br_u16"},
      {"0001"_b, "ldff1b_z_p_br_u16"},
      {"0010"_b, "ld1b_z_p_br_u64"},
      {"0011"_b, "ldff1b_z_p_br_u64"},
      {"0100"_b, "ld1h_z_p_br_u16"},
      {"0101"_b, "ldff1h_z_p_br_u16"},
      {"0110"_b, "ld1h_z_p_br_u64"},
      {"0111"_b, "ldff1h_z_p_br_u64"},
      {"1001"_b, "st2b_z_p_br_contiguous"},
      {"1011"_b, "st4b_z_p_br_contiguous"},
      {"10x0"_b, "st1b_z_p_br"},
      {"1101"_b, "st2h_z_p_br_contiguous"},
      {"1111"_b, "st4h_z_p_br_contiguous"},
      {"11x0"_b, "st1h_z_p_br"},
    },
  },

  { "_ngxkmp",
    {18, 17},
    { {"0x"_b, "st3_asisdlsep_r3_r"},
      {"10"_b, "st3_asisdlsep_r3_r"},
      {"11"_b, "st3_asisdlsep_i3_i"},
    },
  },

  { "_ngzyqj",
    {11, 10},
    { {"00"_b, "asr_z_zi"},
      {"01"_b, "lsr_z_zi"},
      {"11"_b, "lsl_z_zi"},
    },
  },

  { "_nhhpqz",
    {23, 22, 13, 12},
    { {"0000"_b, "fmul_s_floatdp2"},
      {"0001"_b, "fdiv_s_floatdp2"},
      {"0010"_b, "fadd_s_floatdp2"},
      {"0011"_b, "fsub_s_floatdp2"},
      {"0100"_b, "fmul_d_floatdp2"},
      {"0101"_b, "fdiv_d_floatdp2"},
      {"0110"_b, "fadd_d_floatdp2"},
      {"0111"_b, "fsub_d_floatdp2"},
      {"1100"_b, "fmul_h_floatdp2"},
      {"1101"_b, "fdiv_h_floatdp2"},
      {"1110"_b, "fadd_h_floatdp2"},
      {"1111"_b, "fsub_h_floatdp2"},
    },
  },

  { "_nhkstj",
    {30, 23, 22},
    { {"00x"_b, "add_64_addsub_shift"},
      {"010"_b, "add_64_addsub_shift"},
      {"10x"_b, "sub_64_addsub_shift"},
      {"110"_b, "sub_64_addsub_shift"},
    },
  },

  { "_nhxxmh",
    {23, 22, 9, 3, 2, 1, 0},
    { {"0100000"_b, "ptest_p_p"},
    },
  },

  { "_nhzrqr",
    {23, 22},
    { {"00"_b, "fmadd_s_floatdp3"},
      {"01"_b, "fmadd_d_floatdp3"},
      {"11"_b, "fmadd_h_floatdp3"},
    },
  },

  { "_nhzyvv",
    {23, 22, 4, 3, 2, 1, 0},
    { {"0000000"_b, "brk_ex_exception"},
      {"0100000"_b, "tcancel_ex_exception"},
      {"1000001"_b, "dcps1_dc_exception"},
      {"1000010"_b, "dcps2_dc_exception"},
      {"1000011"_b, "dcps3_dc_exception"},
    },
  },

  { "_njgmvx",
    {18, 17},
    { {"00"_b, "_rzqzlq"},
    },
  },

  { "_njgxlz",
    {30},
    { {"0"_b, "_txzxzs"},
      {"1"_b, "_vprkpq"},
    },
  },

  { "_njngkk",
    {23, 22, 9, 8, 7, 6, 5},
    { {"0000000"_b, "rdffr_p_f"},
    },
  },

  { "_njtngm",
    {13, 12, 10},
    { {"001"_b, "_qkzlkj"},
      {"010"_b, "_jvpqrp"},
      {"011"_b, "_kknjng"},
      {"101"_b, "_xmtlmj"},
      {"110"_b, "sqdmlal_asisdelem_l"},
      {"111"_b, "_zgjpym"},
    },
  },

  { "_njvkjq",
    {11, 10},
    { {"00"_b, "index_z_ii"},
      {"01"_b, "index_z_ri"},
      {"10"_b, "index_z_ir"},
      {"11"_b, "index_z_rr"},
    },
  },

  { "_njxtpv",
    {30, 23, 22, 11, 10, 4},
    { {"001000"_b, "ccmn_32_condcmp_reg"},
      {"001100"_b, "ccmn_32_condcmp_imm"},
      {"101000"_b, "ccmp_32_condcmp_reg"},
      {"101100"_b, "ccmp_32_condcmp_imm"},
    },
  },

  { "_nkjgpq",
    {23, 20, 19, 18, 17, 16, 13},
    { {"0000000"_b, "ld1r_asisdlso_r1"},
      {"0000001"_b, "ld3r_asisdlso_r3"},
      {"10xxxx0"_b, "ld1r_asisdlsop_rx1_r"},
      {"10xxxx1"_b, "ld3r_asisdlsop_rx3_r"},
      {"110xxx0"_b, "ld1r_asisdlsop_rx1_r"},
      {"110xxx1"_b, "ld3r_asisdlsop_rx3_r"},
      {"1110xx0"_b, "ld1r_asisdlsop_rx1_r"},
      {"1110xx1"_b, "ld3r_asisdlsop_rx3_r"},
      {"11110x0"_b, "ld1r_asisdlsop_rx1_r"},
      {"11110x1"_b, "ld3r_asisdlsop_rx3_r"},
      {"1111100"_b, "ld1r_asisdlsop_rx1_r"},
      {"1111101"_b, "ld3r_asisdlsop_rx3_r"},
      {"1111110"_b, "ld1r_asisdlsop_r1_i"},
      {"1111111"_b, "ld3r_asisdlsop_r3_i"},
    },
  },

  { "_nkrqgn",
    {12},
    { {"0"_b, "ld3_asisdlsop_dx3_r3d"},
    },
  },

  { "_nkxhsy",
    {22, 20, 11},
    { {"000"_b, "cntb_r_s"},
      {"010"_b, "incb_r_rs"},
      {"100"_b, "cnth_r_s"},
      {"110"_b, "inch_r_rs"},
    },
  },

  { "_nlgqsk",
    {30, 23, 13, 12, 11, 10},
    { {"100001"_b, "sri_asisdshf_r"},
      {"100101"_b, "sli_asisdshf_r"},
      {"101001"_b, "sqshlu_asisdshf_r"},
      {"101101"_b, "uqshl_asisdshf_r"},
    },
  },

  { "_nlkkyx",
    {23, 13, 12},
    { {"001"_b, "fmulx_asisdsame_only"},
      {"011"_b, "frecps_asisdsame_only"},
      {"111"_b, "frsqrts_asisdsame_only"},
    },
  },

  { "_nllnsg",
    {30, 23, 22, 19, 16},
    { {"10010"_b, "aesmc_b_cryptoaes"},
      {"x0x01"_b, "fcvtn_asimdmisc_n"},
      {"x1001"_b, "bfcvtn_asimdmisc_4s"},
      {"xxx00"_b, "sadalp_asimdmisc_p"},
    },
  },

  { "_nlpmvl",
    {30, 13},
    { {"00"_b, "mad_z_p_zzz"},
      {"01"_b, "msb_z_p_zzz"},
    },
  },

  { "_nlqglq",
    {13, 10},
    { {"00"_b, "_lxvnxm"},
      {"01"_b, "_mzqzhq"},
      {"10"_b, "_myxhpq"},
      {"11"_b, "_pslllp"},
    },
  },

  { "_nlyntn",
    {23, 22, 20, 19, 11},
    { {"00000"_b, "movi_asimdimm_l_sl"},
    },
  },

  { "_nmkqzt",
    {20, 19, 18, 17},
    { {"0000"_b, "_nvqlyn"},
    },
  },

  { "_nmtkjv",
    {17},
    { {"0"_b, "ld1_asisdlso_h1_1h"},
    },
  },

  { "_nmzyvt",
    {30, 23, 22, 13, 12, 11, 10},
    { {"0000000"_b, "ldsmaxb_32_memop"},
      {"0000100"_b, "ldsminb_32_memop"},
      {"0000x10"_b, "strb_32b_ldst_regoff"},
      {"0001000"_b, "ldumaxb_32_memop"},
      {"0001100"_b, "lduminb_32_memop"},
      {"0001x10"_b, "strb_32bl_ldst_regoff"},
      {"0010000"_b, "ldsmaxlb_32_memop"},
      {"0010100"_b, "ldsminlb_32_memop"},
      {"0010x10"_b, "ldrb_32b_ldst_regoff"},
      {"0011000"_b, "ldumaxlb_32_memop"},
      {"0011100"_b, "lduminlb_32_memop"},
      {"0011x10"_b, "ldrb_32bl_ldst_regoff"},
      {"0100000"_b, "ldsmaxab_32_memop"},
      {"0100100"_b, "ldsminab_32_memop"},
      {"0100x10"_b, "ldrsb_64b_ldst_regoff"},
      {"0101000"_b, "ldumaxab_32_memop"},
      {"0101100"_b, "lduminab_32_memop"},
      {"0101x10"_b, "ldrsb_64bl_ldst_regoff"},
      {"0110000"_b, "ldsmaxalb_32_memop"},
      {"0110100"_b, "ldsminalb_32_memop"},
      {"0110x10"_b, "ldrsb_32b_ldst_regoff"},
      {"0111000"_b, "ldumaxalb_32_memop"},
      {"0111100"_b, "lduminalb_32_memop"},
      {"0111x10"_b, "ldrsb_32bl_ldst_regoff"},
      {"1000000"_b, "ldsmaxh_32_memop"},
      {"1000100"_b, "ldsminh_32_memop"},
      {"1001000"_b, "ldumaxh_32_memop"},
      {"1001100"_b, "lduminh_32_memop"},
      {"100xx10"_b, "strh_32_ldst_regoff"},
      {"1010000"_b, "ldsmaxlh_32_memop"},
      {"1010100"_b, "ldsminlh_32_memop"},
      {"1011000"_b, "ldumaxlh_32_memop"},
      {"1011100"_b, "lduminlh_32_memop"},
      {"101xx10"_b, "ldrh_32_ldst_regoff"},
      {"1100000"_b, "ldsmaxah_32_memop"},
      {"1100100"_b, "ldsminah_32_memop"},
      {"1101000"_b, "ldumaxah_32_memop"},
      {"1101100"_b, "lduminah_32_memop"},
      {"110xx10"_b, "ldrsh_64_ldst_regoff"},
      {"1110000"_b, "ldsmaxalh_32_memop"},
      {"1110100"_b, "ldsminalh_32_memop"},
      {"1111000"_b, "ldumaxalh_32_memop"},
      {"1111100"_b, "lduminalh_32_memop"},
      {"111xx10"_b, "ldrsh_32_ldst_regoff"},
    },
  },

  { "_nnhprs",
    {1, 0},
    { {"00"_b, "ret_64r_branch_reg"},
    },
  },

  { "_nnkxgr",
    {11, 10},
    { {"00"_b, "ftssel_z_zz"},
      {"10"_b, "_yhlntp"},
      {"11"_b, "_rsqmgk"},
    },
  },

  { "_nnkyzr",
    {18, 17, 16},
    { {"011"_b, "_yvgqjx"},
    },
  },

  { "_nnllqy",
    {18, 17},
    { {"00"_b, "ld1_asisdlso_s1_1s"},
    },
  },

  { "_nnlvqz",
    {9, 8, 7, 6, 5},
    { {"00000"_b, "fmov_d_floatimm"},
    },
  },

  { "_nnzhgm",
    {19, 18, 17, 16, 4},
    { {"0000x"_b, "brka_p_p_p"},
      {"10000"_b, "brkn_p_p_pp"},
    },
  },

  { "_nqgqjh",
    {30, 23, 22, 20, 19},
    { {"0xxxx"_b, "bl_only_branch_imm"},
      {"10001"_b, "sys_cr_systeminstrs"},
      {"1001x"_b, "msr_sr_systemmove"},
    },
  },

  { "_nqkhrv",
    {30, 13},
    { {"10"_b, "fnmla_z_p_zzz"},
      {"11"_b, "fnmls_z_p_zzz"},
    },
  },

  { "_nqlgtn",
    {23, 20, 19, 18, 17, 16, 13},
    { {"0000000"_b, "ld2r_asisdlso_r2"},
      {"0000001"_b, "ld4r_asisdlso_r4"},
      {"10xxxx0"_b, "ld2r_asisdlsop_rx2_r"},
      {"10xxxx1"_b, "ld4r_asisdlsop_rx4_r"},
      {"110xxx0"_b, "ld2r_asisdlsop_rx2_r"},
      {"110xxx1"_b, "ld4r_asisdlsop_rx4_r"},
      {"1110xx0"_b, "ld2r_asisdlsop_rx2_r"},
      {"1110xx1"_b, "ld4r_asisdlsop_rx4_r"},
      {"11110x0"_b, "ld2r_asisdlsop_rx2_r"},
      {"11110x1"_b, "ld4r_asisdlsop_rx4_r"},
      {"1111100"_b, "ld2r_asisdlsop_rx2_r"},
      {"1111101"_b, "ld4r_asisdlsop_rx4_r"},
      {"1111110"_b, "ld2r_asisdlsop_r2_i"},
      {"1111111"_b, "ld4r_asisdlsop_r4_i"},
    },
  },

  { "_nqysxy",
    {0},
    { {"1"_b, "blraaz_64_branch_reg"},
    },
  },

  { "_nrrmtx",
    {22, 13, 12},
    { {"000"_b, "swpa_64_memop"},
      {"100"_b, "swpal_64_memop"},
    },
  },

  { "_nrssjz",
    {17},
    { {"0"_b, "ld3_asisdlso_b3_3b"},
    },
  },

  { "_nshjhk",
    {17, 9, 8, 7, 6, 5},
    { {"000000"_b, "aesimc_z_z"},
      {"1xxxxx"_b, "aesd_z_zz"},
    },
  },

  { "_nsjhhg",
    {30, 13},
    { {"00"_b, "_jhllmn"},
      {"01"_b, "_htplsj"},
      {"10"_b, "_rztvnl"},
      {"11"_b, "_vgtnjh"},
    },
  },

  { "_nsnyxt",
    {23},
    { {"0"_b, "fmla_asimdsame_only"},
      {"1"_b, "fmls_asimdsame_only"},
    },
  },

  { "_nssrnm",
    {20, 18, 17, 16},
    { {"0000"_b, "_lnpvky"},
    },
  },

  { "_nszhhy",
    {17},
    { {"0"_b, "ld2_asisdlsep_r2_r"},
      {"1"_b, "ld2_asisdlsep_i2_i"},
    },
  },

  { "_nthvqx",
    {23, 22},
    { {"00"_b, "eor_asimdsame_only"},
      {"01"_b, "bsl_asimdsame_only"},
      {"10"_b, "bit_asimdsame_only"},
      {"11"_b, "bif_asimdsame_only"},
    },
  },

  { "_ntjpsx",
    {22, 20, 11},
    { {"000"_b, "uqincb_r_rs_uw"},
      {"001"_b, "uqdecb_r_rs_uw"},
      {"010"_b, "uqincb_r_rs_x"},
      {"011"_b, "uqdecb_r_rs_x"},
      {"100"_b, "uqinch_r_rs_uw"},
      {"101"_b, "uqdech_r_rs_uw"},
      {"110"_b, "uqinch_r_rs_x"},
      {"111"_b, "uqdech_r_rs_x"},
    },
  },

  { "_ntkhsm",
    {13, 12},
    { {"00"_b, "cmtst_asisdsame_only"},
    },
  },

  { "_ntkqhk",
    {11, 10, 9, 8, 7, 6},
    { {"000000"_b, "yield_hi_hints"},
      {"000001"_b, "wfi_hi_hints"},
      {"000010"_b, "sevl_hi_hints"},
      {"000011"_b, "xpaclri_hi_hints"},
      {"001000"_b, "psb_hc_hints"},
      {"0010x1"_b, "hint_hm_hints"},
      {"001100"_b, "paciasp_hi_hints"},
      {"001101"_b, "pacibsp_hi_hints"},
      {"001110"_b, "autiasp_hi_hints"},
      {"001111"_b, "autibsp_hi_hints"},
      {"0x01xx"_b, "hint_hm_hints"},
      {"0x1010"_b, "hint_hm_hints"},
      {"10x0xx"_b, "hint_hm_hints"},
      {"10x1xx"_b, "hint_hm_hints"},
      {"1101xx"_b, "hint_hm_hints"},
      {"111010"_b, "hint_hm_hints"},
      {"x100xx"_b, "hint_hm_hints"},
      {"x1100x"_b, "hint_hm_hints"},
      {"x11011"_b, "hint_hm_hints"},
      {"x111xx"_b, "hint_hm_hints"},
    },
  },

  { "_nvkthr",
    {30, 13},
    { {"00"_b, "_kjqynn"},
      {"01"_b, "_jgyhrh"},
      {"10"_b, "_jymnkk"},
      {"11"_b, "_pqjjsh"},
    },
  },

  { "_nvqlyn",
    {16, 13, 12},
    { {"000"_b, "rev_64_dp_1src"},
      {"100"_b, "pacdb_64p_dp_1src"},
      {"101"_b, "autdb_64p_dp_1src"},
      {"110"_b, "_hhnjjk"},
      {"111"_b, "_yvnjkr"},
    },
  },

  { "_nvthzh",
    {20, 19, 18, 17, 16, 13, 12, 9, 8, 7, 6, 5},
    { {"000010011111"_b, "xpacd_64z_dp_1src"},
    },
  },

  { "_nvyxmh",
    {20, 19, 18, 17, 16},
    { {"00000"_b, "add_z_p_zz"},
      {"00001"_b, "sub_z_p_zz"},
      {"00011"_b, "subr_z_p_zz"},
      {"01000"_b, "smax_z_p_zz"},
      {"01001"_b, "umax_z_p_zz"},
      {"01010"_b, "smin_z_p_zz"},
      {"01011"_b, "umin_z_p_zz"},
      {"01100"_b, "sabd_z_p_zz"},
      {"01101"_b, "uabd_z_p_zz"},
      {"10000"_b, "mul_z_p_zz"},
      {"10010"_b, "smulh_z_p_zz"},
      {"10011"_b, "umulh_z_p_zz"},
      {"10100"_b, "sdiv_z_p_zz"},
      {"10101"_b, "udiv_z_p_zz"},
      {"10110"_b, "sdivr_z_p_zz"},
      {"10111"_b, "udivr_z_p_zz"},
      {"11000"_b, "orr_z_p_zz"},
      {"11001"_b, "eor_z_p_zz"},
      {"11010"_b, "and_z_p_zz"},
      {"11011"_b, "bic_z_p_zz"},
    },
  },

  { "_nxjgmm",
    {17},
    { {"0"_b, "st3_asisdlsop_bx3_r3b"},
      {"1"_b, "st3_asisdlsop_b3_i3b"},
    },
  },

  { "_nxjkqs",
    {23, 22, 12, 11, 10},
    { {"0x000"_b, "fmla_z_zzzi_h"},
      {"0x001"_b, "fmls_z_zzzi_h"},
      {"10000"_b, "fmla_z_zzzi_s"},
      {"10001"_b, "fmls_z_zzzi_s"},
      {"101xx"_b, "fcmla_z_zzzi_h"},
      {"11000"_b, "fmla_z_zzzi_d"},
      {"11001"_b, "fmls_z_zzzi_d"},
      {"111xx"_b, "fcmla_z_zzzi_s"},
    },
  },

  { "_nxmjvy",
    {30, 23, 11, 10},
    { {"1001"_b, "_jksztq"},
    },
  },

  { "_nxqygl",
    {13},
    { {"0"_b, "mla_asimdelem_r"},
      {"1"_b, "umlal_asimdelem_l"},
    },
  },

  { "_nxyhyv",
    {30, 11, 10},
    { {"000"_b, "_kvyysq"},
      {"001"_b, "_rvjzgt"},
      {"010"_b, "_vjlnqj"},
      {"011"_b, "_jvvzjq"},
      {"100"_b, "_tzzhsk"},
      {"101"_b, "_mplskr"},
      {"110"_b, "_njgmvx"},
      {"111"_b, "_ntkhsm"},
    },
  },

  { "_nykvly",
    {16, 13, 12},
    { {"000"_b, "rev32_64_dp_1src"},
      {"100"_b, "pacda_64p_dp_1src"},
      {"101"_b, "autda_64p_dp_1src"},
      {"110"_b, "_mgqvvn"},
      {"111"_b, "_xvlnmy"},
    },
  },

  { "_nyssqn",
    {12},
    { {"0"_b, "st2_asisdlsop_dx2_r2d"},
    },
  },

  { "_nyxxks",
    {20, 19, 18, 17, 16},
    { {"00000"_b, "suqadd_asimdmisc_r"},
      {"10000"_b, "saddlv_asimdall_only"},
    },
  },

  { "_nzkhrj",
    {17},
    { {"0"_b, "st4_asisdlsep_r4_r"},
      {"1"_b, "st4_asisdlsep_i4_i"},
    },
  },

  { "_nzqkky",
    {20, 19, 18, 17, 16},
    { {"00000"_b, "rev32_asimdmisc_r"},
    },
  },

  { "_pgjjsz",
    {30, 13, 12, 11, 10},
    { {"00000"_b, "_lmyxhr"},
      {"00001"_b, "_tmhlvh"},
      {"00010"_b, "_qvtxpr"},
      {"00011"_b, "_ymkthj"},
      {"00100"_b, "_rhmxyp"},
      {"00101"_b, "_zryvjk"},
      {"01000"_b, "zip1_z_zz"},
      {"01001"_b, "zip2_z_zz"},
      {"01010"_b, "uzp1_z_zz"},
      {"01011"_b, "uzp2_z_zz"},
      {"01100"_b, "trn1_z_zz"},
      {"01101"_b, "trn2_z_zz"},
      {"10000"_b, "_llvrrk"},
      {"10001"_b, "_qyjvqr"},
      {"10010"_b, "_tmtnkq"},
      {"10011"_b, "_gpxltv"},
      {"10100"_b, "_pnlnzt"},
      {"10101"_b, "_pygvrr"},
      {"11000"_b, "addhnb_z_zz"},
      {"11001"_b, "addhnt_z_zz"},
      {"11010"_b, "raddhnb_z_zz"},
      {"11011"_b, "raddhnt_z_zz"},
      {"11100"_b, "subhnb_z_zz"},
      {"11101"_b, "subhnt_z_zz"},
      {"11110"_b, "rsubhnb_z_zz"},
      {"11111"_b, "rsubhnt_z_zz"},
    },
  },

  { "_phthqj",
    {30, 13},
    { {"00"_b, "_sntyqy"},
      {"01"_b, "_xhlhmh"},
      {"10"_b, "_rtrlts"},
      {"11"_b, "_jzkqhn"},
    },
  },

  { "_phtnny",
    {18, 17},
    { {"0x"_b, "ld1_asisdlsep_r3_r3"},
      {"10"_b, "ld1_asisdlsep_r3_r3"},
      {"11"_b, "ld1_asisdlsep_i3_i3"},
    },
  },

  { "_phvnqh",
    {30},
    { {"0"_b, "bic_32_log_shift"},
      {"1"_b, "eon_32_log_shift"},
    },
  },

  { "_phxkzh",
    {17, 4},
    { {"00"_b, "fcmlt_p_p_z0"},
      {"01"_b, "fcmle_p_p_z0"},
      {"10"_b, "fcmne_p_p_z0"},
    },
  },

  { "_pjgkjs",
    {18, 17},
    { {"00"_b, "_mxnzyr"},
    },
  },

  { "_pjkylt",
    {23, 22},
    { {"00"_b, "fcsel_s_floatsel"},
      {"01"_b, "fcsel_d_floatsel"},
      {"11"_b, "fcsel_h_floatsel"},
    },
  },

  { "_plktrh",
    {30, 23},
    { {"00"_b, "adds_32s_addsub_imm"},
      {"10"_b, "subs_32s_addsub_imm"},
    },
  },

  { "_plltlx",
    {23},
    { {"0"_b, "fadd_asimdsame_only"},
      {"1"_b, "fsub_asimdsame_only"},
    },
  },

  { "_pmkxlj",
    {17},
    { {"0"_b, "st1_asisdlse_r2_2v"},
    },
  },

  { "_pmrngh",
    {30},
    { {"0"_b, "bl_only_branch_imm"},
      {"1"_b, "_snkqvp"},
    },
  },

  { "_pnlnzt",
    {23, 18, 17, 16},
    { {"0000"_b, "sqxtunb_z_zz"},
    },
  },

  { "_pnqxjg",
    {4},
    { {"0"_b, "ccmn_32_condcmp_reg"},
    },
  },

  { "_pnxggm",
    {4, 3, 2, 1, 0},
    { {"00000"_b, "fcmp_d_floatcmp"},
      {"01000"_b, "fcmp_dz_floatcmp"},
      {"10000"_b, "fcmpe_d_floatcmp"},
      {"11000"_b, "fcmpe_dz_floatcmp"},
    },
  },

  { "_pnxgrg",
    {30, 23, 22},
    { {"000"_b, "madd_32a_dp_3src"},
    },
  },

  { "_pnzphx",
    {17},
    { {"1"_b, "frecpe_z_z"},
    },
  },

  { "_pphhym",
    {30, 23, 22},
    { {"00x"_b, "add_32_addsub_shift"},
      {"010"_b, "add_32_addsub_shift"},
      {"10x"_b, "sub_32_addsub_shift"},
      {"110"_b, "sub_32_addsub_shift"},
    },
  },

  { "_ppllxt",
    {18, 17},
    { {"00"_b, "ld1_asisdlse_r3_3v"},
    },
  },

  { "_ppnssm",
    {30, 13, 12},
    { {"000"_b, "_ktyppm"},
      {"001"_b, "_ngzyqj"},
      {"010"_b, "_yxnslx"},
      {"011"_b, "_nnkxgr"},
      {"100"_b, "_kzmvpk"},
      {"101"_b, "_thrxph"},
      {"110"_b, "_kgpgly"},
      {"111"_b, "_yppszx"},
    },
  },

  { "_pppsmg",
    {30},
    { {"0"_b, "_xyhmgh"},
      {"1"_b, "_rlrjxp"},
    },
  },

  { "_ppqkym",
    {30, 23, 22, 11, 10},
    { {"10001"_b, "stg_64spost_ldsttags"},
      {"10010"_b, "stg_64soffset_ldsttags"},
      {"10011"_b, "stg_64spre_ldsttags"},
      {"10100"_b, "ldg_64loffset_ldsttags"},
      {"10101"_b, "stzg_64spost_ldsttags"},
      {"10110"_b, "stzg_64soffset_ldsttags"},
      {"10111"_b, "stzg_64spre_ldsttags"},
      {"11001"_b, "st2g_64spost_ldsttags"},
      {"11010"_b, "st2g_64soffset_ldsttags"},
      {"11011"_b, "st2g_64spre_ldsttags"},
      {"11101"_b, "stz2g_64spost_ldsttags"},
      {"11110"_b, "stz2g_64soffset_ldsttags"},
      {"11111"_b, "stz2g_64spre_ldsttags"},
    },
  },

  { "_pqjjsh",
    {23, 22, 12, 10},
    { {"1000"_b, "fmlslb_z_zzzi_s"},
      {"1001"_b, "fmlslt_z_zzzi_s"},
    },
  },

  { "_pqpzkt",
    {11, 10, 9, 8, 7, 6},
    { {"000000"_b, "nop_hi_hints"},
      {"000001"_b, "wfe_hi_hints"},
      {"000010"_b, "sev_hi_hints"},
      {"000011"_b, "dgh_hi_hints"},
      {"000100"_b, "pacia1716_hi_hints"},
      {"000101"_b, "pacib1716_hi_hints"},
      {"000110"_b, "autia1716_hi_hints"},
      {"000111"_b, "autib1716_hi_hints"},
      {"001000"_b, "esb_hi_hints"},
      {"001001"_b, "tsb_hc_hints"},
      {"001010"_b, "csdb_hi_hints"},
      {"001100"_b, "paciaz_hi_hints"},
      {"001101"_b, "pacibz_hi_hints"},
      {"001110"_b, "autiaz_hi_hints"},
      {"001111"_b, "autibz_hi_hints"},
      {"0100xx"_b, "bti_hb_hints"},
      {"0x1011"_b, "hint_hm_hints"},
      {"10x0xx"_b, "hint_hm_hints"},
      {"10x1xx"_b, "hint_hm_hints"},
      {"1100xx"_b, "hint_hm_hints"},
      {"111011"_b, "hint_hm_hints"},
      {"x1100x"_b, "hint_hm_hints"},
      {"x11010"_b, "hint_hm_hints"},
      {"x1x1xx"_b, "hint_hm_hints"},
    },
  },

  { "_pqtjgx",
    {23, 22, 13, 12, 11, 10},
    { {"01x1x0"_b, "fcmla_asimdelem_c_h"},
      {"0x0001"_b, "sri_asimdshf_r"},
      {"0x0101"_b, "sli_asimdshf_r"},
      {"0x1001"_b, "sqshlu_asimdshf_r"},
      {"0x1101"_b, "uqshl_asimdshf_r"},
      {"10x1x0"_b, "fcmla_asimdelem_c_s"},
      {"xx00x0"_b, "mls_asimdelem_r"},
      {"xx10x0"_b, "umlsl_asimdelem_l"},
    },
  },

  { "_prkmty",
    {23, 22, 9},
    { {"000"_b, "brkpa_p_p_pp"},
      {"010"_b, "brkpas_p_p_pp"},
    },
  },

  { "_pslllp",
    {30, 23, 22, 20, 19, 12, 11},
    { {"0000000"_b, "movi_asimdimm_d_ds"},
      {"1000000"_b, "movi_asimdimm_d2_d"},
      {"1000010"_b, "fmov_asimdimm_d2_d"},
      {"x00x100"_b, "ucvtf_asimdshf_c"},
      {"x00x111"_b, "fcvtzu_asimdshf_c"},
      {"x010x00"_b, "ucvtf_asimdshf_c"},
      {"x010x11"_b, "fcvtzu_asimdshf_c"},
      {"x011100"_b, "ucvtf_asimdshf_c"},
      {"x011111"_b, "fcvtzu_asimdshf_c"},
      {"x0x1000"_b, "ucvtf_asimdshf_c"},
      {"x0x1011"_b, "fcvtzu_asimdshf_c"},
    },
  },

  { "_psqpkp",
    {17, 4},
    { {"00"_b, "fcmge_p_p_z0"},
      {"01"_b, "fcmgt_p_p_z0"},
      {"10"_b, "fcmeq_p_p_z0"},
    },
  },

  { "_ptjyqx",
    {13},
    { {"0"_b, "fcmuo_p_p_zz"},
    },
  },

  { "_ptkrvg",
    {12},
    { {"0"_b, "ld2_asisdlsop_dx2_r2d"},
    },
  },

  { "_ptsjnr",
    {30, 20, 19, 18, 17, 16, 13},
    { {"0000000"_b, "asr_z_p_zi"},
      {"0000010"_b, "lsr_z_p_zi"},
      {"0000110"_b, "lsl_z_p_zi"},
      {"0001000"_b, "asrd_z_p_zi"},
      {"0001100"_b, "sqshl_z_p_zi"},
      {"0001110"_b, "uqshl_z_p_zi"},
      {"0011000"_b, "srshr_z_p_zi"},
      {"0011010"_b, "urshr_z_p_zi"},
      {"0011110"_b, "sqshlu_z_p_zi"},
      {"0100000"_b, "asr_z_p_zz"},
      {"0100001"_b, "sxtb_z_p_z"},
      {"0100010"_b, "lsr_z_p_zz"},
      {"0100011"_b, "uxtb_z_p_z"},
      {"0100101"_b, "sxth_z_p_z"},
      {"0100110"_b, "lsl_z_p_zz"},
      {"0100111"_b, "uxth_z_p_z"},
      {"0101000"_b, "asrr_z_p_zz"},
      {"0101001"_b, "sxtw_z_p_z"},
      {"0101010"_b, "lsrr_z_p_zz"},
      {"0101011"_b, "uxtw_z_p_z"},
      {"0101101"_b, "abs_z_p_z"},
      {"0101110"_b, "lslr_z_p_zz"},
      {"0101111"_b, "neg_z_p_z"},
      {"0110000"_b, "asr_z_p_zw"},
      {"0110001"_b, "cls_z_p_z"},
      {"0110010"_b, "lsr_z_p_zw"},
      {"0110011"_b, "clz_z_p_z"},
      {"0110101"_b, "cnt_z_p_z"},
      {"0110110"_b, "lsl_z_p_zw"},
      {"0110111"_b, "cnot_z_p_z"},
      {"0111001"_b, "fabs_z_p_z"},
      {"0111011"_b, "fneg_z_p_z"},
      {"0111101"_b, "not_z_p_z"},
      {"1000001"_b, "urecpe_z_p_z"},
      {"1000011"_b, "ursqrte_z_p_z"},
      {"1000100"_b, "srshl_z_p_zz"},
      {"1000110"_b, "urshl_z_p_zz"},
      {"1001001"_b, "sadalp_z_p_z"},
      {"1001011"_b, "uadalp_z_p_z"},
      {"1001100"_b, "srshlr_z_p_zz"},
      {"1001110"_b, "urshlr_z_p_zz"},
      {"1010000"_b, "sqshl_z_p_zz"},
      {"1010001"_b, "sqabs_z_p_z"},
      {"1010010"_b, "uqshl_z_p_zz"},
      {"1010011"_b, "sqneg_z_p_z"},
      {"1010100"_b, "sqrshl_z_p_zz"},
      {"1010110"_b, "uqrshl_z_p_zz"},
      {"1011000"_b, "sqshlr_z_p_zz"},
      {"1011010"_b, "uqshlr_z_p_zz"},
      {"1011100"_b, "sqrshlr_z_p_zz"},
      {"1011110"_b, "uqrshlr_z_p_zz"},
      {"1100000"_b, "shadd_z_p_zz"},
      {"1100010"_b, "uhadd_z_p_zz"},
      {"1100011"_b, "addp_z_p_zz"},
      {"1100100"_b, "shsub_z_p_zz"},
      {"1100110"_b, "uhsub_z_p_zz"},
      {"1101000"_b, "srhadd_z_p_zz"},
      {"1101001"_b, "smaxp_z_p_zz"},
      {"1101010"_b, "urhadd_z_p_zz"},
      {"1101011"_b, "umaxp_z_p_zz"},
      {"1101100"_b, "shsubr_z_p_zz"},
      {"1101101"_b, "sminp_z_p_zz"},
      {"1101110"_b, "uhsubr_z_p_zz"},
      {"1101111"_b, "uminp_z_p_zz"},
      {"1110000"_b, "sqadd_z_p_zz"},
      {"1110010"_b, "uqadd_z_p_zz"},
      {"1110100"_b, "sqsub_z_p_zz"},
      {"1110110"_b, "uqsub_z_p_zz"},
      {"1111000"_b, "suqadd_z_p_zz"},
      {"1111010"_b, "usqadd_z_p_zz"},
      {"1111100"_b, "sqsubr_z_p_zz"},
      {"1111110"_b, "uqsubr_z_p_zz"},
    },
  },

  { "_ptslzg",
    {30, 23, 22, 13, 4},
    { {"01000"_b, "ldr_p_bi"},
      {"01100"_b, "prfb_i_p_bi_s"},
      {"01110"_b, "prfh_i_p_bi_s"},
      {"10x0x"_b, "ld1sw_z_p_bz_d_x32_scaled"},
      {"10x1x"_b, "ldff1sw_z_p_bz_d_x32_scaled"},
    },
  },

  { "_pvkmmv",
    {30, 23, 22, 13, 12, 11, 10},
    { {"0000000"_b, "ldsmax_32_memop"},
      {"0000100"_b, "ldsmin_32_memop"},
      {"0001000"_b, "ldumax_32_memop"},
      {"0001100"_b, "ldumin_32_memop"},
      {"000xx10"_b, "str_32_ldst_regoff"},
      {"0010000"_b, "ldsmaxl_32_memop"},
      {"0010100"_b, "ldsminl_32_memop"},
      {"0011000"_b, "ldumaxl_32_memop"},
      {"0011100"_b, "lduminl_32_memop"},
      {"001xx10"_b, "ldr_32_ldst_regoff"},
      {"0100000"_b, "ldsmaxa_32_memop"},
      {"0100100"_b, "ldsmina_32_memop"},
      {"0101000"_b, "ldumaxa_32_memop"},
      {"0101100"_b, "ldumina_32_memop"},
      {"010xx10"_b, "ldrsw_64_ldst_regoff"},
      {"0110000"_b, "ldsmaxal_32_memop"},
      {"0110100"_b, "ldsminal_32_memop"},
      {"0111000"_b, "ldumaxal_32_memop"},
      {"0111100"_b, "lduminal_32_memop"},
      {"1000000"_b, "ldsmax_64_memop"},
      {"1000100"_b, "ldsmin_64_memop"},
      {"1001000"_b, "ldumax_64_memop"},
      {"1001100"_b, "ldumin_64_memop"},
      {"100xx10"_b, "str_64_ldst_regoff"},
      {"1010000"_b, "ldsmaxl_64_memop"},
      {"1010100"_b, "ldsminl_64_memop"},
      {"1011000"_b, "ldumaxl_64_memop"},
      {"1011100"_b, "lduminl_64_memop"},
      {"101xx10"_b, "ldr_64_ldst_regoff"},
      {"10xxx01"_b, "ldraa_64_ldst_pac"},
      {"10xxx11"_b, "ldraa_64w_ldst_pac"},
      {"1100000"_b, "ldsmaxa_64_memop"},
      {"1100100"_b, "ldsmina_64_memop"},
      {"1101000"_b, "ldumaxa_64_memop"},
      {"1101100"_b, "ldumina_64_memop"},
      {"110xx10"_b, "prfm_p_ldst_regoff"},
      {"1110000"_b, "ldsmaxal_64_memop"},
      {"1110100"_b, "ldsminal_64_memop"},
      {"1111000"_b, "ldumaxal_64_memop"},
      {"1111100"_b, "lduminal_64_memop"},
      {"11xxx01"_b, "ldrab_64_ldst_pac"},
      {"11xxx11"_b, "ldrab_64w_ldst_pac"},
    },
  },

  { "_pvrylp",
    {13, 12},
    { {"00"_b, "sbc_64_addsub_carry"},
    },
  },

  { "_pxgztg",
    {23, 22, 20, 19, 13, 11},
    { {"0000x0"_b, "bic_asimdimm_l_sl"},
      {"00x100"_b, "sli_asimdshf_r"},
      {"00x110"_b, "uqshl_asimdshf_r"},
      {"010x00"_b, "sli_asimdshf_r"},
      {"010x10"_b, "uqshl_asimdshf_r"},
      {"011100"_b, "sli_asimdshf_r"},
      {"011110"_b, "uqshl_asimdshf_r"},
      {"0x1000"_b, "sli_asimdshf_r"},
      {"0x1010"_b, "uqshl_asimdshf_r"},
    },
  },

  { "_pxkqxn",
    {20, 19, 18, 17, 16},
    { {"00000"_b, "cmle_asisdmisc_z"},
    },
  },

  { "_pxlnhs",
    {23, 20, 19, 18, 17, 16},
    { {"000001"_b, "fcvtxn_asimdmisc_n"},
      {"x00000"_b, "uadalp_asimdmisc_p"},
    },
  },

  { "_pxnnrz",
    {20, 19, 18, 17, 16, 13, 12, 3, 2, 1, 0},
    { {"00000001101"_b, "setf16_only_setf"},
    },
  },

  { "_pxtsvn",
    {20, 19, 18, 17, 16},
    { {"10000"_b, "fminp_asisdpair_only_sd"},
    },
  },

  { "_pxyrpm",
    {22, 11},
    { {"00"_b, "sqdmulh_z_zzi_s"},
      {"01"_b, "mul_z_zzi_s"},
      {"10"_b, "sqdmulh_z_zzi_d"},
      {"11"_b, "mul_z_zzi_d"},
    },
  },

  { "_pxzkjy",
    {30},
    { {"1"_b, "_yplktv"},
    },
  },

  { "_pygvrr",
    {23, 18, 17, 16},
    { {"0000"_b, "sqxtunt_z_zz"},
    },
  },

  { "_qghmks",
    {13, 12},
    { {"00"_b, "subp_64s_dp_2src"},
      {"01"_b, "irg_64i_dp_2src"},
      {"10"_b, "lslv_64_dp_2src"},
      {"11"_b, "pacga_64p_dp_2src"},
    },
  },

  { "_qgmngg",
    {30, 23},
    { {"00"_b, "orr_64_log_imm"},
      {"10"_b, "ands_64s_log_imm"},
      {"11"_b, "movk_64_movewide"},
    },
  },

  { "_qgryzh",
    {18, 17},
    { {"0x"_b, "st1_asisdlsep_r3_r3"},
      {"10"_b, "st1_asisdlsep_r3_r3"},
      {"11"_b, "st1_asisdlsep_i3_i3"},
    },
  },

  { "_qgymsy",
    {11},
    { {"0"_b, "_hmsgpj"},
    },
  },

  { "_qhgtvk",
    {30, 23, 22},
    { {"00x"_b, "adds_32_addsub_shift"},
      {"010"_b, "adds_32_addsub_shift"},
      {"10x"_b, "subs_32_addsub_shift"},
      {"110"_b, "subs_32_addsub_shift"},
    },
  },

  { "_qhsplz",
    {23, 22, 20, 19, 18, 17, 16},
    { {"0111001"_b, "frintn_asimdmiscfp16_r"},
      {"0x00001"_b, "frintn_asimdmisc_r"},
      {"1111001"_b, "frintp_asimdmiscfp16_r"},
      {"1x00001"_b, "frintp_asimdmisc_r"},
      {"xx00000"_b, "cmgt_asimdmisc_z"},
    },
  },

  { "_qhtqrj",
    {30, 23, 22},
    { {"000"_b, "stnp_s_ldstnapair_offs"},
      {"001"_b, "ldnp_s_ldstnapair_offs"},
      {"010"_b, "stp_s_ldstpair_post"},
      {"011"_b, "ldp_s_ldstpair_post"},
      {"100"_b, "stnp_d_ldstnapair_offs"},
      {"101"_b, "ldnp_d_ldstnapair_offs"},
      {"110"_b, "stp_d_ldstpair_post"},
      {"111"_b, "ldp_d_ldstpair_post"},
    },
  },

  { "_qhtrnn",
    {30, 23, 22, 11, 10},
    { {"00000"_b, "stur_32_ldst_unscaled"},
      {"00001"_b, "str_32_ldst_immpost"},
      {"00010"_b, "sttr_32_ldst_unpriv"},
      {"00011"_b, "str_32_ldst_immpre"},
      {"00100"_b, "ldur_32_ldst_unscaled"},
      {"00101"_b, "ldr_32_ldst_immpost"},
      {"00110"_b, "ldtr_32_ldst_unpriv"},
      {"00111"_b, "ldr_32_ldst_immpre"},
      {"01000"_b, "ldursw_64_ldst_unscaled"},
      {"01001"_b, "ldrsw_64_ldst_immpost"},
      {"01010"_b, "ldtrsw_64_ldst_unpriv"},
      {"01011"_b, "ldrsw_64_ldst_immpre"},
      {"10000"_b, "stur_64_ldst_unscaled"},
      {"10001"_b, "str_64_ldst_immpost"},
      {"10010"_b, "sttr_64_ldst_unpriv"},
      {"10011"_b, "str_64_ldst_immpre"},
      {"10100"_b, "ldur_64_ldst_unscaled"},
      {"10101"_b, "ldr_64_ldst_immpost"},
      {"10110"_b, "ldtr_64_ldst_unpriv"},
      {"10111"_b, "ldr_64_ldst_immpre"},
      {"11000"_b, "prfum_p_ldst_unscaled"},
    },
  },

  { "_qhxzxl",
    {17},
    { {"0"_b, "ld1_asisdlse_r2_2v"},
    },
  },

  { "_qjyvln",
    {20, 19, 18, 17, 16, 13, 12, 9, 8, 7, 6, 5},
    { {"000010011111"_b, "xpaci_64z_dp_1src"},
    },
  },

  { "_qkyjhg",
    {30},
    { {"0"_b, "ldr_32_loadlit"},
      {"1"_b, "ldr_64_loadlit"},
    },
  },

  { "_qkzlkj",
    {23, 22, 20, 19, 11},
    { {"00010"_b, "sshr_asisdshf_r"},
      {"001x0"_b, "sshr_asisdshf_r"},
      {"01xx0"_b, "sshr_asisdshf_r"},
    },
  },

  { "_qljhnp",
    {22},
    { {"0"_b, "sqdmullt_z_zzi_s"},
      {"1"_b, "sqdmullt_z_zzi_d"},
    },
  },

  { "_qlqhzg",
    {20},
    { {"0"_b, "_hzmlps"},
      {"1"_b, "msr_sr_systemmove"},
    },
  },

  { "_qlxksl",
    {30},
    { {"0"_b, "_hrxyts"},
      {"1"_b, "_tytvjk"},
    },
  },

  { "_qmgtyq",
    {17},
    { {"0"_b, "ld2_asisdlse_r2"},
    },
  },

  { "_qmjqhq",
    {9, 8, 7, 6, 5},
    { {"00000"_b, "fmov_h_floatimm"},
    },
  },

  { "_qmqmpj",
    {12, 10},
    { {"00"_b, "_nxqygl"},
      {"01"_b, "_skglrt"},
      {"10"_b, "_sjlpxn"},
      {"11"_b, "_qzxvsk"},
    },
  },

  { "_qmrgkn",
    {30},
    { {"0"_b, "bl_only_branch_imm"},
      {"1"_b, "_hsvgnt"},
    },
  },

  { "_qmzqsy",
    {20, 19, 18, 17},
    { {"0000"_b, "_nykvly"},
    },
  },

  { "_qnprqt",
    {4},
    { {"0"_b, "eor_p_p_pp_z"},
      {"1"_b, "sel_p_p_pp"},
    },
  },

  { "_qnsxkj",
    {20, 19, 18, 17, 16, 13},
    { {"000000"_b, "fabs_d_floatdp1"},
      {"000010"_b, "fsqrt_d_floatdp1"},
      {"000110"_b, "fcvt_hd_floatdp1"},
      {"001000"_b, "frintp_d_floatdp1"},
      {"001010"_b, "frintz_d_floatdp1"},
      {"001110"_b, "frinti_d_floatdp1"},
      {"010000"_b, "frint32x_d_floatdp1"},
      {"010010"_b, "frint64x_d_floatdp1"},
    },
  },

  { "_qntssm",
    {30, 11, 10},
    { {"000"_b, "_hxrtsq"},
      {"001"_b, "_ygxhyg"},
      {"010"_b, "_nhhpqz"},
      {"011"_b, "_vjymzn"},
      {"101"_b, "_gszxkp"},
      {"110"_b, "_nssrnm"},
      {"111"_b, "_jrsptt"},
    },
  },

  { "_qntygx",
    {13, 12, 11, 10},
    { {"0000"_b, "uaddl_asimddiff_l"},
      {"0001"_b, "uhadd_asimdsame_only"},
      {"0010"_b, "_nzqkky"},
      {"0011"_b, "uqadd_asimdsame_only"},
      {"0100"_b, "uaddw_asimddiff_w"},
      {"0101"_b, "urhadd_asimdsame_only"},
      {"0111"_b, "_nthvqx"},
      {"1000"_b, "usubl_asimddiff_l"},
      {"1001"_b, "uhsub_asimdsame_only"},
      {"1010"_b, "_srmhlk"},
      {"1011"_b, "uqsub_asimdsame_only"},
      {"1100"_b, "usubw_asimddiff_w"},
      {"1101"_b, "cmhi_asimdsame_only"},
      {"1110"_b, "_mvgsjr"},
      {"1111"_b, "cmhs_asimdsame_only"},
    },
  },

  { "_qnvgmh",
    {23},
    { {"0"_b, "fmul_asimdsame_only"},
    },
  },

  { "_qptvrm",
    {23},
    { {"0"_b, "fmaxnmp_asimdsame_only"},
      {"1"_b, "fminnmp_asimdsame_only"},
    },
  },

  { "_qpvgnh",
    {30, 23, 22, 20, 13},
    { {"00001"_b, "ld2b_z_p_bi_contiguous"},
      {"000x0"_b, "ld2b_z_p_br_contiguous"},
      {"00101"_b, "ld4b_z_p_bi_contiguous"},
      {"001x0"_b, "ld4b_z_p_br_contiguous"},
      {"01001"_b, "ld2h_z_p_bi_contiguous"},
      {"010x0"_b, "ld2h_z_p_br_contiguous"},
      {"01101"_b, "ld4h_z_p_bi_contiguous"},
      {"011x0"_b, "ld4h_z_p_br_contiguous"},
      {"10011"_b, "st2b_z_p_bi_contiguous"},
      {"10111"_b, "st4b_z_p_bi_contiguous"},
      {"10x01"_b, "st1b_z_p_bi"},
      {"11011"_b, "st2h_z_p_bi_contiguous"},
      {"110x0"_b, "st1h_z_p_bz_d_x32_scaled"},
      {"11111"_b, "st4h_z_p_bi_contiguous"},
      {"111x0"_b, "st1h_z_p_bz_s_x32_scaled"},
      {"11x01"_b, "st1h_z_p_bi"},
    },
  },

  { "_qpzynz",
    {23, 22},
    { {"00"_b, "_jkpsxk"},
    },
  },

  { "_qqpkkm",
    {9, 8, 7, 6, 5, 1, 0},
    { {"1111111"_b, "eretaa_64e_branch_reg"},
    },
  },

  { "_qqpqnm",
    {18, 17},
    { {"0x"_b, "st1_asisdlsop_sx1_r1s"},
      {"10"_b, "st1_asisdlsop_sx1_r1s"},
      {"11"_b, "st1_asisdlsop_s1_i1s"},
    },
  },

  { "_qqsmlt",
    {4},
    { {"0"_b, "ccmp_32_condcmp_imm"},
    },
  },

  { "_qqtpln",
    {17},
    { {"0"_b, "ld1_asisdlsop_bx1_r1b"},
      {"1"_b, "ld1_asisdlsop_b1_i1b"},
    },
  },

  { "_qqyryl",
    {30, 23, 22, 13, 4},
    { {"00x0x"_b, "ld1w_z_p_bz_s_x32_unscaled"},
      {"00x1x"_b, "ldff1w_z_p_bz_s_x32_unscaled"},
      {"0100x"_b, "ldr_z_bi"},
      {"01100"_b, "prfw_i_p_bi_s"},
      {"01110"_b, "prfd_i_p_bi_s"},
      {"10x0x"_b, "ld1w_z_p_bz_d_x32_unscaled"},
      {"10x1x"_b, "ldff1w_z_p_bz_d_x32_unscaled"},
      {"11x0x"_b, "ld1d_z_p_bz_d_x32_unscaled"},
      {"11x1x"_b, "ldff1d_z_p_bz_d_x32_unscaled"},
    },
  },

  { "_qqzrhz",
    {23, 22, 20, 19, 18, 17, 16},
    { {"0111001"_b, "fcvtau_asimdmiscfp16_r"},
      {"0x00001"_b, "fcvtau_asimdmisc_r"},
      {"0x10000"_b, "fmaxnmv_asimdall_only_sd"},
      {"1111000"_b, "fcmge_asimdmiscfp16_fz"},
      {"1x00000"_b, "fcmge_asimdmisc_fz"},
      {"1x00001"_b, "ursqrte_asimdmisc_r"},
      {"1x10000"_b, "fminnmv_asimdall_only_sd"},
    },
  },

  { "_qrygny",
    {30, 23, 22, 20, 13},
    { {"00001"_b, "ld1b_z_p_bi_u8"},
      {"00011"_b, "ldnf1b_z_p_bi_u8"},
      {"00101"_b, "ld1b_z_p_bi_u32"},
      {"00111"_b, "ldnf1b_z_p_bi_u32"},
      {"01001"_b, "ld1sw_z_p_bi_s64"},
      {"01011"_b, "ldnf1sw_z_p_bi_s64"},
      {"01101"_b, "ld1h_z_p_bi_u32"},
      {"01111"_b, "ldnf1h_z_p_bi_u32"},
      {"100x0"_b, "st1b_z_p_bz_d_x32_unscaled"},
      {"100x1"_b, "st1b_z_p_bz_d_64_unscaled"},
      {"101x0"_b, "st1b_z_p_bz_s_x32_unscaled"},
      {"101x1"_b, "st1b_z_p_ai_d"},
      {"110x0"_b, "st1h_z_p_bz_d_x32_unscaled"},
      {"110x1"_b, "st1h_z_p_bz_d_64_unscaled"},
      {"111x0"_b, "st1h_z_p_bz_s_x32_unscaled"},
      {"111x1"_b, "st1h_z_p_ai_d"},
    },
  },

  { "_qrykhm",
    {12},
    { {"0"_b, "st4_asisdlsop_dx4_r4d"},
    },
  },

  { "_qsnqpz",
    {18, 17},
    { {"0x"_b, "ld4_asisdlsop_sx4_r4s"},
      {"10"_b, "ld4_asisdlsop_sx4_r4s"},
      {"11"_b, "ld4_asisdlsop_s4_i4s"},
    },
  },

  { "_qsqqxg",
    {30, 23, 22, 13, 12, 11, 10},
    { {"1010000"_b, "sha512h_qqv_cryptosha512_3"},
      {"1010001"_b, "sha512h2_qqv_cryptosha512_3"},
      {"1010010"_b, "sha512su1_vvv2_cryptosha512_3"},
      {"1010011"_b, "rax1_vvv2_cryptosha512_3"},
    },
  },

  { "_qsrlql",
    {30, 23, 22, 13, 12, 11, 10},
    { {"010xx00"_b, "csel_32_condsel"},
      {"010xx01"_b, "csinc_32_condsel"},
      {"0110000"_b, "crc32b_32c_dp_2src"},
      {"0110001"_b, "crc32h_32c_dp_2src"},
      {"0110010"_b, "crc32w_32c_dp_2src"},
      {"0110100"_b, "crc32cb_32c_dp_2src"},
      {"0110101"_b, "crc32ch_32c_dp_2src"},
      {"0110110"_b, "crc32cw_32c_dp_2src"},
      {"110xx00"_b, "csinv_32_condsel"},
      {"110xx01"_b, "csneg_32_condsel"},
    },
  },

  { "_qsrtzz",
    {30},
    { {"0"_b, "bl_only_branch_imm"},
      {"1"_b, "_lvshqt"},
    },
  },

  { "_qssyls",
    {20, 19, 18, 17, 16, 13, 12},
    { {"0000000"_b, "stzgm_64bulk_ldsttags"},
    },
  },

  { "_qsxpyq",
    {20, 19, 18, 17, 16, 13, 12, 4, 3, 2, 1, 0},
    { {"000000001101"_b, "setf8_only_setf"},
    },
  },

  { "_qsygjs",
    {30, 23, 22, 12, 11, 10},
    { {"0000xx"_b, "add_32_addsub_ext"},
      {"000100"_b, "add_32_addsub_ext"},
      {"1000xx"_b, "sub_32_addsub_ext"},
      {"100100"_b, "sub_32_addsub_ext"},
    },
  },

  { "_qtgvhn",
    {17},
    { {"0"_b, "ld4_asisdlsop_bx4_r4b"},
      {"1"_b, "ld4_asisdlsop_b4_i4b"},
    },
  },

  { "_qtjzhs",
    {17},
    { {"0"_b, "ld1_asisdlse_r4_4v"},
    },
  },

  { "_qtknlp",
    {30, 11, 10},
    { {"000"_b, "_skpjrp"},
      {"001"_b, "_sjnqvx"},
      {"011"_b, "_rgnxpp"},
      {"100"_b, "_rtlzxv"},
      {"101"_b, "_zvlxrl"},
      {"110"_b, "_ynnrny"},
      {"111"_b, "_nlkkyx"},
    },
  },

  { "_qtkpxg",
    {20},
    { {"0"_b, "_srggzy"},
      {"1"_b, "mrs_rs_systemmove"},
    },
  },

  { "_qtmjkr",
    {23},
    { {"0"_b, "fdiv_asimdsame_only"},
    },
  },

  { "_qtxpky",
    {4},
    { {"0"_b, "cmphs_p_p_zi"},
      {"1"_b, "cmphi_p_p_zi"},
    },
  },

  { "_qtxypt",
    {9, 8, 7, 6, 5, 1, 0},
    { {"1111111"_b, "retab_64e_branch_reg"},
    },
  },

  { "_qtystr",
    {23, 22, 20, 19, 18, 17, 16},
    { {"0111001"_b, "scvtf_asimdmiscfp16_r"},
      {"0x00001"_b, "scvtf_asimdmisc_r"},
      {"1111000"_b, "fcmeq_asimdmiscfp16_fz"},
      {"1111001"_b, "frecpe_asimdmiscfp16_r"},
      {"1x00000"_b, "fcmeq_asimdmisc_fz"},
      {"1x00001"_b, "frecpe_asimdmisc_r"},
    },
  },

  { "_qvlnll",
    {22, 20, 11},
    { {"010"_b, "decw_r_rs"},
      {"110"_b, "decd_r_rs"},
    },
  },

  { "_qvlytr",
    {23, 22, 20, 19, 18, 17, 16},
    { {"0x00001"_b, "frint64x_asimdmisc_r"},
      {"0x10000"_b, "fmaxv_asimdall_only_sd"},
      {"1111000"_b, "fneg_asimdmiscfp16_r"},
      {"1111001"_b, "fsqrt_asimdmiscfp16_r"},
      {"1x00000"_b, "fneg_asimdmisc_r"},
      {"1x00001"_b, "fsqrt_asimdmisc_r"},
      {"1x10000"_b, "fminv_asimdall_only_sd"},
    },
  },

  { "_qvsypn",
    {30, 23, 22, 20, 13},
    { {"00001"_b, "ldnt1w_z_p_bi_contiguous"},
      {"000x0"_b, "ldnt1w_z_p_br_contiguous"},
      {"00101"_b, "ld3w_z_p_bi_contiguous"},
      {"001x0"_b, "ld3w_z_p_br_contiguous"},
      {"01001"_b, "ldnt1d_z_p_bi_contiguous"},
      {"010x0"_b, "ldnt1d_z_p_br_contiguous"},
      {"01101"_b, "ld3d_z_p_bi_contiguous"},
      {"011x0"_b, "ld3d_z_p_br_contiguous"},
      {"10011"_b, "stnt1w_z_p_bi_contiguous"},
      {"100x0"_b, "st1w_z_p_bz_d_x32_unscaled"},
      {"10111"_b, "st3w_z_p_bi_contiguous"},
      {"101x0"_b, "st1w_z_p_bz_s_x32_unscaled"},
      {"10x01"_b, "st1w_z_p_bi"},
      {"11011"_b, "stnt1d_z_p_bi_contiguous"},
      {"110x0"_b, "st1d_z_p_bz_d_x32_unscaled"},
      {"11111"_b, "st3d_z_p_bi_contiguous"},
      {"11x01"_b, "st1d_z_p_bi"},
    },
  },

  { "_qvtxpr",
    {20, 9, 4},
    { {"000"_b, "uzp1_p_pp"},
    },
  },

  { "_qxrzgv",
    {17},
    { {"0"_b, "ld1_asisdlsep_r2_r2"},
      {"1"_b, "ld1_asisdlsep_i2_i2"},
    },
  },

  { "_qxtvzy",
    {13, 12, 11, 10},
    { {"0000"_b, "umlal_asimddiff_l"},
      {"0001"_b, "sub_asimdsame_only"},
      {"0010"_b, "_gznnvh"},
      {"0011"_b, "cmeq_asimdsame_only"},
      {"0101"_b, "mls_asimdsame_only"},
      {"0110"_b, "_vsqlkr"},
      {"0111"_b, "pmul_asimdsame_only"},
      {"1000"_b, "umlsl_asimddiff_l"},
      {"1001"_b, "umaxp_asimdsame_only"},
      {"1010"_b, "_gggyqx"},
      {"1011"_b, "uminp_asimdsame_only"},
      {"1101"_b, "sqrdmulh_asimdsame_only"},
      {"1110"_b, "_slnkst"},
    },
  },

  { "_qyjvqr",
    {23, 18, 17, 16},
    { {"0000"_b, "sqxtnt_z_zz"},
    },
  },

  { "_qytrjj",
    {30, 23, 22},
    { {"100"_b, "bcax_vvv16_crypto4"},
    },
  },

  { "_qzjnpr",
    {30, 23, 22, 20, 19, 18, 17, 16},
    { {"00000000"_b, "udf_only_perm_undef"},
    },
  },

  { "_qzrjss",
    {18, 17, 12},
    { {"0x0"_b, "st3_asisdlsop_dx3_r3d"},
      {"100"_b, "st3_asisdlsop_dx3_r3d"},
      {"110"_b, "st3_asisdlsop_d3_i3d"},
    },
  },

  { "_qzsthq",
    {30, 23, 22},
    { {"000"_b, "strb_32_ldst_pos"},
      {"001"_b, "ldrb_32_ldst_pos"},
      {"010"_b, "ldrsb_64_ldst_pos"},
      {"011"_b, "ldrsb_32_ldst_pos"},
      {"100"_b, "strh_32_ldst_pos"},
      {"101"_b, "ldrh_32_ldst_pos"},
      {"110"_b, "ldrsh_64_ldst_pos"},
      {"111"_b, "ldrsh_32_ldst_pos"},
    },
  },

  { "_qzxvsk",
    {23, 22, 20, 19, 13, 11},
    { {"0000x0"_b, "bic_asimdimm_l_sl"},
      {"00x100"_b, "usra_asimdshf_r"},
      {"00x110"_b, "ursra_asimdshf_r"},
      {"010x00"_b, "usra_asimdshf_r"},
      {"010x10"_b, "ursra_asimdshf_r"},
      {"011100"_b, "usra_asimdshf_r"},
      {"011110"_b, "ursra_asimdshf_r"},
      {"0x1000"_b, "usra_asimdshf_r"},
      {"0x1010"_b, "ursra_asimdshf_r"},
    },
  },

  { "_qzzlhq",
    {30, 23, 22},
    { {"000"_b, "and_32_log_imm"},
      {"010"_b, "movn_32_movewide"},
      {"100"_b, "eor_32_log_imm"},
      {"110"_b, "movz_32_movewide"},
    },
  },

  { "_qzzlpv",
    {13, 12},
    { {"01"_b, "gmi_64g_dp_2src"},
      {"10"_b, "lsrv_64_dp_2src"},
    },
  },

  { "_rgjqzs",
    {30, 23, 22},
    { {"001"_b, "sbfm_64m_bitfield"},
      {"101"_b, "ubfm_64m_bitfield"},
    },
  },

  { "_rgnxpp",
    {23, 22},
    { {"00"_b, "fcsel_s_floatsel"},
      {"01"_b, "fcsel_d_floatsel"},
      {"11"_b, "fcsel_h_floatsel"},
    },
  },

  { "_rgztzl",
    {20, 19, 18, 17, 16},
    { {"00000"_b, "saddlp_asimdmisc_p"},
      {"00001"_b, "xtn_asimdmisc_n"},
    },
  },

  { "_rhhrhg",
    {30, 13, 4},
    { {"000"_b, "cmphs_p_p_zw"},
      {"001"_b, "cmphi_p_p_zw"},
      {"010"_b, "cmplo_p_p_zw"},
      {"011"_b, "cmpls_p_p_zw"},
    },
  },

  { "_rhmxyp",
    {20, 9, 4},
    { {"000"_b, "trn1_p_pp"},
    },
  },

  { "_rhpmjz",
    {12, 11},
    { {"00"_b, "incp_z_p_z"},
      {"01"_b, "incp_r_p_r"},
      {"10"_b, "_mpstrr"},
    },
  },

  { "_rhttgj",
    {12, 10},
    { {"00"_b, "_xxpzrl"},
      {"01"_b, "_vlzrlm"},
      {"10"_b, "_vxylhh"},
      {"11"_b, "_pxgztg"},
    },
  },

  { "_rhvksm",
    {23, 22, 20, 19, 18, 17, 16},
    { {"0111001"_b, "fcvtnu_asisdmiscfp16_r"},
      {"0x00001"_b, "fcvtnu_asisdmisc_r"},
      {"1111001"_b, "fcvtpu_asisdmiscfp16_r"},
      {"1x00001"_b, "fcvtpu_asisdmisc_r"},
    },
  },

  { "_rhzhyz",
    {13, 12, 4},
    { {"000"_b, "rmif_only_rmif"},
    },
  },

  { "_rjmyyl",
    {20, 19, 18, 17, 16, 13},
    { {"000000"_b, "fmov_s_floatdp1"},
      {"000010"_b, "fneg_s_floatdp1"},
      {"001000"_b, "frintn_s_floatdp1"},
      {"001010"_b, "frintm_s_floatdp1"},
      {"001100"_b, "frinta_s_floatdp1"},
      {"001110"_b, "frintx_s_floatdp1"},
      {"010000"_b, "frint32z_s_floatdp1"},
      {"010010"_b, "frint64z_s_floatdp1"},
    },
  },

  { "_rjyrnt",
    {4},
    { {"0"_b, "cmpge_p_p_zi"},
      {"1"_b, "cmpgt_p_p_zi"},
    },
  },

  { "_rjysnh",
    {18, 17, 16, 9, 8, 7, 6},
    { {"0000000"_b, "fadd_z_p_zs"},
      {"0010000"_b, "fsub_z_p_zs"},
      {"0100000"_b, "fmul_z_p_zs"},
      {"0110000"_b, "fsubr_z_p_zs"},
      {"1000000"_b, "fmaxnm_z_p_zs"},
      {"1010000"_b, "fminnm_z_p_zs"},
      {"1100000"_b, "fmax_z_p_zs"},
      {"1110000"_b, "fmin_z_p_zs"},
    },
  },

  { "_rkqtvs",
    {23, 22, 13},
    { {"100"_b, "fmlal_asimdelem_lh"},
      {"xx1"_b, "smlal_asimdelem_l"},
    },
  },

  { "_rkrltp",
    {17},
    { {"0"_b, "st3_asisdlso_b3_3b"},
    },
  },

  { "_rksxpn",
    {30, 23, 22, 11, 10},
    { {"00010"_b, "str_b_ldst_regoff"},
      {"00110"_b, "ldr_b_ldst_regoff"},
      {"01010"_b, "str_q_ldst_regoff"},
      {"01110"_b, "ldr_q_ldst_regoff"},
      {"10010"_b, "str_h_ldst_regoff"},
      {"10110"_b, "ldr_h_ldst_regoff"},
    },
  },

  { "_rkvyqk",
    {23, 22, 20, 19, 13, 11},
    { {"0000x0"_b, "movi_asimdimm_l_hl"},
      {"00x100"_b, "shrn_asimdshf_n"},
      {"00x101"_b, "rshrn_asimdshf_n"},
      {"00x110"_b, "sshll_asimdshf_l"},
      {"010x00"_b, "shrn_asimdshf_n"},
      {"010x01"_b, "rshrn_asimdshf_n"},
      {"010x10"_b, "sshll_asimdshf_l"},
      {"011100"_b, "shrn_asimdshf_n"},
      {"011101"_b, "rshrn_asimdshf_n"},
      {"011110"_b, "sshll_asimdshf_l"},
      {"0x1000"_b, "shrn_asimdshf_n"},
      {"0x1001"_b, "rshrn_asimdshf_n"},
      {"0x1010"_b, "sshll_asimdshf_l"},
    },
  },

  { "_rlrjxp",
    {13, 4},
    { {"00"_b, "fcmge_p_p_zz"},
      {"01"_b, "fcmgt_p_p_zz"},
      {"10"_b, "fcmeq_p_p_zz"},
      {"11"_b, "fcmne_p_p_zz"},
    },
  },

  { "_rlyvpn",
    {23, 12, 11, 10},
    { {"0000"_b, "sqshrunb_z_zi"},
      {"0001"_b, "sqshrunt_z_zi"},
      {"0010"_b, "sqrshrunb_z_zi"},
      {"0011"_b, "sqrshrunt_z_zi"},
      {"0100"_b, "shrnb_z_zi"},
      {"0101"_b, "shrnt_z_zi"},
      {"0110"_b, "rshrnb_z_zi"},
      {"0111"_b, "rshrnt_z_zi"},
    },
  },

  { "_rmltms",
    {9, 8, 7, 6, 5, 1, 0},
    { {"1111100"_b, "eret_64e_branch_reg"},
    },
  },

  { "_rmmmjj",
    {30, 23, 22},
    { {"000"_b, "smaddl_64wa_dp_3src"},
      {"010"_b, "umaddl_64wa_dp_3src"},
    },
  },

  { "_rmxjsn",
    {30},
    { {"0"_b, "orr_64_log_shift"},
      {"1"_b, "ands_64_log_shift"},
    },
  },

  { "_rnktts",
    {23, 22},
    { {"00"_b, "and_asimdsame_only"},
      {"01"_b, "bic_asimdsame_only"},
      {"10"_b, "orr_asimdsame_only"},
      {"11"_b, "orn_asimdsame_only"},
    },
  },

  { "_rnqtmt",
    {30},
    { {"0"_b, "_zyjjgs"},
      {"1"_b, "_lrntmz"},
    },
  },

  { "_rnrzsj",
    {20, 18, 17},
    { {"000"_b, "_lgglzy"},
    },
  },

  { "_rnypvh",
    {17},
    { {"0"_b, "st1_asisdlsop_bx1_r1b"},
      {"1"_b, "st1_asisdlsop_b1_i1b"},
    },
  },

  { "_rpmrkq",
    {23},
    { {"0"_b, "fcmeq_asimdsame_only"},
    },
  },

  { "_rpqgjl",
    {18, 17, 16, 13, 12, 7, 4, 3, 2, 1, 0},
    { {"00000011111"_b, "_kpxtsp"},
    },
  },

  { "_rpzykx",
    {11},
    { {"0"_b, "_svvyrz"},
    },
  },

  { "_rqhryp",
    {12, 10},
    { {"00"_b, "_kjpxvh"},
      {"01"_b, "_mxvjxx"},
      {"10"_b, "sm4ekey_z_zz"},
      {"11"_b, "rax1_z_zz"},
    },
  },

  { "_rshyht",
    {13},
    { {"0"_b, "facge_p_p_zz"},
      {"1"_b, "facgt_p_p_zz"},
    },
  },

  { "_rsqmgk",
    {23, 22, 20, 19, 18, 17, 16},
    { {"0000000"_b, "movprfx_z_z"},
    },
  },

  { "_rsyhtj",
    {13, 12, 11, 10},
    { {"0001"_b, "ushl_asisdsame_only"},
      {"0010"_b, "_gxnlxg"},
      {"0011"_b, "uqshl_asisdsame_only"},
      {"0101"_b, "urshl_asisdsame_only"},
      {"0111"_b, "uqrshl_asisdsame_only"},
      {"1010"_b, "_msnsjp"},
      {"1110"_b, "_llnzlv"},
    },
  },

  { "_rsyjqj",
    {23, 22, 20, 19, 18, 17, 16},
    { {"0010000"_b, "fmaxv_asimdall_only_h"},
      {"0x00001"_b, "frint64z_asimdmisc_r"},
      {"1010000"_b, "fminv_asimdall_only_h"},
      {"1111000"_b, "fabs_asimdmiscfp16_r"},
      {"1x00000"_b, "fabs_asimdmisc_r"},
    },
  },

  { "_rsyzrs",
    {22},
    { {"0"_b, "str_64_ldst_regoff"},
      {"1"_b, "ldr_64_ldst_regoff"},
    },
  },

  { "_rtgkkg",
    {30, 23, 22, 13, 12, 11, 10},
    { {"1101001"_b, "smmla_asimdsame2_g"},
      {"1101011"_b, "usmmla_asimdsame2_g"},
      {"x100111"_b, "usdot_asimdsame2_d"},
      {"xxx0101"_b, "sdot_asimdsame2_d"},
    },
  },

  { "_rtlzxv",
    {13, 12},
    { {"01"_b, "sqdmull_asisddiff_only"},
    },
  },

  { "_rtpztp",
    {22},
    { {"0"_b, "umullb_z_zzi_s"},
      {"1"_b, "umullb_z_zzi_d"},
    },
  },

  { "_rtrlts",
    {23, 22, 12, 11, 10},
    { {"01000"_b, "bfdot_z_zzz"},
      {"10000"_b, "fmlalb_z_zzz"},
      {"10001"_b, "fmlalt_z_zzz"},
      {"11000"_b, "bfmlalb_z_zzz"},
      {"11001"_b, "bfmlalt_z_zzz"},
    },
  },

  { "_rvjzgt",
    {23, 22, 4},
    { {"000"_b, "fccmp_s_floatccmp"},
      {"001"_b, "fccmpe_s_floatccmp"},
      {"010"_b, "fccmp_d_floatccmp"},
      {"011"_b, "fccmpe_d_floatccmp"},
      {"110"_b, "fccmp_h_floatccmp"},
      {"111"_b, "fccmpe_h_floatccmp"},
    },
  },

  { "_rvzhhx",
    {18, 17, 12},
    { {"000"_b, "st3_asisdlso_d3_3d"},
    },
  },

  { "_rxjrmn",
    {22, 13, 12},
    { {"000"_b, "swpa_32_memop"},
      {"100"_b, "swpal_32_memop"},
    },
  },

  { "_rxpspy",
    {30, 23, 22, 12, 11, 10},
    { {"0000xx"_b, "adds_32s_addsub_ext"},
      {"000100"_b, "adds_32s_addsub_ext"},
      {"1000xx"_b, "subs_32s_addsub_ext"},
      {"100100"_b, "subs_32s_addsub_ext"},
    },
  },

  { "_ryglvl",
    {4},
    { {"0"_b, "ccmp_32_condcmp_reg"},
    },
  },

  { "_rykykh",
    {20, 19, 18, 17, 16},
    { {"00000"_b, "rev64_asimdmisc_r"},
    },
  },

  { "_rzkmny",
    {30},
    { {"0"_b, "and_64_log_shift"},
      {"1"_b, "eor_64_log_shift"},
    },
  },

  { "_rznrqt",
    {22},
    { {"0"_b, "umullt_z_zzi_s"},
      {"1"_b, "umullt_z_zzi_d"},
    },
  },

  { "_rzqzlq",
    {23, 22, 20, 19, 16, 13, 12},
    { {"0111110"_b, "fcvtns_asisdmiscfp16_r"},
      {"0111111"_b, "fcvtms_asisdmiscfp16_r"},
      {"0x00110"_b, "fcvtns_asisdmisc_r"},
      {"0x00111"_b, "fcvtms_asisdmisc_r"},
      {"1111110"_b, "fcvtps_asisdmiscfp16_r"},
      {"1111111"_b, "fcvtzs_asisdmiscfp16_r"},
      {"1x00110"_b, "fcvtps_asisdmisc_r"},
      {"1x00111"_b, "fcvtzs_asisdmisc_r"},
      {"xx00000"_b, "cmgt_asisdmisc_z"},
      {"xx00001"_b, "cmeq_asisdmisc_z"},
      {"xx00010"_b, "cmlt_asisdmisc_z"},
      {"xx00011"_b, "abs_asisdmisc_r"},
      {"xx10111"_b, "addp_asisdpair_only"},
    },
  },

  { "_rztvnl",
    {20, 19, 18, 17, 16},
    { {"0000x"_b, "fcadd_z_p_zz"},
      {"10000"_b, "faddp_z_p_zz"},
      {"10100"_b, "fmaxnmp_z_p_zz"},
      {"10101"_b, "fminnmp_z_p_zz"},
      {"10110"_b, "fmaxp_z_p_zz"},
      {"10111"_b, "fminp_z_p_zz"},
    },
  },

  { "_rzzxsn",
    {30, 13},
    { {"00"_b, "_nvyxmh"},
      {"01"_b, "_hykhmt"},
      {"10"_b, "_yszjsm"},
      {"11"_b, "_jrnxzh"},
    },
  },

  { "_sghgtk",
    {4},
    { {"0"_b, "cmplo_p_p_zi"},
      {"1"_b, "cmpls_p_p_zi"},
    },
  },

  { "_sgnknz",
    {23, 22, 20, 19, 11},
    { {"00011"_b, "fcvtzs_asisdshf_c"},
      {"001x1"_b, "fcvtzs_asisdshf_c"},
      {"01xx1"_b, "fcvtzs_asisdshf_c"},
    },
  },

  { "_sgztlj",
    {23, 22, 20, 19, 18, 17, 16},
    { {"0010000"_b, "fmaxnmv_asimdall_only_h"},
      {"0111001"_b, "fcvtas_asimdmiscfp16_r"},
      {"0x00001"_b, "fcvtas_asimdmisc_r"},
      {"1010000"_b, "fminnmv_asimdall_only_h"},
      {"1111000"_b, "fcmgt_asimdmiscfp16_fz"},
      {"1x00000"_b, "fcmgt_asimdmisc_fz"},
      {"1x00001"_b, "urecpe_asimdmisc_r"},
    },
  },

  { "_shgkvq",
    {18, 17},
    { {"00"_b, "st2_asisdlso_s2_2s"},
    },
  },

  { "_shqygv",
    {30, 4},
    { {"00"_b, "_thvxym"},
      {"01"_b, "_mrhtxt"},
      {"10"_b, "_ptjyqx"},
      {"11"_b, "_rshyht"},
    },
  },

  { "_shrsxr",
    {30, 23, 22},
    { {"000"_b, "stnp_64_ldstnapair_offs"},
      {"001"_b, "ldnp_64_ldstnapair_offs"},
      {"010"_b, "stp_64_ldstpair_post"},
      {"011"_b, "ldp_64_ldstpair_post"},
    },
  },

  { "_shzysp",
    {30, 23, 22, 19, 18, 17, 16},
    { {"1001000"_b, "ins_asimdins_ir_r"},
      {"100x100"_b, "ins_asimdins_ir_r"},
      {"100xx10"_b, "ins_asimdins_ir_r"},
      {"100xxx1"_b, "ins_asimdins_ir_r"},
      {"x01xxxx"_b, "fmulx_asimdsamefp16_only"},
    },
  },

  { "_sjlpxn",
    {23, 22},
    { {"01"_b, "fcmla_asimdelem_c_h"},
      {"10"_b, "fcmla_asimdelem_c_s"},
    },
  },

  { "_sjlrxn",
    {10},
    { {"0"_b, "_mpzqxm"},
    },
  },

  { "_sjnqvx",
    {23, 22, 4},
    { {"000"_b, "fccmp_s_floatccmp"},
      {"001"_b, "fccmpe_s_floatccmp"},
      {"010"_b, "fccmp_d_floatccmp"},
      {"011"_b, "fccmpe_d_floatccmp"},
      {"110"_b, "fccmp_h_floatccmp"},
      {"111"_b, "fccmpe_h_floatccmp"},
    },
  },

  { "_sjnspg",
    {4},
    { {"0"_b, "nors_p_p_pp_z"},
      {"1"_b, "nands_p_p_pp_z"},
    },
  },

  { "_sjnxky",
    {30},
    { {"1"_b, "_ylyskq"},
    },
  },

  { "_sjrqth",
    {23, 22},
    { {"00"_b, "fmov_s_floatimm"},
      {"01"_b, "fmov_d_floatimm"},
      {"11"_b, "fmov_h_floatimm"},
    },
  },

  { "_sjsltg",
    {17},
    { {"0"_b, "st2_asisdlsop_hx2_r2h"},
      {"1"_b, "st2_asisdlsop_h2_i2h"},
    },
  },

  { "_sjtrhm",
    {30, 23, 22, 20, 13},
    { {"00001"_b, "ld1rqb_z_p_bi_u8"},
      {"000x0"_b, "ld1rqb_z_p_br_contiguous"},
      {"01001"_b, "ld1rqh_z_p_bi_u16"},
      {"010x0"_b, "ld1rqh_z_p_br_contiguous"},
      {"100x1"_b, "stnt1b_z_p_ar_d_64_unscaled"},
      {"101x1"_b, "stnt1b_z_p_ar_s_x32_unscaled"},
      {"110x1"_b, "stnt1h_z_p_ar_d_64_unscaled"},
      {"111x1"_b, "stnt1h_z_p_ar_s_x32_unscaled"},
    },
  },

  { "_sjvhlq",
    {22},
    { {"0"_b, "smullb_z_zzi_s"},
      {"1"_b, "smullb_z_zzi_d"},
    },
  },

  { "_sjzsvv",
    {30, 23, 13, 12, 11, 10},
    { {"101001"_b, "ucvtf_asisdshf_c"},
      {"101111"_b, "fcvtzu_asisdshf_c"},
      {"1x01x0"_b, "sqrdmlah_asisdelem_r"},
      {"1x11x0"_b, "sqrdmlsh_asisdelem_r"},
    },
  },

  { "_skglrt",
    {23, 22, 20, 19, 13, 11},
    { {"0000x0"_b, "mvni_asimdimm_l_sl"},
      {"00x100"_b, "ushr_asimdshf_r"},
      {"00x110"_b, "urshr_asimdshf_r"},
      {"010x00"_b, "ushr_asimdshf_r"},
      {"010x10"_b, "urshr_asimdshf_r"},
      {"011100"_b, "ushr_asimdshf_r"},
      {"011110"_b, "urshr_asimdshf_r"},
      {"0x1000"_b, "ushr_asimdshf_r"},
      {"0x1010"_b, "urshr_asimdshf_r"},
    },
  },

  { "_skpjrp",
    {23, 22, 12},
    { {"000"_b, "_xzyylk"},
      {"001"_b, "_hpgqlp"},
      {"010"_b, "_qnsxkj"},
      {"011"_b, "_nnlvqz"},
      {"110"_b, "_vylhvl"},
      {"111"_b, "_stgkpy"},
    },
  },

  { "_slhpgp",
    {23},
    { {"0"_b, "facge_asimdsame_only"},
      {"1"_b, "facgt_asimdsame_only"},
    },
  },

  { "_sllkpt",
    {13, 12},
    { {"10"_b, "lsrv_32_dp_2src"},
    },
  },

  { "_slnkst",
    {23, 22, 20, 19, 18, 17, 16},
    { {"0111001"_b, "fcvtmu_asimdmiscfp16_r"},
      {"0x00001"_b, "fcvtmu_asimdmisc_r"},
      {"1111001"_b, "fcvtzu_asimdmiscfp16_r"},
      {"1x00001"_b, "fcvtzu_asimdmisc_r"},
      {"xx00000"_b, "neg_asimdmisc_r"},
    },
  },

  { "_sltqpy",
    {30, 23, 22, 13, 12, 11, 10},
    { {"000xx10"_b, "strb_32b_ldst_regoff"},
      {"001xx10"_b, "ldrb_32b_ldst_regoff"},
      {"0100000"_b, "ldaprb_32l_memop"},
      {"010xx10"_b, "ldrsb_64b_ldst_regoff"},
      {"011xx10"_b, "ldrsb_32b_ldst_regoff"},
      {"100xx10"_b, "strh_32_ldst_regoff"},
      {"101xx10"_b, "ldrh_32_ldst_regoff"},
      {"1100000"_b, "ldaprh_32l_memop"},
      {"110xx10"_b, "ldrsh_64_ldst_regoff"},
      {"111xx10"_b, "ldrsh_32_ldst_regoff"},
    },
  },

  { "_smplhv",
    {10},
    { {"0"_b, "braa_64p_branch_reg"},
      {"1"_b, "brab_64p_branch_reg"},
    },
  },

  { "_smqvrs",
    {18, 17},
    { {"00"_b, "st1_asisdlse_r1_1v"},
    },
  },

  { "_smrtxq",
    {13, 12},
    { {"00"_b, "sbcs_32_addsub_carry"},
    },
  },

  { "_snjpvy",
    {23, 22, 13, 12, 11, 10},
    { {"0001x0"_b, "fmulx_asimdelem_rh_h"},
      {"0x0001"_b, "sqshrun_asimdshf_n"},
      {"0x0011"_b, "sqrshrun_asimdshf_n"},
      {"0x0101"_b, "uqshrn_asimdshf_n"},
      {"0x0111"_b, "uqrshrn_asimdshf_n"},
      {"0x1001"_b, "ushll_asimdshf_l"},
      {"1000x0"_b, "fmlal2_asimdelem_lh"},
      {"1x01x0"_b, "fmulx_asimdelem_r_sd"},
      {"xx10x0"_b, "umull_asimdelem_l"},
    },
  },

  { "_snkqvp",
    {23, 22, 20, 19, 18, 17, 16, 13, 12, 11},
    { {"0011111001"_b, "_gkpvxz"},
    },
  },

  { "_sntyqy",
    {4},
    { {"0"_b, "cmphs_p_p_zi"},
      {"1"_b, "cmphi_p_p_zi"},
    },
  },

  { "_sntzjg",
    {23, 22, 11, 10},
    { {"0000"_b, "_qssyls"},
      {"0001"_b, "stg_64spost_ldsttags"},
      {"0010"_b, "stg_64soffset_ldsttags"},
      {"0011"_b, "stg_64spre_ldsttags"},
      {"0100"_b, "ldg_64loffset_ldsttags"},
      {"0101"_b, "stzg_64spost_ldsttags"},
      {"0110"_b, "stzg_64soffset_ldsttags"},
      {"0111"_b, "stzg_64spre_ldsttags"},
      {"1000"_b, "_kyxqgg"},
      {"1001"_b, "st2g_64spost_ldsttags"},
      {"1010"_b, "st2g_64soffset_ldsttags"},
      {"1011"_b, "st2g_64spre_ldsttags"},
      {"1100"_b, "_stjrgx"},
      {"1101"_b, "stz2g_64spost_ldsttags"},
      {"1110"_b, "stz2g_64soffset_ldsttags"},
      {"1111"_b, "stz2g_64spre_ldsttags"},
    },
  },

  { "_spglxn",
    {4, 3, 2, 1, 0},
    { {"11111"_b, "_yqmvxk"},
    },
  },

  { "_sphpkr",
    {4, 3, 2, 1, 0},
    { {"11111"_b, "_thsxvg"},
    },
  },

  { "_spjjkg",
    {23, 22, 13, 12, 11, 10},
    { {"0011x0"_b, "sudot_asimdelem_d"},
      {"0111x0"_b, "bfdot_asimdelem_e"},
      {"0x1001"_b, "scvtf_asimdshf_c"},
      {"0x1111"_b, "fcvtzs_asimdshf_c"},
      {"1011x0"_b, "usdot_asimdelem_d"},
      {"1111x0"_b, "bfmlal_asimdelem_f"},
      {"xx00x0"_b, "sqdmulh_asimdelem_r"},
      {"xx01x0"_b, "sqrdmulh_asimdelem_r"},
      {"xx10x0"_b, "sdot_asimdelem_d"},
    },
  },

  { "_spmkmm",
    {30, 19, 18, 17, 16, 10},
    { {"110001"_b, "ins_asimdins_iv_v"},
      {"1x1001"_b, "ins_asimdins_iv_v"},
      {"1xx101"_b, "ins_asimdins_iv_v"},
      {"1xxx11"_b, "ins_asimdins_iv_v"},
      {"xxxxx0"_b, "ext_asimdext_only"},
    },
  },

  { "_spzgkt",
    {23, 22, 13, 12, 11, 10},
    { {"0x1001"_b, "ucvtf_asimdshf_c"},
      {"0x1111"_b, "fcvtzu_asimdshf_c"},
      {"1000x0"_b, "fmlsl2_asimdelem_lh"},
      {"xx01x0"_b, "sqrdmlah_asimdelem_r"},
      {"xx10x0"_b, "udot_asimdelem_d"},
      {"xx11x0"_b, "sqrdmlsh_asimdelem_r"},
    },
  },

  { "_sqgjmn",
    {20, 9},
    { {"00"_b, "_mxgykv"},
    },
  },

  { "_sqgxzn",
    {9, 8, 7, 6, 5},
    { {"11111"_b, "paciza_64z_dp_1src"},
    },
  },

  { "_sqjpsl",
    {30, 13, 12, 11, 10},
    { {"10001"_b, "sqrdmlah_asisdsame2_only"},
      {"10011"_b, "sqrdmlsh_asisdsame2_only"},
    },
  },

  { "_sqpjtr",
    {20, 18, 17},
    { {"000"_b, "_nllnsg"},
    },
  },

  { "_srggzy",
    {19},
    { {"0"_b, "_xqgxjp"},
      {"1"_b, "sysl_rc_systeminstrs"},
    },
  },

  { "_srglgl",
    {18, 17},
    { {"0x"_b, "st3_asisdlsop_sx3_r3s"},
      {"10"_b, "st3_asisdlsop_sx3_r3s"},
      {"11"_b, "st3_asisdlsop_s3_i3s"},
    },
  },

  { "_srmhjk",
    {30},
    { {"0"_b, "ldr_s_loadlit"},
      {"1"_b, "ldr_d_loadlit"},
    },
  },

  { "_srmhlk",
    {20, 19, 18, 17, 16},
    { {"00000"_b, "uaddlp_asimdmisc_p"},
      {"00001"_b, "sqxtun_asimdmisc_n"},
    },
  },

  { "_srvnql",
    {18, 17, 12},
    { {"0x0"_b, "ld1_asisdlsop_dx1_r1d"},
      {"100"_b, "ld1_asisdlsop_dx1_r1d"},
      {"110"_b, "ld1_asisdlsop_d1_i1d"},
    },
  },

  { "_stgkpy",
    {9, 8, 7, 6, 5},
    { {"00000"_b, "fmov_h_floatimm"},
    },
  },

  { "_stjrgx",
    {20, 19, 18, 17, 16, 13, 12},
    { {"0000000"_b, "ldgm_64bulk_ldsttags"},
    },
  },

  { "_stqmps",
    {12},
    { {"0"_b, "ld3_asisdlsop_dx3_r3d"},
    },
  },

  { "_strkph",
    {23, 22},
    { {"00"_b, "tbl_asimdtbl_l2_2"},
    },
  },

  { "_svnyyx",
    {13, 12},
    { {"00"_b, "adcs_32_addsub_carry"},
    },
  },

  { "_svrnxq",
    {12},
    { {"0"_b, "st3_asisdlsop_dx3_r3d"},
    },
  },

  { "_svvyrz",
    {23, 22, 20, 19, 18, 17, 16},
    { {"00xxxxx"_b, "addvl_r_ri"},
      {"01xxxxx"_b, "addpl_r_ri"},
      {"1011111"_b, "rdvl_r_i"},
    },
  },

  { "_sxnkrh",
    {23},
    { {"1"_b, "_xxkvsy"},
    },
  },

  { "_sxpvym",
    {30, 23, 22, 13},
    { {"0000"_b, "ldnt1sb_z_p_ar_s_x32_unscaled"},
      {"0001"_b, "ldnt1b_z_p_ar_s_x32_unscaled"},
      {"0010"_b, "ld1rb_z_p_bi_u8"},
      {"0011"_b, "ld1rb_z_p_bi_u16"},
      {"0100"_b, "ldnt1sh_z_p_ar_s_x32_unscaled"},
      {"0101"_b, "ldnt1h_z_p_ar_s_x32_unscaled"},
      {"0110"_b, "ld1rsw_z_p_bi_s64"},
      {"0111"_b, "ld1rh_z_p_bi_u16"},
      {"1000"_b, "ldnt1sb_z_p_ar_d_64_unscaled"},
      {"1010"_b, "ld1sb_z_p_bz_d_64_unscaled"},
      {"1011"_b, "ldff1sb_z_p_bz_d_64_unscaled"},
      {"1100"_b, "ldnt1sh_z_p_ar_d_64_unscaled"},
      {"1110"_b, "ld1sh_z_p_bz_d_64_unscaled"},
      {"1111"_b, "ldff1sh_z_p_bz_d_64_unscaled"},
    },
  },

  { "_syktsg",
    {13, 12},
    { {"00"_b, "udiv_64_dp_2src"},
      {"10"_b, "asrv_64_dp_2src"},
    },
  },

  { "_syzjtz",
    {13, 12, 10},
    { {"010"_b, "sqrdmlah_asisdelem_r"},
      {"101"_b, "_jqnglz"},
      {"110"_b, "sqrdmlsh_asisdelem_r"},
      {"111"_b, "_zslsvj"},
    },
  },

  { "_szttjy",
    {30, 23, 22, 19, 18, 17, 16},
    { {"00000x1"_b, "umov_asimdins_w_w"},
      {"0000x10"_b, "umov_asimdins_w_w"},
      {"00010xx"_b, "umov_asimdins_w_w"},
      {"0001110"_b, "umov_asimdins_w_w"},
      {"000x10x"_b, "umov_asimdins_w_w"},
      {"000x111"_b, "umov_asimdins_w_w"},
      {"1001000"_b, "umov_asimdins_x_x"},
      {"x01xxxx"_b, "frecps_asimdsamefp16_only"},
      {"x11xxxx"_b, "frsqrts_asimdsamefp16_only"},
    },
  },

  { "_tgmljr",
    {23, 22, 20, 19, 12, 11},
    { {"000000"_b, "movi_asimdimm_n_b"},
      {"000010"_b, "fmov_asimdimm_s_s"},
      {"000011"_b, "fmov_asimdimm_h_h"},
      {"00x100"_b, "scvtf_asimdshf_c"},
      {"00x111"_b, "fcvtzs_asimdshf_c"},
      {"010x00"_b, "scvtf_asimdshf_c"},
      {"010x11"_b, "fcvtzs_asimdshf_c"},
      {"011100"_b, "scvtf_asimdshf_c"},
      {"011111"_b, "fcvtzs_asimdshf_c"},
      {"0x1000"_b, "scvtf_asimdshf_c"},
      {"0x1011"_b, "fcvtzs_asimdshf_c"},
    },
  },

  { "_tgqsyg",
    {22},
    { {"0"_b, "prfm_p_ldst_regoff"},
    },
  },

  { "_thqvrp",
    {17},
    { {"0"_b, "st1_asisdlsep_r2_r2"},
      {"1"_b, "st1_asisdlsep_i2_i2"},
    },
  },

  { "_thrxph",
    {23, 22, 10},
    { {"100"_b, "umlalb_z_zzzi_s"},
      {"101"_b, "umlalt_z_zzzi_s"},
      {"110"_b, "umlalb_z_zzzi_d"},
      {"111"_b, "umlalt_z_zzzi_d"},
    },
  },

  { "_thsxvg",
    {11, 10, 9, 8, 7, 6},
    { {"000010"_b, "ssbb_only_barriers"},
      {"010010"_b, "pssbb_only_barriers"},
      {"0x1010"_b, "dsb_bo_barriers"},
      {"0xx110"_b, "dsb_bo_barriers"},
      {"1xxx10"_b, "dsb_bo_barriers"},
      {"xxxx01"_b, "clrex_bn_barriers"},
      {"xxxx11"_b, "isb_bi_barriers"},
    },
  },

  { "_thvvzp",
    {18, 17, 12},
    { {"0x0"_b, "st1_asisdlsop_dx1_r1d"},
      {"100"_b, "st1_asisdlsop_dx1_r1d"},
      {"110"_b, "st1_asisdlsop_d1_i1d"},
    },
  },

  { "_thvxym",
    {20},
    { {"0"_b, "_prkmty"},
      {"1"_b, "_pjgkjs"},
    },
  },

  { "_tjktkm",
    {30},
    { {"1"_b, "_gntpyh"},
    },
  },

  { "_tjltls",
    {18, 17},
    { {"0x"_b, "st1_asisdlsep_r1_r1"},
      {"10"_b, "st1_asisdlsep_r1_r1"},
      {"11"_b, "st1_asisdlsep_i1_i1"},
    },
  },

  { "_tjpjng",
    {23, 22, 13, 12},
    { {"0000"_b, "fmax_s_floatdp2"},
      {"0001"_b, "fmin_s_floatdp2"},
      {"0010"_b, "fmaxnm_s_floatdp2"},
      {"0011"_b, "fminnm_s_floatdp2"},
      {"0100"_b, "fmax_d_floatdp2"},
      {"0101"_b, "fmin_d_floatdp2"},
      {"0110"_b, "fmaxnm_d_floatdp2"},
      {"0111"_b, "fminnm_d_floatdp2"},
      {"1100"_b, "fmax_h_floatdp2"},
      {"1101"_b, "fmin_h_floatdp2"},
      {"1110"_b, "fmaxnm_h_floatdp2"},
      {"1111"_b, "fminnm_h_floatdp2"},
    },
  },

  { "_tjtgjy",
    {20, 19, 18, 17},
    { {"0000"_b, "_gjsnly"},
    },
  },

  { "_tjzqnp",
    {30, 23, 22, 20, 13},
    { {"00001"_b, "ldnt1b_z_p_bi_contiguous"},
      {"000x0"_b, "ldnt1b_z_p_br_contiguous"},
      {"00101"_b, "ld3b_z_p_bi_contiguous"},
      {"001x0"_b, "ld3b_z_p_br_contiguous"},
      {"01001"_b, "ldnt1h_z_p_bi_contiguous"},
      {"010x0"_b, "ldnt1h_z_p_br_contiguous"},
      {"01101"_b, "ld3h_z_p_bi_contiguous"},
      {"011x0"_b, "ld3h_z_p_br_contiguous"},
      {"10011"_b, "stnt1b_z_p_bi_contiguous"},
      {"100x0"_b, "st1b_z_p_bz_d_x32_unscaled"},
      {"10111"_b, "st3b_z_p_bi_contiguous"},
      {"101x0"_b, "st1b_z_p_bz_s_x32_unscaled"},
      {"10x01"_b, "st1b_z_p_bi"},
      {"11011"_b, "stnt1h_z_p_bi_contiguous"},
      {"110x0"_b, "st1h_z_p_bz_d_x32_unscaled"},
      {"11111"_b, "st3h_z_p_bi_contiguous"},
      {"111x0"_b, "st1h_z_p_bz_s_x32_unscaled"},
      {"11x01"_b, "st1h_z_p_bi"},
    },
  },

  { "_tkjtgp",
    {30},
    { {"0"_b, "_sqgjmn"},
      {"1"_b, "_ztpryr"},
    },
  },

  { "_tkzqqp",
    {4, 3, 2, 1, 0},
    { {"11111"_b, "_ntkqhk"},
    },
  },

  { "_tlstgz",
    {30, 23, 22},
    { {"000"_b, "stlxp_sp32_ldstexcl"},
      {"001"_b, "ldaxp_lp32_ldstexcl"},
      {"100"_b, "stlxp_sp64_ldstexcl"},
      {"101"_b, "ldaxp_lp64_ldstexcl"},
    },
  },

  { "_tlzlrj",
    {17},
    { {"0"_b, "st2_asisdlso_b2_2b"},
    },
  },

  { "_tmhlvh",
    {20, 9, 4},
    { {"000"_b, "zip2_p_pp"},
    },
  },

  { "_tmrnzq",
    {17},
    { {"0"_b, "st2_asisdlsep_r2_r"},
      {"1"_b, "st2_asisdlsep_i2_i"},
    },
  },

  { "_tmshps",
    {17},
    { {"0"_b, "fmaxnmv_v_p_z"},
      {"1"_b, "fmaxv_v_p_z"},
    },
  },

  { "_tmthqm",
    {22},
    { {"0"_b, "str_32_ldst_regoff"},
      {"1"_b, "ldr_32_ldst_regoff"},
    },
  },

  { "_tmtnkq",
    {23, 18, 17, 16},
    { {"0000"_b, "uqxtnb_z_zz"},
    },
  },

  { "_tnhmpx",
    {30, 23, 22, 13, 12, 11, 10},
    { {"1011001"_b, "fcmge_asisdsamefp16_only"},
      {"1011011"_b, "facge_asisdsamefp16_only"},
      {"1110101"_b, "fabd_asisdsamefp16_only"},
      {"1111001"_b, "fcmgt_asisdsamefp16_only"},
      {"1111011"_b, "facgt_asisdsamefp16_only"},
    },
  },

  { "_tnrrjk",
    {30, 23, 22, 11, 10},
    { {"01000"_b, "csel_32_condsel"},
      {"01001"_b, "csinc_32_condsel"},
      {"11000"_b, "csinv_32_condsel"},
      {"11001"_b, "csneg_32_condsel"},
    },
  },

  { "_tnxlnl",
    {13, 12},
    { {"00"_b, "crc32x_64c_dp_2src"},
      {"01"_b, "crc32cx_64c_dp_2src"},
    },
  },

  { "_tnzytv",
    {11, 10, 9, 8, 7, 6},
    { {"000000"_b, "wfet_only_systeminstrswithreg"},
    },
  },

  { "_tpkslq",
    {30, 23, 22, 20, 13, 4},
    { {"00001x"_b, "ld1rqw_z_p_bi_u32"},
      {"000x0x"_b, "ld1rqw_z_p_br_contiguous"},
      {"01001x"_b, "ld1rqd_z_p_bi_u64"},
      {"010x0x"_b, "ld1rqd_z_p_br_contiguous"},
      {"100x1x"_b, "stnt1w_z_p_ar_d_64_unscaled"},
      {"101x1x"_b, "stnt1w_z_p_ar_s_x32_unscaled"},
      {"110x00"_b, "str_p_bi"},
      {"110x1x"_b, "stnt1d_z_p_ar_d_64_unscaled"},
    },
  },

  { "_tpkzxg",
    {4},
    { {"0"_b, "ccmp_64_condcmp_imm"},
    },
  },

  { "_tpsylx",
    {13},
    { {"0"_b, "_gjylrt"},
      {"1"_b, "_ygjslq"},
    },
  },

  { "_trlhgn",
    {30, 23, 22, 11, 10},
    { {"00010"_b, "str_b_ldst_regoff"},
      {"00110"_b, "ldr_b_ldst_regoff"},
      {"01010"_b, "str_q_ldst_regoff"},
      {"01110"_b, "ldr_q_ldst_regoff"},
      {"10010"_b, "str_h_ldst_regoff"},
      {"10110"_b, "ldr_h_ldst_regoff"},
    },
  },

  { "_tsksxr",
    {17},
    { {"0"_b, "fminnmv_v_p_z"},
      {"1"_b, "fminv_v_p_z"},
    },
  },

  { "_tssqsr",
    {30},
    { {"1"_b, "_syzjtz"},
    },
  },

  { "_tsvsgh",
    {17},
    { {"0"_b, "st1_asisdlso_b1_1b"},
    },
  },

  { "_tszvvk",
    {18, 17, 12},
    { {"000"_b, "ld2_asisdlso_d2_2d"},
    },
  },

  { "_ttplgp",
    {12, 11, 10},
    { {"000"_b, "sqincp_z_p_z"},
      {"010"_b, "sqincp_r_p_r_sx"},
      {"011"_b, "sqincp_r_p_r_x"},
      {"100"_b, "_zqmrhp"},
    },
  },

  { "_ttstyt",
    {12, 10},
    { {"00"_b, "_rkqtvs"},
      {"01"_b, "_mtlhnl"},
      {"10"_b, "_zlmgyp"},
      {"11"_b, "_kjghlk"},
    },
  },

  { "_tvgvvq",
    {30},
    { {"0"_b, "cbnz_32_compbranch"},
    },
  },

  { "_tvsszp",
    {23, 22},
    { {"00"_b, "fmadd_s_floatdp3"},
      {"01"_b, "fmadd_d_floatdp3"},
      {"11"_b, "fmadd_h_floatdp3"},
    },
  },

  { "_txhzxq",
    {30, 22, 11},
    { {"000"_b, "_svnyyx"},
      {"001"_b, "_qsxpyq"},
      {"010"_b, "_pnqxjg"},
      {"011"_b, "_myrshl"},
      {"100"_b, "_smrtxq"},
      {"110"_b, "_ryglvl"},
      {"111"_b, "_qqsmlt"},
    },
  },

  { "_txjyxr",
    {18, 17},
    { {"0x"_b, "ld1_asisdlsep_r1_r1"},
      {"10"_b, "ld1_asisdlsep_r1_r1"},
      {"11"_b, "ld1_asisdlsep_i1_i1"},
    },
  },

  { "_txnqzy",
    {30, 23, 22},
    { {"000"_b, "smsubl_64wa_dp_3src"},
      {"010"_b, "umsubl_64wa_dp_3src"},
    },
  },

  { "_txsmts",
    {13, 12, 11, 10},
    { {"0000"_b, "smlal_asimddiff_l"},
      {"0001"_b, "add_asimdsame_only"},
      {"0010"_b, "_qhsplz"},
      {"0011"_b, "cmtst_asimdsame_only"},
      {"0100"_b, "sqdmlal_asimddiff_l"},
      {"0101"_b, "mla_asimdsame_only"},
      {"0110"_b, "_yvxgrr"},
      {"0111"_b, "mul_asimdsame_only"},
      {"1000"_b, "smlsl_asimddiff_l"},
      {"1001"_b, "smaxp_asimdsame_only"},
      {"1010"_b, "_mnxmst"},
      {"1011"_b, "sminp_asimdsame_only"},
      {"1100"_b, "sqdmlsl_asimddiff_l"},
      {"1101"_b, "sqdmulh_asimdsame_only"},
      {"1110"_b, "_klkgqk"},
      {"1111"_b, "addp_asimdsame_only"},
    },
  },

  { "_txzxzs",
    {23, 22, 20, 19, 18},
    { {"00000"_b, "orr_z_zi"},
      {"01000"_b, "eor_z_zi"},
      {"10000"_b, "and_z_zi"},
      {"11000"_b, "dupm_z_i"},
      {"xx1xx"_b, "cpy_z_p_i"},
    },
  },

  { "_tyjqvt",
    {18, 17},
    { {"00"_b, "ld4_asisdlso_s4_4s"},
    },
  },

  { "_tylqpt",
    {23, 22, 13},
    { {"000"_b, "fmulx_asimdelem_rh_h"},
      {"1x0"_b, "fmulx_asimdelem_r_sd"},
    },
  },

  { "_typysz",
    {23, 22, 20, 19, 13, 11, 10},
    { {"00x1001"_b, "sqshrn_asisdshf_n"},
      {"00x1011"_b, "sqrshrn_asisdshf_n"},
      {"00xx0x0"_b, "fmul_asisdelem_rh_h"},
      {"010x001"_b, "sqshrn_asisdshf_n"},
      {"010x011"_b, "sqrshrn_asisdshf_n"},
      {"0111001"_b, "sqshrn_asisdshf_n"},
      {"0111011"_b, "sqrshrn_asisdshf_n"},
      {"0x10001"_b, "sqshrn_asisdshf_n"},
      {"0x10011"_b, "sqrshrn_asisdshf_n"},
      {"1xxx0x0"_b, "fmul_asisdelem_r_sd"},
      {"xxxx1x0"_b, "sqdmull_asisdelem_l"},
    },
  },

  { "_tytvjk",
    {13, 12, 11},
    { {"000"_b, "_lylpyx"},
      {"001"_b, "_kyxrqg"},
      {"010"_b, "_zmkqxl"},
      {"011"_b, "_gngjxr"},
      {"100"_b, "_mlxtxs"},
      {"101"_b, "_mnmtql"},
      {"110"_b, "_xmxpnx"},
      {"111"_b, "_lkttgy"},
    },
  },

  { "_tzzhsk",
    {13, 12},
    { {"01"_b, "sqdmlal_asisddiff_only"},
      {"11"_b, "sqdmlsl_asisddiff_only"},
    },
  },

  { "_tzzssm",
    {12, 11, 10},
    { {"000"_b, "histseg_z_zz"},
    },
  },

  { "_tzzzxz",
    {30, 23, 22, 20, 19},
    { {"0xxxx"_b, "bl_only_branch_imm"},
      {"10001"_b, "sysl_rc_systeminstrs"},
      {"1001x"_b, "mrs_rs_systemmove"},
    },
  },

  { "_vgrhsz",
    {30, 23, 11, 10},
    { {"0010"_b, "_hljrqn"},
      {"0100"_b, "_htnmls"},
      {"0110"_b, "_vxgzqy"},
      {"1000"_b, "_lpsxhz"},
      {"1001"_b, "ldraa_64_ldst_pac"},
      {"1010"_b, "_jtqlhs"},
      {"1011"_b, "ldraa_64w_ldst_pac"},
      {"1100"_b, "_yrlzqp"},
      {"1101"_b, "ldrab_64_ldst_pac"},
      {"1110"_b, "_xyhxzt"},
      {"1111"_b, "ldrab_64w_ldst_pac"},
    },
  },

  { "_vgrtjz",
    {12},
    { {"0"_b, "sqdmulh_asimdelem_r"},
      {"1"_b, "sqrdmulh_asimdelem_r"},
    },
  },

  { "_vgtnjh",
    {23, 22, 20, 19, 18, 17, 16},
    { {"0001010"_b, "fcvtxnt_z_p_z_d2s"},
      {"1001000"_b, "fcvtnt_z_p_z_s2h"},
      {"1001001"_b, "fcvtlt_z_p_z_h2s"},
      {"1001010"_b, "bfcvtnt_z_p_z_s2bf"},
      {"1101010"_b, "fcvtnt_z_p_z_d2s"},
      {"1101011"_b, "fcvtlt_z_p_z_s2d"},
    },
  },

  { "_vhhktl",
    {18, 17},
    { {"0x"_b, "st4_asisdlsop_sx4_r4s"},
      {"10"_b, "st4_asisdlsop_sx4_r4s"},
      {"11"_b, "st4_asisdlsop_s4_i4s"},
    },
  },

  { "_vhmsgj",
    {18, 17, 12},
    { {"000"_b, "ld1_asisdlso_d1_1d"},
    },
  },

  { "_vjlnqj",
    {23, 22, 13, 12},
    { {"0000"_b, "fnmul_s_floatdp2"},
      {"0100"_b, "fnmul_d_floatdp2"},
      {"1100"_b, "fnmul_h_floatdp2"},
    },
  },

  { "_vjmklj",
    {23, 22},
    { {"10"_b, "sqrdcmlah_z_zzzi_h"},
      {"11"_b, "sqrdcmlah_z_zzzi_s"},
    },
  },

  { "_vjqsqs",
    {30},
    { {"0"_b, "and_32_log_shift"},
      {"1"_b, "eor_32_log_shift"},
    },
  },

  { "_vjxqhp",
    {23, 22, 20, 19, 18, 16, 13},
    { {"0000000"_b, "_jlrvpl"},
      {"0000001"_b, "_pmkxlj"},
      {"0100000"_b, "_qmgtyq"},
      {"0100001"_b, "_qhxzxl"},
      {"100xxx0"_b, "st2_asisdlsep_r2_r"},
      {"100xxx1"_b, "st1_asisdlsep_r2_r2"},
      {"1010xx0"_b, "st2_asisdlsep_r2_r"},
      {"1010xx1"_b, "st1_asisdlsep_r2_r2"},
      {"10110x0"_b, "st2_asisdlsep_r2_r"},
      {"10110x1"_b, "st1_asisdlsep_r2_r2"},
      {"1011100"_b, "st2_asisdlsep_r2_r"},
      {"1011101"_b, "st1_asisdlsep_r2_r2"},
      {"1011110"_b, "_tmrnzq"},
      {"1011111"_b, "_thqvrp"},
      {"110xxx0"_b, "ld2_asisdlsep_r2_r"},
      {"110xxx1"_b, "ld1_asisdlsep_r2_r2"},
      {"1110xx0"_b, "ld2_asisdlsep_r2_r"},
      {"1110xx1"_b, "ld1_asisdlsep_r2_r2"},
      {"11110x0"_b, "ld2_asisdlsep_r2_r"},
      {"11110x1"_b, "ld1_asisdlsep_r2_r2"},
      {"1111100"_b, "ld2_asisdlsep_r2_r"},
      {"1111101"_b, "ld1_asisdlsep_r2_r2"},
      {"1111110"_b, "_nszhhy"},
      {"1111111"_b, "_qxrzgv"},
    },
  },

  { "_vjymzn",
    {23, 22},
    { {"00"_b, "fcsel_s_floatsel"},
      {"01"_b, "fcsel_d_floatsel"},
      {"11"_b, "fcsel_h_floatsel"},
    },
  },

  { "_vkhhkk",
    {30, 23, 22, 11, 10, 4},
    { {"001000"_b, "ccmn_64_condcmp_reg"},
      {"001100"_b, "ccmn_64_condcmp_imm"},
      {"101000"_b, "ccmp_64_condcmp_reg"},
      {"101100"_b, "ccmp_64_condcmp_imm"},
    },
  },

  { "_vkrkks",
    {30, 23, 22, 13, 4},
    { {"00000"_b, "prfb_i_p_br_s"},
      {"00010"_b, "prfb_i_p_ai_s"},
      {"0010x"_b, "ld1rb_z_p_bi_u32"},
      {"0011x"_b, "ld1rb_z_p_bi_u64"},
      {"01000"_b, "prfh_i_p_br_s"},
      {"01010"_b, "prfh_i_p_ai_s"},
      {"0110x"_b, "ld1rh_z_p_bi_u32"},
      {"0111x"_b, "ld1rh_z_p_bi_u64"},
      {"1000x"_b, "ldnt1b_z_p_ar_d_64_unscaled"},
      {"10010"_b, "prfb_i_p_ai_d"},
      {"1010x"_b, "ld1b_z_p_bz_d_64_unscaled"},
      {"1011x"_b, "ldff1b_z_p_bz_d_64_unscaled"},
      {"1100x"_b, "ldnt1h_z_p_ar_d_64_unscaled"},
      {"11010"_b, "prfh_i_p_ai_d"},
      {"1110x"_b, "ld1h_z_p_bz_d_64_unscaled"},
      {"1111x"_b, "ldff1h_z_p_bz_d_64_unscaled"},
    },
  },

  { "_vkvgnm",
    {30, 13},
    { {"10"_b, "_vyygqs"},
    },
  },

  { "_vkyngx",
    {23, 22, 19, 18, 17, 16},
    { {"0000x1"_b, "dup_asimdins_dv_v"},
      {"000x10"_b, "dup_asimdins_dv_v"},
      {"0010xx"_b, "dup_asimdins_dv_v"},
      {"001110"_b, "dup_asimdins_dv_v"},
      {"00x10x"_b, "dup_asimdins_dv_v"},
      {"00x111"_b, "dup_asimdins_dv_v"},
      {"01xxxx"_b, "fmaxnm_asimdsamefp16_only"},
      {"11xxxx"_b, "fminnm_asimdsamefp16_only"},
    },
  },

  { "_vllqmp",
    {30, 23, 22, 13, 12, 11, 10},
    { {"000xxxx"_b, "stxp_sp32_ldstexcl"},
      {"001xxxx"_b, "ldxp_lp32_ldstexcl"},
      {"0101111"_b, "cas_c32_ldstexcl"},
      {"0111111"_b, "casa_c32_ldstexcl"},
      {"100xxxx"_b, "stxp_sp64_ldstexcl"},
      {"101xxxx"_b, "ldxp_lp64_ldstexcl"},
      {"1101111"_b, "cas_c64_ldstexcl"},
      {"1111111"_b, "casa_c64_ldstexcl"},
    },
  },

  { "_vlrhpy",
    {30, 23, 22, 13, 4},
    { {"0000x"_b, "ld1sb_z_p_ai_s"},
      {"0001x"_b, "ldff1sb_z_p_ai_s"},
      {"0010x"_b, "ld1rb_z_p_bi_u8"},
      {"0011x"_b, "ld1rb_z_p_bi_u16"},
      {"0100x"_b, "ld1sh_z_p_ai_s"},
      {"0101x"_b, "ldff1sh_z_p_ai_s"},
      {"0110x"_b, "ld1rsw_z_p_bi_s64"},
      {"0111x"_b, "ld1rh_z_p_bi_u16"},
      {"1000x"_b, "ld1sb_z_p_ai_d"},
      {"1001x"_b, "ldff1sb_z_p_ai_d"},
      {"10100"_b, "prfb_i_p_bz_d_64_scaled"},
      {"10110"_b, "prfh_i_p_bz_d_64_scaled"},
      {"1100x"_b, "ld1sh_z_p_ai_d"},
      {"1101x"_b, "ldff1sh_z_p_ai_d"},
      {"1110x"_b, "ld1sh_z_p_bz_d_64_scaled"},
      {"1111x"_b, "ldff1sh_z_p_bz_d_64_scaled"},
    },
  },

  { "_vlrrtz",
    {30, 23, 22},
    { {"001"_b, "bfm_64m_bitfield"},
    },
  },

  { "_vlsmsn",
    {22, 20, 19, 18, 17, 16},
    { {"111000"_b, "fcmle_asisdmiscfp16_fz"},
      {"111001"_b, "frsqrte_asisdmiscfp16_r"},
      {"x00000"_b, "fcmle_asisdmisc_fz"},
      {"x00001"_b, "frsqrte_asisdmisc_r"},
    },
  },

  { "_vlzrlm",
    {23, 22, 20, 19, 13, 11},
    { {"0000x0"_b, "mvni_asimdimm_l_sl"},
      {"00x100"_b, "sri_asimdshf_r"},
      {"00x110"_b, "sqshlu_asimdshf_r"},
      {"010x00"_b, "sri_asimdshf_r"},
      {"010x10"_b, "sqshlu_asimdshf_r"},
      {"011100"_b, "sri_asimdshf_r"},
      {"011110"_b, "sqshlu_asimdshf_r"},
      {"0x1000"_b, "sri_asimdshf_r"},
      {"0x1010"_b, "sqshlu_asimdshf_r"},
    },
  },

  { "_vmjgmg",
    {30, 23, 22},
    { {"000"_b, "stxrb_sr32_ldstexcl"},
      {"001"_b, "ldxrb_lr32_ldstexcl"},
      {"010"_b, "stllrb_sl32_ldstexcl"},
      {"011"_b, "ldlarb_lr32_ldstexcl"},
      {"100"_b, "stxrh_sr32_ldstexcl"},
      {"101"_b, "ldxrh_lr32_ldstexcl"},
      {"110"_b, "stllrh_sl32_ldstexcl"},
      {"111"_b, "ldlarh_lr32_ldstexcl"},
    },
  },

  { "_vmjtrx",
    {23, 22, 12},
    { {"001"_b, "sudot_asimdelem_d"},
      {"011"_b, "bfdot_asimdelem_e"},
      {"101"_b, "usdot_asimdelem_d"},
      {"111"_b, "bfmlal_asimdelem_f"},
      {"xx0"_b, "sdot_asimdelem_d"},
    },
  },

  { "_vmjzyk",
    {30, 23, 22},
    { {"000"_b, "stp_32_ldstpair_off"},
      {"001"_b, "ldp_32_ldstpair_off"},
      {"010"_b, "stp_32_ldstpair_pre"},
      {"011"_b, "ldp_32_ldstpair_pre"},
      {"100"_b, "stgp_64_ldstpair_off"},
      {"101"_b, "ldpsw_64_ldstpair_off"},
      {"110"_b, "stgp_64_ldstpair_pre"},
      {"111"_b, "ldpsw_64_ldstpair_pre"},
    },
  },

  { "_vmplgv",
    {12},
    { {"0"_b, "ld1_asisdlsop_dx1_r1d"},
    },
  },

  { "_vmpnlv",
    {11, 10, 9, 8, 7, 6},
    { {"000000"_b, "wfit_only_systeminstrswithreg"},
    },
  },

  { "_vnpqrh",
    {30, 23, 22},
    { {"000"_b, "stp_s_ldstpair_off"},
      {"001"_b, "ldp_s_ldstpair_off"},
      {"010"_b, "stp_s_ldstpair_pre"},
      {"011"_b, "ldp_s_ldstpair_pre"},
      {"100"_b, "stp_d_ldstpair_off"},
      {"101"_b, "ldp_d_ldstpair_off"},
      {"110"_b, "stp_d_ldstpair_pre"},
      {"111"_b, "ldp_d_ldstpair_pre"},
    },
  },

  { "_vnrnmg",
    {17},
    { {"0"_b, "st4_asisdlse_r4"},
    },
  },

  { "_vpkhvh",
    {17},
    { {"0"_b, "st2_asisdlso_h2_2h"},
    },
  },

  { "_vpkptr",
    {30, 23, 22},
    { {"000"_b, "stnp_32_ldstnapair_offs"},
      {"001"_b, "ldnp_32_ldstnapair_offs"},
      {"010"_b, "stp_32_ldstpair_post"},
      {"011"_b, "ldp_32_ldstpair_post"},
      {"110"_b, "stgp_64_ldstpair_post"},
      {"111"_b, "ldpsw_64_ldstpair_post"},
    },
  },

  { "_vpmxrj",
    {13},
    { {"0"_b, "histcnt_z_p_zz"},
      {"1"_b, "_jxszhy"},
    },
  },

  { "_vppthj",
    {30, 23},
    { {"00"_b, "add_32_addsub_imm"},
      {"10"_b, "sub_32_addsub_imm"},
    },
  },

  { "_vprkpq",
    {13, 12, 11, 10},
    { {"0000"_b, "saddwb_z_zz"},
      {"0001"_b, "saddwt_z_zz"},
      {"0010"_b, "uaddwb_z_zz"},
      {"0011"_b, "uaddwt_z_zz"},
      {"0100"_b, "ssubwb_z_zz"},
      {"0101"_b, "ssubwt_z_zz"},
      {"0110"_b, "usubwb_z_zz"},
      {"0111"_b, "usubwt_z_zz"},
      {"1000"_b, "sqdmullb_z_zz"},
      {"1001"_b, "sqdmullt_z_zz"},
      {"1010"_b, "pmullb_z_zz"},
      {"1011"_b, "pmullt_z_zz"},
      {"1100"_b, "smullb_z_zz"},
      {"1101"_b, "smullt_z_zz"},
      {"1110"_b, "umullb_z_zz"},
      {"1111"_b, "umullt_z_zz"},
    },
  },

  { "_vpxvjs",
    {20, 19, 18, 17, 16},
    { {"00000"_b, "fcvtns_32s_float2int"},
      {"00001"_b, "fcvtnu_32s_float2int"},
      {"00010"_b, "scvtf_s32_float2int"},
      {"00011"_b, "ucvtf_s32_float2int"},
      {"00100"_b, "fcvtas_32s_float2int"},
      {"00101"_b, "fcvtau_32s_float2int"},
      {"00110"_b, "fmov_32s_float2int"},
      {"00111"_b, "fmov_s32_float2int"},
      {"01000"_b, "fcvtps_32s_float2int"},
      {"01001"_b, "fcvtpu_32s_float2int"},
      {"10000"_b, "fcvtms_32s_float2int"},
      {"10001"_b, "fcvtmu_32s_float2int"},
      {"11000"_b, "fcvtzs_32s_float2int"},
      {"11001"_b, "fcvtzu_32s_float2int"},
    },
  },

  { "_vpykkg",
    {23, 22, 10},
    { {"000"_b, "ext_asimdext_only"},
      {"001"_b, "_jnmgrh"},
      {"011"_b, "_vytgtz"},
      {"111"_b, "_jrnlzs"},
    },
  },

  { "_vqlytp",
    {12},
    { {"0"_b, "st3_asisdlsop_dx3_r3d"},
    },
  },

  { "_vqqrjl",
    {23, 22, 20, 19, 13, 11, 10},
    { {"0001001"_b, "shl_asisdshf_r"},
      {"0001101"_b, "sqshl_asisdshf_r"},
      {"001x001"_b, "shl_asisdshf_r"},
      {"001x101"_b, "sqshl_asisdshf_r"},
      {"00xx0x0"_b, "fmls_asisdelem_rh_h"},
      {"01xx001"_b, "shl_asisdshf_r"},
      {"01xx101"_b, "sqshl_asisdshf_r"},
      {"1xxx0x0"_b, "fmls_asisdelem_r_sd"},
      {"xxxx1x0"_b, "sqdmlsl_asisdelem_l"},
    },
  },

  { "_vqvqhp",
    {30, 23, 22},
    { {"000"_b, "str_32_ldst_pos"},
      {"001"_b, "ldr_32_ldst_pos"},
      {"010"_b, "ldrsw_64_ldst_pos"},
      {"100"_b, "str_64_ldst_pos"},
      {"101"_b, "ldr_64_ldst_pos"},
      {"110"_b, "prfm_p_ldst_pos"},
    },
  },

  { "_vqzlzt",
    {30, 23},
    { {"00"_b, "and_64_log_imm"},
      {"01"_b, "movn_64_movewide"},
      {"10"_b, "eor_64_log_imm"},
      {"11"_b, "movz_64_movewide"},
    },
  },

  { "_vsqlkr",
    {23, 22, 20, 19, 18, 17, 16},
    { {"0111001"_b, "frintx_asimdmiscfp16_r"},
      {"0x00001"_b, "frintx_asimdmisc_r"},
      {"1111001"_b, "frinti_asimdmiscfp16_r"},
      {"1x00001"_b, "frinti_asimdmisc_r"},
      {"xx00000"_b, "cmle_asimdmisc_z"},
    },
  },

  { "_vsqpzr",
    {23},
    { {"0"_b, "faddp_asimdsame_only"},
      {"1"_b, "fabd_asimdsame_only"},
    },
  },

  { "_vsvrgt",
    {17},
    { {"0"_b, "fadda_v_p_z"},
    },
  },

  { "_vsvtqz",
    {30, 23, 22},
    { {"00x"_b, "add_64_addsub_imm"},
      {"010"_b, "addg_64_addsub_immtags"},
      {"10x"_b, "sub_64_addsub_imm"},
      {"110"_b, "subg_64_addsub_immtags"},
    },
  },

  { "_vtxyxz",
    {23, 22, 13, 12, 11, 10},
    { {"01x1x0"_b, "fcmla_asimdelem_c_h"},
      {"0x0001"_b, "ushr_asimdshf_r"},
      {"0x0101"_b, "usra_asimdshf_r"},
      {"0x1001"_b, "urshr_asimdshf_r"},
      {"0x1101"_b, "ursra_asimdshf_r"},
      {"10x1x0"_b, "fcmla_asimdelem_c_s"},
      {"xx00x0"_b, "mla_asimdelem_r"},
      {"xx10x0"_b, "umlal_asimdelem_l"},
    },
  },

  { "_vvhzhv",
    {30, 23, 22, 13, 12, 11, 10},
    { {"0000000"_b, "swpb_32_memop"},
      {"000xx10"_b, "strb_32b_ldst_regoff"},
      {"0010000"_b, "swplb_32_memop"},
      {"001xx10"_b, "ldrb_32b_ldst_regoff"},
      {"0100000"_b, "swpab_32_memop"},
      {"010xx10"_b, "ldrsb_64b_ldst_regoff"},
      {"0110000"_b, "swpalb_32_memop"},
      {"011xx10"_b, "ldrsb_32b_ldst_regoff"},
      {"1000000"_b, "swph_32_memop"},
      {"100xx10"_b, "strh_32_ldst_regoff"},
      {"1010000"_b, "swplh_32_memop"},
      {"101xx10"_b, "ldrh_32_ldst_regoff"},
      {"1100000"_b, "swpah_32_memop"},
      {"110xx10"_b, "ldrsh_64_ldst_regoff"},
      {"1110000"_b, "swpalh_32_memop"},
      {"111xx10"_b, "ldrsh_32_ldst_regoff"},
    },
  },

  { "_vvprhx",
    {0},
    { {"0"_b, "blr_64_branch_reg"},
    },
  },

  { "_vvrmvg",
    {12},
    { {"1"_b, "_typysz"},
    },
  },

  { "_vvtnrv",
    {23, 22, 20, 19, 18},
    { {"00000"_b, "orr_z_zi"},
      {"01000"_b, "eor_z_zi"},
      {"10000"_b, "and_z_zi"},
      {"11000"_b, "dupm_z_i"},
    },
  },

  { "_vvxsxt",
    {4},
    { {"0"_b, "ands_p_p_pp_z"},
      {"1"_b, "bics_p_p_pp_z"},
    },
  },

  { "_vxgzqy",
    {22},
    { {"0"_b, "ldrsw_64_ldst_regoff"},
    },
  },

  { "_vxhgzz",
    {23, 22, 12, 11, 10},
    { {"00xxx"_b, "ext_z_zi_des"},
      {"01xxx"_b, "ext_z_zi_con"},
      {"10000"_b, "zip1_z_zz_q"},
      {"10001"_b, "zip2_z_zz_q"},
      {"10010"_b, "uzp1_z_zz_q"},
      {"10011"_b, "uzp2_z_zz_q"},
      {"10110"_b, "trn1_z_zz_q"},
      {"10111"_b, "trn2_z_zz_q"},
    },
  },

  { "_vxsjgg",
    {30, 22, 11},
    { {"001"_b, "_pxnnrz"},
      {"010"_b, "ccmn_32_condcmp_reg"},
      {"011"_b, "ccmn_32_condcmp_imm"},
      {"110"_b, "ccmp_32_condcmp_reg"},
      {"111"_b, "ccmp_32_condcmp_imm"},
    },
  },

  { "_vxsvhs",
    {13, 12},
    { {"00"_b, "adcs_64_addsub_carry"},
    },
  },

  { "_vxylhh",
    {23, 22},
    { {"01"_b, "fcmla_asimdelem_c_h"},
      {"10"_b, "fcmla_asimdelem_c_s"},
    },
  },

  { "_vylhvl",
    {20, 19, 18, 17, 16, 13},
    { {"000000"_b, "fabs_h_floatdp1"},
      {"000010"_b, "fsqrt_h_floatdp1"},
      {"000100"_b, "fcvt_dh_floatdp1"},
      {"001000"_b, "frintp_h_floatdp1"},
      {"001010"_b, "frintz_h_floatdp1"},
      {"001110"_b, "frinti_h_floatdp1"},
    },
  },

  { "_vytgtz",
    {13, 12, 11},
    { {"000"_b, "fmaxnmp_asimdsamefp16_only"},
      {"010"_b, "faddp_asimdsamefp16_only"},
      {"011"_b, "fmul_asimdsamefp16_only"},
      {"100"_b, "fcmge_asimdsamefp16_only"},
      {"101"_b, "facge_asimdsamefp16_only"},
      {"110"_b, "fmaxp_asimdsamefp16_only"},
      {"111"_b, "fdiv_asimdsamefp16_only"},
    },
  },

  { "_vytxll",
    {18, 17, 12},
    { {"000"_b, "st2_asisdlso_d2_2d"},
    },
  },

  { "_vyygqs",
    {23, 22, 20, 19, 12, 11, 10},
    { {"00x1001"_b, "sqshrun_asisdshf_n"},
      {"00x1011"_b, "sqrshrun_asisdshf_n"},
      {"00x1101"_b, "uqshrn_asisdshf_n"},
      {"00x1111"_b, "uqrshrn_asisdshf_n"},
      {"00xx1x0"_b, "fmulx_asisdelem_rh_h"},
      {"010x001"_b, "sqshrun_asisdshf_n"},
      {"010x011"_b, "sqrshrun_asisdshf_n"},
      {"010x101"_b, "uqshrn_asisdshf_n"},
      {"010x111"_b, "uqrshrn_asisdshf_n"},
      {"0111001"_b, "sqshrun_asisdshf_n"},
      {"0111011"_b, "sqrshrun_asisdshf_n"},
      {"0111101"_b, "uqshrn_asisdshf_n"},
      {"0111111"_b, "uqrshrn_asisdshf_n"},
      {"0x10001"_b, "sqshrun_asisdshf_n"},
      {"0x10011"_b, "sqrshrun_asisdshf_n"},
      {"0x10101"_b, "uqshrn_asisdshf_n"},
      {"0x10111"_b, "uqrshrn_asisdshf_n"},
      {"1xxx1x0"_b, "fmulx_asisdelem_r_sd"},
    },
  },

  { "_vyztqx",
    {8},
    { {"0"_b, "tstart_br_systemresult"},
      {"1"_b, "ttest_br_systemresult"},
    },
  },

  { "_vzjvtv",
    {23, 22, 12, 11, 10},
    { {"01001"_b, "bfmmla_z_zzz"},
      {"10001"_b, "fmmla_z_zzz_s"},
      {"11001"_b, "fmmla_z_zzz_d"},
    },
  },

  { "_vzzvlr",
    {23, 22, 20, 19, 18, 16, 13},
    { {"0000000"_b, "_tlzlrj"},
      {"0000001"_b, "_yhxvhy"},
      {"0100000"_b, "_hqhzgj"},
      {"0100001"_b, "_kzrklp"},
      {"100xxx0"_b, "st2_asisdlsop_bx2_r2b"},
      {"100xxx1"_b, "st4_asisdlsop_bx4_r4b"},
      {"1010xx0"_b, "st2_asisdlsop_bx2_r2b"},
      {"1010xx1"_b, "st4_asisdlsop_bx4_r4b"},
      {"10110x0"_b, "st2_asisdlsop_bx2_r2b"},
      {"10110x1"_b, "st4_asisdlsop_bx4_r4b"},
      {"1011100"_b, "st2_asisdlsop_bx2_r2b"},
      {"1011101"_b, "st4_asisdlsop_bx4_r4b"},
      {"1011110"_b, "_mykjss"},
      {"1011111"_b, "_xkkggt"},
      {"110xxx0"_b, "ld2_asisdlsop_bx2_r2b"},
      {"110xxx1"_b, "ld4_asisdlsop_bx4_r4b"},
      {"1110xx0"_b, "ld2_asisdlsop_bx2_r2b"},
      {"1110xx1"_b, "ld4_asisdlsop_bx4_r4b"},
      {"11110x0"_b, "ld2_asisdlsop_bx2_r2b"},
      {"11110x1"_b, "ld4_asisdlsop_bx4_r4b"},
      {"1111100"_b, "ld2_asisdlsop_bx2_r2b"},
      {"1111101"_b, "ld4_asisdlsop_bx4_r4b"},
      {"1111110"_b, "_gvstrp"},
      {"1111111"_b, "_qtgvhn"},
    },
  },

  { "_xgvgmk",
    {23, 22, 4},
    { {"000"_b, "fccmp_s_floatccmp"},
      {"001"_b, "fccmpe_s_floatccmp"},
      {"010"_b, "fccmp_d_floatccmp"},
      {"011"_b, "fccmpe_d_floatccmp"},
      {"110"_b, "fccmp_h_floatccmp"},
      {"111"_b, "fccmpe_h_floatccmp"},
    },
  },

  { "_xhkgqh",
    {30, 23, 22},
    { {"000"_b, "stp_64_ldstpair_off"},
      {"001"_b, "ldp_64_ldstpair_off"},
      {"010"_b, "stp_64_ldstpair_pre"},
      {"011"_b, "ldp_64_ldstpair_pre"},
    },
  },

  { "_xhktsk",
    {22},
    { {"0"_b, "smullt_z_zzi_s"},
      {"1"_b, "smullt_z_zzi_d"},
    },
  },

  { "_xhlhmh",
    {4},
    { {"0"_b, "cmplo_p_p_zi"},
      {"1"_b, "cmpls_p_p_zi"},
    },
  },

  { "_xhltxn",
    {12, 10},
    { {"00"_b, "_jqtltz"},
      {"01"_b, "_rkvyqk"},
      {"10"_b, "_zpnsrv"},
      {"11"_b, "_lhvtrp"},
    },
  },

  { "_xhmpmy",
    {4},
    { {"0"_b, "and_p_p_pp_z"},
      {"1"_b, "bic_p_p_pp_z"},
    },
  },

  { "_xhvtjg",
    {11},
    { {"0"_b, "_mpyklp"},
    },
  },

  { "_xhxrnt",
    {30},
    { {"0"_b, "_zxhhny"},
      {"1"_b, "_lhpgsn"},
    },
  },

  { "_xjghst",
    {13, 12, 11, 10},
    { {"0000"_b, "_kvmrng"},
      {"0001"_b, "_vkyngx"},
      {"0011"_b, "_lxqynh"},
      {"0100"_b, "_kjngjl"},
      {"0101"_b, "_xmqgmz"},
      {"0110"_b, "uzp1_asimdperm_only"},
      {"0111"_b, "_shzysp"},
      {"1000"_b, "_strkph"},
      {"1001"_b, "_jpvljz"},
      {"1010"_b, "trn1_asimdperm_only"},
      {"1011"_b, "_jryylt"},
      {"1100"_b, "_grxzzg"},
      {"1101"_b, "_lnnyzt"},
      {"1110"_b, "zip1_asimdperm_only"},
      {"1111"_b, "_szttjy"},
    },
  },

  { "_xjxppp",
    {1, 0},
    { {"11"_b, "brabz_64_branch_reg"},
    },
  },

  { "_xkkggt",
    {17},
    { {"0"_b, "st4_asisdlsop_bx4_r4b"},
      {"1"_b, "st4_asisdlsop_b4_i4b"},
    },
  },

  { "_xlhjhx",
    {30},
    { {"0"_b, "bl_only_branch_imm"},
      {"1"_b, "_zhrtts"},
    },
  },

  { "_xmqgmz",
    {23, 22},
    { {"01"_b, "fadd_asimdsamefp16_only"},
      {"11"_b, "fsub_asimdsamefp16_only"},
    },
  },

  { "_xmqvpl",
    {12},
    { {"0"_b, "ld1_asisdlsop_dx1_r1d"},
    },
  },

  { "_xmtlmj",
    {23, 22, 20, 19, 11},
    { {"00010"_b, "srshr_asisdshf_r"},
      {"001x0"_b, "srshr_asisdshf_r"},
      {"01xx0"_b, "srshr_asisdshf_r"},
    },
  },

  { "_xmxpnx",
    {10},
    { {"0"_b, "sri_z_zzi"},
      {"1"_b, "sli_z_zzi"},
    },
  },

  { "_xnsrny",
    {30, 23, 22},
    { {"000"_b, "madd_64a_dp_3src"},
      {"001"_b, "smulh_64_dp_3src"},
      {"011"_b, "umulh_64_dp_3src"},
    },
  },

  { "_xpkkpn",
    {17},
    { {"1"_b, "frsqrte_z_z"},
    },
  },

  { "_xpmvjv",
    {13, 12},
    { {"00"_b, "sqshl_asisdsame_only"},
      {"01"_b, "sqrshl_asisdsame_only"},
    },
  },

  { "_xpqglq",
    {4},
    { {"0"_b, "cmpeq_p_p_zi"},
      {"1"_b, "cmpne_p_p_zi"},
    },
  },

  { "_xprlgy",
    {30, 23, 22, 11, 10},
    { {"00010"_b, "str_s_ldst_regoff"},
      {"00110"_b, "ldr_s_ldst_regoff"},
      {"10010"_b, "str_d_ldst_regoff"},
      {"10110"_b, "ldr_d_ldst_regoff"},
    },
  },

  { "_xpvpqq",
    {23, 22, 11, 10, 4, 3, 2},
    { {"0000000"_b, "_hngpxg"},
      {"0010111"_b, "_gnytkh"},
      {"0011111"_b, "_xjxppp"},
      {"0100000"_b, "_nnhprs"},
      {"0110111"_b, "_hmtxlh"},
      {"0111111"_b, "_qtxypt"},
      {"1000000"_b, "_rmltms"},
      {"1010111"_b, "_qqpkkm"},
      {"1011111"_b, "_klnhpj"},
    },
  },

  { "_xqgxjp",
    {18, 17, 16, 13, 12, 11, 10, 9, 7, 6, 5},
    { {"01111000011"_b, "_vyztqx"},
    },
  },

  { "_xqhgkk",
    {30},
    { {"0"_b, "b_only_branch_imm"},
    },
  },

  { "_xqjrgk",
    {12},
    { {"0"_b, "ld4_asisdlsop_dx4_r4d"},
    },
  },

  { "_xrhhjz",
    {11},
    { {"0"_b, "_hzxjsp"},
    },
  },

  { "_xrhmtg",
    {30, 23, 22, 11, 10},
    { {"00000"_b, "stur_s_ldst_unscaled"},
      {"00001"_b, "str_s_ldst_immpost"},
      {"00011"_b, "str_s_ldst_immpre"},
      {"00100"_b, "ldur_s_ldst_unscaled"},
      {"00101"_b, "ldr_s_ldst_immpost"},
      {"00111"_b, "ldr_s_ldst_immpre"},
      {"10000"_b, "stur_d_ldst_unscaled"},
      {"10001"_b, "str_d_ldst_immpost"},
      {"10011"_b, "str_d_ldst_immpre"},
      {"10100"_b, "ldur_d_ldst_unscaled"},
      {"10101"_b, "ldr_d_ldst_immpost"},
      {"10111"_b, "ldr_d_ldst_immpre"},
    },
  },

  { "_xrpmzt",
    {17},
    { {"0"_b, "st4_asisdlsop_hx4_r4h"},
      {"1"_b, "st4_asisdlsop_h4_i4h"},
    },
  },

  { "_xrxvpr",
    {23, 22},
    { {"00"_b, "_spmkmm"},
    },
  },

  { "_xryzqs",
    {30, 23, 22, 13, 12, 11, 10},
    { {"0001111"_b, "caspl_cp32_ldstexcl"},
      {"0011111"_b, "caspal_cp32_ldstexcl"},
      {"0101111"_b, "caslb_c32_ldstexcl"},
      {"0111111"_b, "casalb_c32_ldstexcl"},
      {"1001111"_b, "caspl_cp64_ldstexcl"},
      {"1011111"_b, "caspal_cp64_ldstexcl"},
      {"1101111"_b, "caslh_c32_ldstexcl"},
      {"1111111"_b, "casalh_c32_ldstexcl"},
    },
  },

  { "_xsgxyy",
    {9, 8, 7, 6, 5},
    { {"11111"_b, "autizb_64z_dp_1src"},
    },
  },

  { "_xstkrn",
    {20, 19},
    { {"00"_b, "_hrllsn"},
      {"01"_b, "_kqvljp"},
      {"10"_b, "_lxhlkx"},
      {"11"_b, "_rjysnh"},
    },
  },

  { "_xtgtyz",
    {19, 18, 17, 16},
    { {"0000"_b, "brkb_p_p_p"},
    },
  },

  { "_xtqmyj",
    {30, 23, 22},
    { {"000"_b, "orr_32_log_imm"},
      {"100"_b, "ands_32s_log_imm"},
      {"110"_b, "movk_32_movewide"},
    },
  },

  { "_xtxyxj",
    {4},
    { {"0"_b, "orr_p_p_pp_z"},
      {"1"_b, "orn_p_p_pp_z"},
    },
  },

  { "_xtzlzy",
    {12, 11, 10},
    { {"000"_b, "fadd_z_zz"},
      {"001"_b, "fsub_z_zz"},
      {"010"_b, "fmul_z_zz"},
      {"011"_b, "ftsmul_z_zz"},
      {"110"_b, "frecps_z_zz"},
      {"111"_b, "frsqrts_z_zz"},
    },
  },

  { "_xvlnmy",
    {9, 8, 7, 6, 5},
    { {"11111"_b, "autdza_64z_dp_1src"},
    },
  },

  { "_xvnyxq",
    {30, 23, 13, 4},
    { {"0000"_b, "prfb_i_p_bz_s_x32_scaled"},
      {"0010"_b, "prfh_i_p_bz_s_x32_scaled"},
      {"010x"_b, "ld1sh_z_p_bz_s_x32_scaled"},
      {"011x"_b, "ldff1sh_z_p_bz_s_x32_scaled"},
      {"1000"_b, "prfb_i_p_bz_d_x32_scaled"},
      {"1010"_b, "prfh_i_p_bz_d_x32_scaled"},
      {"110x"_b, "ld1sh_z_p_bz_d_x32_scaled"},
      {"111x"_b, "ldff1sh_z_p_bz_d_x32_scaled"},
    },
  },

  { "_xvppmm",
    {30, 23, 22, 13, 12, 11, 10},
    { {"0xx0xxx"_b, "mla_z_p_zzz"},
      {"0xx1xxx"_b, "mls_z_p_zzz"},
      {"1101110"_b, "usdot_z_zzz_s"},
      {"1xx0000"_b, "smlalb_z_zzz"},
      {"1xx0001"_b, "smlalt_z_zzz"},
      {"1xx0010"_b, "umlalb_z_zzz"},
      {"1xx0011"_b, "umlalt_z_zzz"},
      {"1xx0100"_b, "smlslb_z_zzz"},
      {"1xx0101"_b, "smlslt_z_zzz"},
      {"1xx0110"_b, "umlslb_z_zzz"},
      {"1xx0111"_b, "umlslt_z_zzz"},
      {"1xx1000"_b, "sqdmlalb_z_zzz"},
      {"1xx1001"_b, "sqdmlalt_z_zzz"},
      {"1xx1010"_b, "sqdmlslb_z_zzz"},
      {"1xx1011"_b, "sqdmlslt_z_zzz"},
      {"1xx1100"_b, "sqrdmlah_z_zzz"},
      {"1xx1101"_b, "sqrdmlsh_z_zzz"},
    },
  },

  { "_xxjrsy",
    {23, 22, 9},
    { {"000"_b, "rdffr_p_p_f"},
      {"010"_b, "rdffrs_p_p_f"},
    },
  },

  { "_xxkvsy",
    {30, 22, 11, 10},
    { {"0000"_b, "csel_64_condsel"},
      {"0001"_b, "csinc_64_condsel"},
      {"0111"_b, "_tnxlnl"},
      {"1000"_b, "csinv_64_condsel"},
      {"1001"_b, "csneg_64_condsel"},
      {"1100"_b, "_qjyvln"},
      {"1101"_b, "_nvthzh"},
    },
  },

  { "_xxpqgg",
    {30, 23, 22},
    { {"001"_b, "sbfm_64m_bitfield"},
      {"011"_b, "extr_64_extract"},
      {"101"_b, "ubfm_64m_bitfield"},
    },
  },

  { "_xxpzrl",
    {13},
    { {"0"_b, "mls_asimdelem_r"},
      {"1"_b, "umlsl_asimdelem_l"},
    },
  },

  { "_xxxxlh",
    {4},
    { {"0"_b, "ccmn_64_condcmp_imm"},
    },
  },

  { "_xxyklv",
    {23, 22, 13, 12, 11, 10},
    { {"000000"_b, "tbl_asimdtbl_l3_3"},
      {"000100"_b, "tbx_asimdtbl_l3_3"},
      {"001000"_b, "tbl_asimdtbl_l4_4"},
      {"001100"_b, "tbx_asimdtbl_l4_4"},
      {"xx0110"_b, "uzp2_asimdperm_only"},
      {"xx1010"_b, "trn2_asimdperm_only"},
      {"xx1110"_b, "zip2_asimdperm_only"},
    },
  },

  { "_xygxsv",
    {17},
    { {"0"_b, "ld3_asisdlsop_hx3_r3h"},
      {"1"_b, "ld3_asisdlsop_h3_i3h"},
    },
  },

  { "_xyhmgh",
    {23, 22, 20, 9},
    { {"0000"_b, "_xhmpmy"},
      {"0001"_b, "_qnprqt"},
      {"0010"_b, "_nnzhgm"},
      {"0100"_b, "_vvxsxt"},
      {"0101"_b, "_yzmjhn"},
      {"0110"_b, "_mkgsly"},
      {"1000"_b, "_xtxyxj"},
      {"1001"_b, "_hmtmlq"},
      {"1010"_b, "_xtgtyz"},
      {"1100"_b, "_yynmjl"},
      {"1101"_b, "_sjnspg"},
      {"1110"_b, "_jzjvtv"},
    },
  },

  { "_xyhxzt",
    {22},
    { {"0"_b, "prfm_p_ldst_regoff"},
    },
  },

  { "_xyljvp",
    {30, 23, 22, 11, 10},
    { {"00000"_b, "_yjpstj"},
      {"01000"_b, "csel_64_condsel"},
      {"01001"_b, "csinc_64_condsel"},
      {"01100"_b, "_qghmks"},
      {"01101"_b, "_qzzlpv"},
      {"01110"_b, "_syktsg"},
      {"01111"_b, "_hjtvvm"},
      {"10000"_b, "_pvrylp"},
      {"11000"_b, "csinv_64_condsel"},
      {"11001"_b, "csneg_64_condsel"},
      {"11100"_b, "_kkgpjl"},
      {"11101"_b, "_tjtgjy"},
      {"11110"_b, "_qmzqsy"},
      {"11111"_b, "_nmkqzt"},
    },
  },

  { "_xylmmp",
    {22, 12},
    { {"10"_b, "_nkjgpq"},
    },
  },

  { "_xyzpvp",
    {23, 22, 13},
    { {"100"_b, "fmlsl_asimdelem_lh"},
      {"xx1"_b, "smlsl_asimdelem_l"},
    },
  },

  { "_xzmjxk",
    {30},
    { {"1"_b, "_sntzjg"},
    },
  },

  { "_xznsqh",
    {22, 20, 11},
    { {"000"_b, "cntw_r_s"},
      {"010"_b, "incw_r_rs"},
      {"100"_b, "cntd_r_s"},
      {"110"_b, "incd_r_rs"},
    },
  },

  { "_xzyxnr",
    {30, 23, 22, 11, 10},
    { {"10001"_b, "stg_64spost_ldsttags"},
      {"10010"_b, "stg_64soffset_ldsttags"},
      {"10011"_b, "stg_64spre_ldsttags"},
      {"10100"_b, "ldg_64loffset_ldsttags"},
      {"10101"_b, "stzg_64spost_ldsttags"},
      {"10110"_b, "stzg_64soffset_ldsttags"},
      {"10111"_b, "stzg_64spre_ldsttags"},
      {"11001"_b, "st2g_64spost_ldsttags"},
      {"11010"_b, "st2g_64soffset_ldsttags"},
      {"11011"_b, "st2g_64spre_ldsttags"},
      {"11101"_b, "stz2g_64spost_ldsttags"},
      {"11110"_b, "stz2g_64soffset_ldsttags"},
      {"11111"_b, "stz2g_64spre_ldsttags"},
    },
  },

  { "_xzyylk",
    {20, 19, 18, 17, 16, 13},
    { {"000000"_b, "fabs_s_floatdp1"},
      {"000010"_b, "fsqrt_s_floatdp1"},
      {"000100"_b, "fcvt_ds_floatdp1"},
      {"000110"_b, "fcvt_hs_floatdp1"},
      {"001000"_b, "frintp_s_floatdp1"},
      {"001010"_b, "frintz_s_floatdp1"},
      {"001110"_b, "frinti_s_floatdp1"},
      {"010000"_b, "frint32x_s_floatdp1"},
      {"010010"_b, "frint64x_s_floatdp1"},
    },
  },

  { "_ygjslq",
    {4, 3, 2, 1, 0},
    { {"00000"_b, "fcmp_h_floatcmp"},
      {"01000"_b, "fcmp_hz_floatcmp"},
      {"10000"_b, "fcmpe_h_floatcmp"},
      {"11000"_b, "fcmpe_hz_floatcmp"},
    },
  },

  { "_ygnypk",
    {22, 12},
    { {"10"_b, "_nqlgtn"},
    },
  },

  { "_ygpjrl",
    {13, 12},
    { {"00"_b, "adc_32_addsub_carry"},
    },
  },

  { "_ygxhyg",
    {23, 22, 4},
    { {"000"_b, "fccmp_s_floatccmp"},
      {"001"_b, "fccmpe_s_floatccmp"},
      {"010"_b, "fccmp_d_floatccmp"},
      {"011"_b, "fccmpe_d_floatccmp"},
      {"110"_b, "fccmp_h_floatccmp"},
      {"111"_b, "fccmpe_h_floatccmp"},
    },
  },

  { "_ygyxvx",
    {18, 17},
    { {"00"_b, "ld2_asisdlso_s2_2s"},
    },
  },

  { "_yhlntp",
    {20, 19, 18, 17, 16},
    { {"00000"_b, "fexpa_z_z"},
    },
  },

  { "_yhmlxk",
    {13, 12, 11, 10},
    { {"0000"_b, "decp_z_p_z"},
      {"0010"_b, "decp_r_p_r"},
    },
  },

  { "_yhqyzj",
    {9, 8, 7, 6, 5},
    { {"00000"_b, "fmov_d_floatimm"},
    },
  },

  { "_yhxvhy",
    {17},
    { {"0"_b, "st4_asisdlso_b4_4b"},
    },
  },

  { "_yjjrgg",
    {30},
    { {"0"_b, "cbnz_64_compbranch"},
    },
  },

  { "_yjmngt",
    {30},
    { {"0"_b, "sel_z_p_zz"},
      {"1"_b, "_vpmxrj"},
    },
  },

  { "_yjpstj",
    {13, 12},
    { {"00"_b, "adc_64_addsub_carry"},
    },
  },

  { "_yjsjvt",
    {30, 23, 22, 11, 10},
    { {"00000"_b, "_vxsvhs"},
      {"00001"_b, "_rhzhyz"},
      {"00100"_b, "_zjsgkm"},
      {"00110"_b, "_xxxxlh"},
      {"01100"_b, "_mtjrtt"},
      {"10000"_b, "_yskkjs"},
      {"10100"_b, "_mjxzks"},
      {"10110"_b, "_tpkzxg"},
    },
  },

  { "_yjxshz",
    {30, 23, 22, 11, 10},
    { {"00000"_b, "stlurb_32_ldapstl_unscaled"},
      {"00100"_b, "ldapurb_32_ldapstl_unscaled"},
      {"01000"_b, "ldapursb_64_ldapstl_unscaled"},
      {"01100"_b, "ldapursb_32_ldapstl_unscaled"},
      {"10000"_b, "stlurh_32_ldapstl_unscaled"},
      {"10100"_b, "ldapurh_32_ldapstl_unscaled"},
      {"11000"_b, "ldapursh_64_ldapstl_unscaled"},
      {"11100"_b, "ldapursh_32_ldapstl_unscaled"},
    },
  },

  { "_yjxvkp",
    {18, 17, 12},
    { {"0x0"_b, "st4_asisdlsop_dx4_r4d"},
      {"100"_b, "st4_asisdlsop_dx4_r4d"},
      {"110"_b, "st4_asisdlsop_d4_i4d"},
    },
  },

  { "_yjzknm",
    {13, 12, 11, 10},
    { {"0000"_b, "uqdecp_z_p_z"},
      {"0010"_b, "uqdecp_r_p_r_uw"},
      {"0011"_b, "uqdecp_r_p_r_x"},
    },
  },

  { "_yjztsq",
    {20, 19, 18, 17, 16},
    { {"11111"_b, "st64b_64l_memop"},
    },
  },

  { "_ylhxlt",
    {30},
    { {"0"_b, "ldrsw_64_loadlit"},
      {"1"_b, "prfm_p_loadlit"},
    },
  },

  { "_ylnsvy",
    {20, 19, 18, 17, 16},
    { {"00000"_b, "dup_z_r"},
      {"00100"_b, "insr_z_r"},
      {"10000"_b, "sunpklo_z_z"},
      {"10001"_b, "sunpkhi_z_z"},
      {"10010"_b, "uunpklo_z_z"},
      {"10011"_b, "uunpkhi_z_z"},
      {"10100"_b, "insr_z_v"},
      {"11000"_b, "rev_z_z"},
    },
  },

  { "_ylqnqt",
    {18, 17, 12},
    { {"000"_b, "ld4_asisdlso_d4_4d"},
    },
  },

  { "_ylyskq",
    {13, 12, 11, 10},
    { {"0011"_b, "uqadd_asisdsame_only"},
      {"1010"_b, "_yzqtyl"},
      {"1011"_b, "uqsub_asisdsame_only"},
      {"1101"_b, "cmhi_asisdsame_only"},
      {"1110"_b, "_jxzrxm"},
      {"1111"_b, "cmhs_asisdsame_only"},
    },
  },

  { "_ymgrgx",
    {22, 20, 19, 18, 17, 16},
    { {"111001"_b, "ucvtf_asisdmiscfp16_r"},
      {"x00001"_b, "ucvtf_asisdmisc_r"},
      {"x10000"_b, "faddp_asisdpair_only_sd"},
    },
  },

  { "_ymhgxg",
    {30, 13},
    { {"00"_b, "_yrmmmg"},
      {"01"_b, "_sghgtk"},
      {"10"_b, "_nxjkqs"},
      {"11"_b, "_yvyhlh"},
    },
  },

  { "_ymhkrx",
    {30, 23, 22, 13, 4},
    { {"0000x"_b, "ld1b_z_p_ai_s"},
      {"0001x"_b, "ldff1b_z_p_ai_s"},
      {"0010x"_b, "ld1rb_z_p_bi_u32"},
      {"0011x"_b, "ld1rb_z_p_bi_u64"},
      {"0100x"_b, "ld1h_z_p_ai_s"},
      {"0101x"_b, "ldff1h_z_p_ai_s"},
      {"0110x"_b, "ld1rh_z_p_bi_u32"},
      {"0111x"_b, "ld1rh_z_p_bi_u64"},
      {"1000x"_b, "ld1b_z_p_ai_d"},
      {"1001x"_b, "ldff1b_z_p_ai_d"},
      {"10100"_b, "prfw_i_p_bz_d_64_scaled"},
      {"10110"_b, "prfd_i_p_bz_d_64_scaled"},
      {"1100x"_b, "ld1h_z_p_ai_d"},
      {"1101x"_b, "ldff1h_z_p_ai_d"},
      {"1110x"_b, "ld1h_z_p_bz_d_64_scaled"},
      {"1111x"_b, "ldff1h_z_p_bz_d_64_scaled"},
    },
  },

  { "_ymkthj",
    {20, 9, 4},
    { {"000"_b, "uzp2_p_pp"},
    },
  },

  { "_ympyng",
    {30, 23, 22, 13},
    { {"0000"_b, "ld1sh_z_p_br_s64"},
      {"0001"_b, "ldff1sh_z_p_br_s64"},
      {"0010"_b, "ld1w_z_p_br_u32"},
      {"0011"_b, "ldff1w_z_p_br_u32"},
      {"0100"_b, "ld1sb_z_p_br_s64"},
      {"0101"_b, "ldff1sb_z_p_br_s64"},
      {"0110"_b, "ld1sb_z_p_br_s16"},
      {"0111"_b, "ldff1sb_z_p_br_s16"},
      {"1001"_b, "stnt1w_z_p_br_contiguous"},
      {"1011"_b, "st3w_z_p_br_contiguous"},
      {"10x0"_b, "st1w_z_p_br"},
      {"1100"_b, "str_z_bi"},
      {"1101"_b, "stnt1d_z_p_br_contiguous"},
      {"1111"_b, "st3d_z_p_br_contiguous"},
    },
  },

  { "_ymznlj",
    {13, 10},
    { {"00"_b, "_vgrtjz"},
      {"01"_b, "_kxjgsz"},
      {"10"_b, "_vmjtrx"},
      {"11"_b, "_tgmljr"},
    },
  },

  { "_ynnrny",
    {18, 17},
    { {"00"_b, "_jplmmr"},
    },
  },

  { "_ynqsgl",
    {17},
    { {"0"_b, "ld4_asisdlso_h4_4h"},
    },
  },

  { "_ypjyqh",
    {9, 8, 7, 6, 5, 0},
    { {"111110"_b, "drps_64e_branch_reg"},
    },
  },

  { "_yplktv",
    {13, 12, 11, 10},
    { {"0001"_b, "sub_asisdsame_only"},
      {"0010"_b, "_llxlqz"},
      {"0011"_b, "cmeq_asisdsame_only"},
      {"0110"_b, "_pxkqxn"},
      {"1010"_b, "_rhvksm"},
      {"1101"_b, "sqrdmulh_asisdsame_only"},
      {"1110"_b, "_gkkpjz"},
    },
  },

  { "_yppszx",
    {23, 22, 10},
    { {"100"_b, "umlslb_z_zzzi_s"},
      {"101"_b, "umlslt_z_zzzi_s"},
      {"110"_b, "umlslb_z_zzzi_d"},
      {"111"_b, "umlslt_z_zzzi_d"},
    },
  },

  { "_yppyky",
    {30, 13},
    { {"00"_b, "_gyrjrm"},
      {"01"_b, "_hhkqtn"},
      {"10"_b, "_jgmlpk"},
      {"11"_b, "_tzzssm"},
    },
  },

  { "_ypqgyp",
    {22},
    { {"0"_b, "ldrsw_64_ldst_regoff"},
    },
  },

  { "_ypznsm",
    {23},
    { {"0"_b, "fmaxnm_asimdsame_only"},
      {"1"_b, "fminnm_asimdsame_only"},
    },
  },

  { "_yqmqzp",
    {18, 17, 12},
    { {"000"_b, "st1_asisdlso_d1_1d"},
    },
  },

  { "_yqmvxk",
    {11, 10, 9, 8, 7, 6},
    { {"000001"_b, "tcommit_only_barriers"},
      {"xx1000"_b, "dsb_bon_barriers"},
      {"xxxx10"_b, "dmb_bo_barriers"},
      {"xxxx11"_b, "sb_only_barriers"},
    },
  },

  { "_yqsgrt",
    {23, 22, 20, 19, 16, 13, 12},
    { {"0000000"_b, "_znmhps"},
      {"0000010"_b, "_zssjpv"},
      {"0000011"_b, "_smqvrs"},
      {"0100000"_b, "_jrgzxt"},
      {"0100010"_b, "_ppllxt"},
      {"0100011"_b, "_hqlskj"},
      {"100xx00"_b, "st3_asisdlsep_r3_r"},
      {"100xx10"_b, "st1_asisdlsep_r3_r3"},
      {"100xx11"_b, "st1_asisdlsep_r1_r1"},
      {"1010x00"_b, "st3_asisdlsep_r3_r"},
      {"1010x10"_b, "st1_asisdlsep_r3_r3"},
      {"1010x11"_b, "st1_asisdlsep_r1_r1"},
      {"1011000"_b, "st3_asisdlsep_r3_r"},
      {"1011010"_b, "st1_asisdlsep_r3_r3"},
      {"1011011"_b, "st1_asisdlsep_r1_r1"},
      {"1011100"_b, "_ngxkmp"},
      {"1011110"_b, "_qgryzh"},
      {"1011111"_b, "_tjltls"},
      {"110xx00"_b, "ld3_asisdlsep_r3_r"},
      {"110xx10"_b, "ld1_asisdlsep_r3_r3"},
      {"110xx11"_b, "ld1_asisdlsep_r1_r1"},
      {"1110x00"_b, "ld3_asisdlsep_r3_r"},
      {"1110x10"_b, "ld1_asisdlsep_r3_r3"},
      {"1110x11"_b, "ld1_asisdlsep_r1_r1"},
      {"1111000"_b, "ld3_asisdlsep_r3_r"},
      {"1111010"_b, "ld1_asisdlsep_r3_r3"},
      {"1111011"_b, "ld1_asisdlsep_r1_r1"},
      {"1111100"_b, "_zzgrjz"},
      {"1111110"_b, "_phtnny"},
      {"1111111"_b, "_txjyxr"},
    },
  },

  { "_yqvqtx",
    {30, 23, 22, 20, 13},
    { {"00001"_b, "ld1rob_z_p_bi_u8"},
      {"000x0"_b, "ld1rob_z_p_br_contiguous"},
      {"01001"_b, "ld1roh_z_p_bi_u16"},
      {"010x0"_b, "ld1roh_z_p_br_contiguous"},
    },
  },

  { "_yqxnzl",
    {11, 10},
    { {"00"_b, "sqdmulh_z_zz"},
      {"01"_b, "sqrdmulh_z_zz"},
    },
  },

  { "_yrgnqz",
    {13, 12},
    { {"00"_b, "sshl_asisdsame_only"},
      {"01"_b, "srshl_asisdsame_only"},
    },
  },

  { "_yrlzqp",
    {22, 13, 12},
    { {"000"_b, "ldapr_64l_memop"},
    },
  },

  { "_yrmmmg",
    {4},
    { {"0"_b, "cmphs_p_p_zi"},
      {"1"_b, "cmphi_p_p_zi"},
    },
  },

  { "_yrrppk",
    {20, 19, 18, 17, 16},
    { {"00000"_b, "fcvtns_32d_float2int"},
      {"00001"_b, "fcvtnu_32d_float2int"},
      {"00010"_b, "scvtf_d32_float2int"},
      {"00011"_b, "ucvtf_d32_float2int"},
      {"00100"_b, "fcvtas_32d_float2int"},
      {"00101"_b, "fcvtau_32d_float2int"},
      {"01000"_b, "fcvtps_32d_float2int"},
      {"01001"_b, "fcvtpu_32d_float2int"},
      {"10000"_b, "fcvtms_32d_float2int"},
      {"10001"_b, "fcvtmu_32d_float2int"},
      {"11000"_b, "fcvtzs_32d_float2int"},
      {"11001"_b, "fcvtzu_32d_float2int"},
      {"11110"_b, "fjcvtzs_32d_float2int"},
    },
  },

  { "_ysjqhn",
    {30, 23, 22},
    { {"00x"_b, "adds_64_addsub_shift"},
      {"010"_b, "adds_64_addsub_shift"},
      {"10x"_b, "subs_64_addsub_shift"},
      {"110"_b, "subs_64_addsub_shift"},
    },
  },

  { "_yskkjs",
    {13, 12},
    { {"00"_b, "sbcs_64_addsub_carry"},
    },
  },

  { "_yszjsm",
    {12, 11, 10},
    { {"000"_b, "sdot_z_zzz"},
      {"001"_b, "udot_z_zzz"},
      {"010"_b, "sqdmlalbt_z_zzz"},
      {"011"_b, "sqdmlslbt_z_zzz"},
      {"1xx"_b, "cdot_z_zzz"},
    },
  },

  { "_ytkjxx",
    {30, 23, 22, 13, 4},
    { {"00x0x"_b, "ld1w_z_p_bz_s_x32_scaled"},
      {"00x1x"_b, "ldff1w_z_p_bz_s_x32_scaled"},
      {"0100x"_b, "ldr_z_bi"},
      {"01100"_b, "prfw_i_p_bi_s"},
      {"01110"_b, "prfd_i_p_bi_s"},
      {"10x0x"_b, "ld1w_z_p_bz_d_x32_scaled"},
      {"10x1x"_b, "ldff1w_z_p_bz_d_x32_scaled"},
      {"11x0x"_b, "ld1d_z_p_bz_d_x32_scaled"},
      {"11x1x"_b, "ldff1d_z_p_bz_d_x32_scaled"},
    },
  },

  { "_ytsghm",
    {30, 23, 22},
    { {"000"_b, "msub_32a_dp_3src"},
    },
  },

  { "_ytvtqn",
    {30, 23, 22, 20, 13},
    { {"00001"_b, "ld1sh_z_p_bi_s64"},
      {"00011"_b, "ldnf1sh_z_p_bi_s64"},
      {"00101"_b, "ld1w_z_p_bi_u32"},
      {"00111"_b, "ldnf1w_z_p_bi_u32"},
      {"01001"_b, "ld1sb_z_p_bi_s64"},
      {"01011"_b, "ldnf1sb_z_p_bi_s64"},
      {"01101"_b, "ld1sb_z_p_bi_s16"},
      {"01111"_b, "ldnf1sb_z_p_bi_s16"},
      {"100x0"_b, "st1w_z_p_bz_d_x32_unscaled"},
      {"100x1"_b, "st1w_z_p_bz_d_64_unscaled"},
      {"101x0"_b, "st1w_z_p_bz_s_x32_unscaled"},
      {"101x1"_b, "st1w_z_p_ai_d"},
      {"110x0"_b, "st1d_z_p_bz_d_x32_unscaled"},
      {"110x1"_b, "st1d_z_p_bz_d_64_unscaled"},
      {"111x1"_b, "st1d_z_p_ai_d"},
    },
  },

  { "_ytvxsl",
    {30, 23, 22},
    { {"000"_b, "stlxrb_sr32_ldstexcl"},
      {"001"_b, "ldaxrb_lr32_ldstexcl"},
      {"010"_b, "stlrb_sl32_ldstexcl"},
      {"011"_b, "ldarb_lr32_ldstexcl"},
      {"100"_b, "stlxrh_sr32_ldstexcl"},
      {"101"_b, "ldaxrh_lr32_ldstexcl"},
      {"110"_b, "stlrh_sl32_ldstexcl"},
      {"111"_b, "ldarh_lr32_ldstexcl"},
    },
  },

  { "_yvgqjx",
    {13, 12, 5},
    { {"010"_b, "_tnzytv"},
      {"011"_b, "_vmpnlv"},
      {"100"_b, "_hhhqjk"},
      {"101"_b, "_tkzqqp"},
      {"110"_b, "_sphpkr"},
      {"111"_b, "_spglxn"},
    },
  },

  { "_yvhnlk",
    {30, 23, 22, 13, 12, 11, 10},
    { {"0001111"_b, "casp_cp32_ldstexcl"},
      {"0011111"_b, "caspa_cp32_ldstexcl"},
      {"0101111"_b, "casb_c32_ldstexcl"},
      {"0111111"_b, "casab_c32_ldstexcl"},
      {"1001111"_b, "casp_cp64_ldstexcl"},
      {"1011111"_b, "caspa_cp64_ldstexcl"},
      {"1101111"_b, "cash_c32_ldstexcl"},
      {"1111111"_b, "casah_c32_ldstexcl"},
    },
  },

  { "_yvlhjg",
    {23},
    { {"0"_b, "frecps_asimdsame_only"},
      {"1"_b, "frsqrts_asimdsame_only"},
    },
  },

  { "_yvnjkr",
    {9, 8, 7, 6, 5},
    { {"11111"_b, "autdzb_64z_dp_1src"},
    },
  },

  { "_yvptvx",
    {23, 12, 11, 10},
    { {"0000"_b, "sqshrnb_z_zi"},
      {"0001"_b, "sqshrnt_z_zi"},
      {"0010"_b, "sqrshrnb_z_zi"},
      {"0011"_b, "sqrshrnt_z_zi"},
      {"0100"_b, "uqshrnb_z_zi"},
      {"0101"_b, "uqshrnt_z_zi"},
      {"0110"_b, "uqrshrnb_z_zi"},
      {"0111"_b, "uqrshrnt_z_zi"},
    },
  },

  { "_yvxgrr",
    {23, 22, 20, 19, 18, 17, 16},
    { {"0111001"_b, "frintm_asimdmiscfp16_r"},
      {"0x00001"_b, "frintm_asimdmisc_r"},
      {"1111001"_b, "frintz_asimdmiscfp16_r"},
      {"1x00001"_b, "frintz_asimdmisc_r"},
      {"xx00000"_b, "cmeq_asimdmisc_z"},
    },
  },

  { "_yvygml",
    {30},
    { {"0"_b, "_jkrlsg"},
      {"1"_b, "_vvrmvg"},
    },
  },

  { "_yvyhlh",
    {23, 22, 12, 11, 10},
    { {"0x000"_b, "fmul_z_zzi_h"},
      {"10000"_b, "fmul_z_zzi_s"},
      {"11000"_b, "fmul_z_zzi_d"},
    },
  },

  { "_yvyxkx",
    {10},
    { {"0"_b, "sha512su0_vv2_cryptosha512_2"},
      {"1"_b, "sm4e_vv4_cryptosha512_2"},
    },
  },

  { "_yxhrpk",
    {23, 22},
    { {"00"_b, "fmlal2_asimdsame_f"},
      {"10"_b, "fmlsl2_asimdsame_f"},
    },
  },

  { "_yxmkzr",
    {12},
    { {"0"_b, "st1_asisdlsop_dx1_r1d"},
    },
  },

  { "_yxnslx",
    {23, 22},
    { {"00"_b, "adr_z_az_d_s32_scaled"},
      {"01"_b, "adr_z_az_d_u32_scaled"},
      {"1x"_b, "adr_z_az_sd_same_scaled"},
    },
  },

  { "_yykhjv",
    {23, 22, 13, 12, 11, 10},
    { {"000110"_b, "smmla_z_zzz"},
      {"0x1000"_b, "sshllb_z_zi"},
      {"0x1001"_b, "sshllt_z_zi"},
      {"0x1010"_b, "ushllb_z_zi"},
      {"0x1011"_b, "ushllt_z_zi"},
      {"100110"_b, "usmmla_z_zzz"},
      {"110110"_b, "ummla_z_zzz"},
      {"xx0000"_b, "saddlbt_z_zz"},
      {"xx0010"_b, "ssublbt_z_zz"},
      {"xx0011"_b, "ssubltb_z_zz"},
      {"xx0100"_b, "eorbt_z_zz"},
      {"xx0101"_b, "eortb_z_zz"},
      {"xx1100"_b, "bext_z_zz"},
      {"xx1101"_b, "bdep_z_zz"},
      {"xx1110"_b, "bgrp_z_zz"},
    },
  },

  { "_yynmjl",
    {4},
    { {"0"_b, "orrs_p_p_pp_z"},
      {"1"_b, "orns_p_p_pp_z"},
    },
  },

  { "_yyrkmn",
    {17, 16, 9, 8, 7, 6, 5},
    { {"0000000"_b, "aesmc_z_z"},
      {"10xxxxx"_b, "aese_z_zz"},
      {"11xxxxx"_b, "sm4e_z_zz"},
    },
  },

  { "_yytvxh",
    {30, 23, 22, 13, 4},
    { {"00000"_b, "prfw_i_p_br_s"},
      {"00010"_b, "prfw_i_p_ai_s"},
      {"0010x"_b, "ld1rw_z_p_bi_u32"},
      {"0011x"_b, "ld1rw_z_p_bi_u64"},
      {"01000"_b, "prfd_i_p_br_s"},
      {"01010"_b, "prfd_i_p_ai_s"},
      {"0110x"_b, "ld1rsb_z_p_bi_s16"},
      {"0111x"_b, "ld1rd_z_p_bi_u64"},
      {"1000x"_b, "ldnt1w_z_p_ar_d_64_unscaled"},
      {"10010"_b, "prfw_i_p_ai_d"},
      {"1010x"_b, "ld1w_z_p_bz_d_64_unscaled"},
      {"1011x"_b, "ldff1w_z_p_bz_d_64_unscaled"},
      {"1100x"_b, "ldnt1d_z_p_ar_d_64_unscaled"},
      {"11010"_b, "prfd_i_p_ai_d"},
      {"1110x"_b, "ld1d_z_p_bz_d_64_unscaled"},
      {"1111x"_b, "ldff1d_z_p_bz_d_64_unscaled"},
    },
  },

  { "_yyyshx",
    {30, 13, 4},
    { {"000"_b, "cmphs_p_p_zz"},
      {"001"_b, "cmphi_p_p_zz"},
      {"010"_b, "cmpeq_p_p_zw"},
      {"011"_b, "cmpne_p_p_zw"},
      {"1xx"_b, "fcmla_z_p_zzz"},
    },
  },

  { "_yzmjhn",
    {4},
    { {"0"_b, "eors_p_p_pp_z"},
    },
  },

  { "_yzqtyl",
    {20, 19, 18, 17, 16},
    { {"00001"_b, "sqxtun_asisdmisc_n"},
    },
  },

  { "_yzzlxs",
    {23, 4},
    { {"00"_b, "_mpgrgp"},
    },
  },

  { "_zgjpym",
    {23, 22, 20, 19, 11},
    { {"00010"_b, "srsra_asisdshf_r"},
      {"001x0"_b, "srsra_asisdshf_r"},
      {"01xx0"_b, "srsra_asisdshf_r"},
    },
  },

  { "_zglksl",
    {30, 23, 22, 13, 12, 11, 10},
    { {"1101001"_b, "ummla_asimdsame2_g"},
      {"xxx0001"_b, "sqrdmlah_asimdsame2_only"},
      {"xxx0011"_b, "sqrdmlsh_asimdsame2_only"},
      {"xxx0101"_b, "udot_asimdsame2_d"},
    },
  },

  { "_zgysvr",
    {30, 13},
    { {"00"_b, "_xpqglq"},
      {"10"_b, "_xstkrn"},
      {"11"_b, "_zjzmvh"},
    },
  },

  { "_zgzlhq",
    {17},
    { {"0"_b, "ld1_asisdlso_b1_1b"},
    },
  },

  { "_zhkjzg",
    {23, 22, 13},
    { {"000"_b, "fmls_asimdelem_rh_h"},
      {"1x0"_b, "fmls_asimdelem_r_sd"},
      {"xx1"_b, "sqdmlsl_asimdelem_l"},
    },
  },

  { "_zhpxqz",
    {9, 8, 7, 6, 5},
    { {"00000"_b, "fmov_h_floatimm"},
    },
  },

  { "_zhrtts",
    {23, 22},
    { {"00"_b, "_qlqhzg"},
    },
  },

  { "_zjgvyp",
    {30, 13, 12, 11, 10},
    { {"00000"_b, "_ghnljt"},
    },
  },

  { "_zjjxjl",
    {9},
    { {"0"_b, "pnext_p_p_p"},
    },
  },

  { "_zjsgkm",
    {4},
    { {"0"_b, "ccmn_64_condcmp_reg"},
    },
  },

  { "_zjslnr",
    {30, 23, 22},
    { {"000"_b, "sbfm_32m_bitfield"},
      {"010"_b, "extr_32_extract"},
      {"100"_b, "ubfm_32m_bitfield"},
    },
  },

  { "_zjzmvh",
    {23, 22, 20, 19, 18, 17, 16},
    { {"0001010"_b, "fcvtx_z_p_z_d2s"},
      {"0011xx0"_b, "flogb_z_p_z"},
      {"0110010"_b, "scvtf_z_p_z_h2fp16"},
      {"0110011"_b, "ucvtf_z_p_z_h2fp16"},
      {"0110100"_b, "scvtf_z_p_z_w2fp16"},
      {"0110101"_b, "ucvtf_z_p_z_w2fp16"},
      {"0110110"_b, "scvtf_z_p_z_x2fp16"},
      {"0110111"_b, "ucvtf_z_p_z_x2fp16"},
      {"0111010"_b, "fcvtzs_z_p_z_fp162h"},
      {"0111011"_b, "fcvtzu_z_p_z_fp162h"},
      {"0111100"_b, "fcvtzs_z_p_z_fp162w"},
      {"0111101"_b, "fcvtzu_z_p_z_fp162w"},
      {"0111110"_b, "fcvtzs_z_p_z_fp162x"},
      {"0111111"_b, "fcvtzu_z_p_z_fp162x"},
      {"1001000"_b, "fcvt_z_p_z_s2h"},
      {"1001001"_b, "fcvt_z_p_z_h2s"},
      {"1001010"_b, "bfcvt_z_p_z_s2bf"},
      {"1010100"_b, "scvtf_z_p_z_w2s"},
      {"1010101"_b, "ucvtf_z_p_z_w2s"},
      {"1011100"_b, "fcvtzs_z_p_z_s2w"},
      {"1011101"_b, "fcvtzu_z_p_z_s2w"},
      {"1101000"_b, "fcvt_z_p_z_d2h"},
      {"1101001"_b, "fcvt_z_p_z_h2d"},
      {"1101010"_b, "fcvt_z_p_z_d2s"},
      {"1101011"_b, "fcvt_z_p_z_s2d"},
      {"1110000"_b, "scvtf_z_p_z_w2d"},
      {"1110001"_b, "ucvtf_z_p_z_w2d"},
      {"1110100"_b, "scvtf_z_p_z_x2s"},
      {"1110101"_b, "ucvtf_z_p_z_x2s"},
      {"1110110"_b, "scvtf_z_p_z_x2d"},
      {"1110111"_b, "ucvtf_z_p_z_x2d"},
      {"1111000"_b, "fcvtzs_z_p_z_d2w"},
      {"1111001"_b, "fcvtzu_z_p_z_d2w"},
      {"1111100"_b, "fcvtzs_z_p_z_s2x"},
      {"1111101"_b, "fcvtzu_z_p_z_s2x"},
      {"1111110"_b, "fcvtzs_z_p_z_d2x"},
      {"1111111"_b, "fcvtzu_z_p_z_d2x"},
      {"xx00000"_b, "frintn_z_p_z"},
      {"xx00001"_b, "frintp_z_p_z"},
      {"xx00010"_b, "frintm_z_p_z"},
      {"xx00011"_b, "frintz_z_p_z"},
      {"xx00100"_b, "frinta_z_p_z"},
      {"xx00110"_b, "frintx_z_p_z"},
      {"xx00111"_b, "frinti_z_p_z"},
      {"xx01100"_b, "frecpx_z_p_z"},
      {"xx01101"_b, "fsqrt_z_p_z"},
    },
  },

  { "_zkhjsp",
    {11},
    { {"0"_b, "sqdmulh_z_zzi_h"},
      {"1"_b, "mul_z_zzi_h"},
    },
  },

  { "_zkqtrj",
    {30},
    { {"0"_b, "b_only_branch_imm"},
    },
  },

  { "_zkttzl",
    {23, 22, 20, 19, 18, 16, 13},
    { {"0000000"_b, "_tsvsgh"},
      {"0000001"_b, "_rkrltp"},
      {"0100000"_b, "_zgzlhq"},
      {"0100001"_b, "_nrssjz"},
      {"100xxx0"_b, "st1_asisdlsop_bx1_r1b"},
      {"100xxx1"_b, "st3_asisdlsop_bx3_r3b"},
      {"1010xx0"_b, "st1_asisdlsop_bx1_r1b"},
      {"1010xx1"_b, "st3_asisdlsop_bx3_r3b"},
      {"10110x0"_b, "st1_asisdlsop_bx1_r1b"},
      {"10110x1"_b, "st3_asisdlsop_bx3_r3b"},
      {"1011100"_b, "st1_asisdlsop_bx1_r1b"},
      {"1011101"_b, "st3_asisdlsop_bx3_r3b"},
      {"1011110"_b, "_rnypvh"},
      {"1011111"_b, "_nxjgmm"},
      {"110xxx0"_b, "ld1_asisdlsop_bx1_r1b"},
      {"110xxx1"_b, "ld3_asisdlsop_bx3_r3b"},
      {"1110xx0"_b, "ld1_asisdlsop_bx1_r1b"},
      {"1110xx1"_b, "ld3_asisdlsop_bx3_r3b"},
      {"11110x0"_b, "ld1_asisdlsop_bx1_r1b"},
      {"11110x1"_b, "ld3_asisdlsop_bx3_r3b"},
      {"1111100"_b, "ld1_asisdlsop_bx1_r1b"},
      {"1111101"_b, "ld3_asisdlsop_bx3_r3b"},
      {"1111110"_b, "_qqtpln"},
      {"1111111"_b, "_glhxyj"},
    },
  },

  { "_zlmgyp",
    {23, 22, 13},
    { {"000"_b, "fmla_asimdelem_rh_h"},
      {"1x0"_b, "fmla_asimdelem_r_sd"},
      {"xx1"_b, "sqdmlal_asimdelem_l"},
    },
  },

  { "_zmkqxl",
    {23, 10},
    { {"00"_b, "adclb_z_zzz"},
      {"01"_b, "adclt_z_zzz"},
      {"10"_b, "sbclb_z_zzz"},
      {"11"_b, "sbclt_z_zzz"},
    },
  },

  { "_zmpzkg",
    {23, 22, 20, 19, 13, 11},
    { {"0000x0"_b, "orr_asimdimm_l_sl"},
      {"00x100"_b, "shl_asimdshf_r"},
      {"00x110"_b, "sqshl_asimdshf_r"},
      {"010x00"_b, "shl_asimdshf_r"},
      {"010x10"_b, "sqshl_asimdshf_r"},
      {"011100"_b, "shl_asimdshf_r"},
      {"011110"_b, "sqshl_asimdshf_r"},
      {"0x1000"_b, "shl_asimdshf_r"},
      {"0x1010"_b, "sqshl_asimdshf_r"},
    },
  },

  { "_zmtkvx",
    {13, 10},
    { {"00"_b, "_rhpmjz"},
    },
  },

  { "_zmzxjm",
    {17},
    { {"0"_b, "faddv_v_p_z"},
    },
  },

  { "_znmhps",
    {18, 17},
    { {"00"_b, "st3_asisdlse_r3"},
    },
  },

  { "_zpmkvt",
    {12},
    { {"1"_b, "_vqqrjl"},
    },
  },

  { "_zpnsrv",
    {23, 22, 13},
    { {"000"_b, "fmul_asimdelem_rh_h"},
      {"1x0"_b, "fmul_asimdelem_r_sd"},
      {"xx1"_b, "sqdmull_asimdelem_l"},
    },
  },

  { "_zppjvk",
    {12},
    { {"0"_b, "ld2_asisdlsop_dx2_r2d"},
    },
  },

  { "_zpsymj",
    {22, 13, 12},
    { {"000"_b, "swp_64_memop"},
      {"001"_b, "_yjztsq"},
      {"010"_b, "st64bv0_64_memop"},
      {"011"_b, "st64bv_64_memop"},
      {"100"_b, "swpl_64_memop"},
    },
  },

  { "_zpzghs",
    {30, 23, 22},
    { {"000"_b, "stnp_q_ldstnapair_offs"},
      {"001"_b, "ldnp_q_ldstnapair_offs"},
      {"010"_b, "stp_q_ldstpair_post"},
      {"011"_b, "ldp_q_ldstpair_post"},
    },
  },

  { "_zqltpy",
    {9, 8, 7, 6, 5},
    { {"00000"_b, "fmov_s_floatimm"},
    },
  },

  { "_zqmmsk",
    {30, 23, 22, 13, 12, 11, 10},
    { {"0000000"_b, "ldaddb_32_memop"},
      {"0000100"_b, "ldclrb_32_memop"},
      {"0001000"_b, "ldeorb_32_memop"},
      {"0001100"_b, "ldsetb_32_memop"},
      {"000xx10"_b, "strb_32b_ldst_regoff"},
      {"0010000"_b, "ldaddlb_32_memop"},
      {"0010100"_b, "ldclrlb_32_memop"},
      {"0011000"_b, "ldeorlb_32_memop"},
      {"0011100"_b, "ldsetlb_32_memop"},
      {"001xx10"_b, "ldrb_32b_ldst_regoff"},
      {"0100000"_b, "ldaddab_32_memop"},
      {"0100100"_b, "ldclrab_32_memop"},
      {"0101000"_b, "ldeorab_32_memop"},
      {"0101100"_b, "ldsetab_32_memop"},
      {"010xx10"_b, "ldrsb_64b_ldst_regoff"},
      {"0110000"_b, "ldaddalb_32_memop"},
      {"0110100"_b, "ldclralb_32_memop"},
      {"0111000"_b, "ldeoralb_32_memop"},
      {"0111100"_b, "ldsetalb_32_memop"},
      {"011xx10"_b, "ldrsb_32b_ldst_regoff"},
      {"1000000"_b, "ldaddh_32_memop"},
      {"1000100"_b, "ldclrh_32_memop"},
      {"1001000"_b, "ldeorh_32_memop"},
      {"1001100"_b, "ldseth_32_memop"},
      {"100xx10"_b, "strh_32_ldst_regoff"},
      {"1010000"_b, "ldaddlh_32_memop"},
      {"1010100"_b, "ldclrlh_32_memop"},
      {"1011000"_b, "ldeorlh_32_memop"},
      {"1011100"_b, "ldsetlh_32_memop"},
      {"101xx10"_b, "ldrh_32_ldst_regoff"},
      {"1100000"_b, "ldaddah_32_memop"},
      {"1100100"_b, "ldclrah_32_memop"},
      {"1101000"_b, "ldeorah_32_memop"},
      {"1101100"_b, "ldsetah_32_memop"},
      {"110xx10"_b, "ldrsh_64_ldst_regoff"},
      {"1110000"_b, "ldaddalh_32_memop"},
      {"1110100"_b, "ldclralh_32_memop"},
      {"1111000"_b, "ldeoralh_32_memop"},
      {"1111100"_b, "ldsetalh_32_memop"},
      {"111xx10"_b, "ldrsh_32_ldst_regoff"},
    },
  },

  { "_zqmrhp",
    {23, 22, 4, 3, 2, 1, 0},
    { {"0000000"_b, "wrffr_f_p"},
    },
  },

  { "_zrmgjx",
    {30, 23, 22, 13, 4},
    { {"01000"_b, "ldr_p_bi"},
      {"01100"_b, "prfb_i_p_bi_s"},
      {"01110"_b, "prfh_i_p_bi_s"},
      {"10x0x"_b, "ld1sw_z_p_bz_d_x32_unscaled"},
      {"10x1x"_b, "ldff1sw_z_p_bz_d_x32_unscaled"},
    },
  },

  { "_zrvlnx",
    {13, 12},
    { {"00"_b, "sbc_32_addsub_carry"},
    },
  },

  { "_zryvjk",
    {20, 9, 4},
    { {"000"_b, "trn2_p_pp"},
    },
  },

  { "_zslsvj",
    {23, 22, 20, 19, 11},
    { {"00011"_b, "fcvtzu_asisdshf_c"},
      {"001x1"_b, "fcvtzu_asisdshf_c"},
      {"01xx1"_b, "fcvtzu_asisdshf_c"},
    },
  },

  { "_zsltyl",
    {22, 20, 11},
    { {"000"_b, "uqincw_r_rs_uw"},
      {"001"_b, "uqdecw_r_rs_uw"},
      {"010"_b, "uqincw_r_rs_x"},
      {"011"_b, "uqdecw_r_rs_x"},
      {"100"_b, "uqincd_r_rs_uw"},
      {"101"_b, "uqdecd_r_rs_uw"},
      {"110"_b, "uqincd_r_rs_x"},
      {"111"_b, "uqdecd_r_rs_x"},
    },
  },

  { "_zssjpv",
    {18, 17},
    { {"00"_b, "st1_asisdlse_r3_3v"},
    },
  },

  { "_zsyggq",
    {23, 10},
    { {"00"_b, "_txhzxq"},
    },
  },

  { "_ztpryr",
    {13},
    { {"0"_b, "fmad_z_p_zzz"},
      {"1"_b, "fmsb_z_p_zzz"},
    },
  },

  { "_ztyqrj",
    {30, 23, 13, 12, 10},
    { {"00000"_b, "_jmvgsp"},
      {"00001"_b, "_jkkqvy"},
      {"00100"_b, "_nkxhsy"},
      {"00101"_b, "_gshrzq"},
      {"00110"_b, "_zvjrlz"},
      {"00111"_b, "_ntjpsx"},
      {"01000"_b, "_mqrzzk"},
      {"01001"_b, "_jqxqql"},
      {"01100"_b, "_xznsqh"},
      {"01101"_b, "_qvlnll"},
      {"01110"_b, "_kvnqhn"},
      {"01111"_b, "_zsltyl"},
      {"10110"_b, "_zkhjsp"},
      {"10111"_b, "_hvyjnk"},
      {"11000"_b, "_sjvhlq"},
      {"11001"_b, "_xhktsk"},
      {"11010"_b, "_rtpztp"},
      {"11011"_b, "_rznrqt"},
      {"11100"_b, "_kyspnn"},
      {"11101"_b, "_qljhnp"},
      {"11110"_b, "_pxyrpm"},
      {"11111"_b, "_khjvqq"},
    },
  },

  { "_zvjrlz",
    {22, 20, 11},
    { {"000"_b, "sqincb_r_rs_sx"},
      {"001"_b, "sqdecb_r_rs_sx"},
      {"010"_b, "sqincb_r_rs_x"},
      {"011"_b, "sqdecb_r_rs_x"},
      {"100"_b, "sqinch_r_rs_sx"},
      {"101"_b, "sqdech_r_rs_sx"},
      {"110"_b, "sqinch_r_rs_x"},
      {"111"_b, "sqdech_r_rs_x"},
    },
  },

  { "_zvlxrl",
    {23, 13, 12},
    { {"010"_b, "fcmeq_asisdsame_only"},
    },
  },

  { "_zvqghy",
    {30, 23, 22, 13, 12, 11, 10},
    { {"1000000"_b, "sha256h_qqv_cryptosha3"},
      {"1000100"_b, "sha256h2_qqv_cryptosha3"},
      {"1001000"_b, "sha256su1_vvv_cryptosha3"},
    },
  },

  { "_zxhhny",
    {23, 22},
    { {"00"_b, "fmsub_s_floatdp3"},
      {"01"_b, "fmsub_d_floatdp3"},
      {"11"_b, "fmsub_h_floatdp3"},
    },
  },

  { "_zxspnk",
    {30, 23, 22, 11, 10},
    { {"00000"_b, "sturb_32_ldst_unscaled"},
      {"00001"_b, "strb_32_ldst_immpost"},
      {"00010"_b, "sttrb_32_ldst_unpriv"},
      {"00011"_b, "strb_32_ldst_immpre"},
      {"00100"_b, "ldurb_32_ldst_unscaled"},
      {"00101"_b, "ldrb_32_ldst_immpost"},
      {"00110"_b, "ldtrb_32_ldst_unpriv"},
      {"00111"_b, "ldrb_32_ldst_immpre"},
      {"01000"_b, "ldursb_64_ldst_unscaled"},
      {"01001"_b, "ldrsb_64_ldst_immpost"},
      {"01010"_b, "ldtrsb_64_ldst_unpriv"},
      {"01011"_b, "ldrsb_64_ldst_immpre"},
      {"01100"_b, "ldursb_32_ldst_unscaled"},
      {"01101"_b, "ldrsb_32_ldst_immpost"},
      {"01110"_b, "ldtrsb_32_ldst_unpriv"},
      {"01111"_b, "ldrsb_32_ldst_immpre"},
      {"10000"_b, "sturh_32_ldst_unscaled"},
      {"10001"_b, "strh_32_ldst_immpost"},
      {"10010"_b, "sttrh_32_ldst_unpriv"},
      {"10011"_b, "strh_32_ldst_immpre"},
      {"10100"_b, "ldurh_32_ldst_unscaled"},
      {"10101"_b, "ldrh_32_ldst_immpost"},
      {"10110"_b, "ldtrh_32_ldst_unpriv"},
      {"10111"_b, "ldrh_32_ldst_immpre"},
      {"11000"_b, "ldursh_64_ldst_unscaled"},
      {"11001"_b, "ldrsh_64_ldst_immpost"},
      {"11010"_b, "ldtrsh_64_ldst_unpriv"},
      {"11011"_b, "ldrsh_64_ldst_immpre"},
      {"11100"_b, "ldursh_32_ldst_unscaled"},
      {"11101"_b, "ldrsh_32_ldst_immpost"},
      {"11110"_b, "ldtrsh_32_ldst_unpriv"},
      {"11111"_b, "ldrsh_32_ldst_immpre"},
    },
  },

  { "_zxtzmv",
    {30, 23, 22, 13},
    { {"0010"_b, "ld1rsh_z_p_bi_s64"},
      {"0011"_b, "ld1rsh_z_p_bi_s32"},
      {"0110"_b, "ld1rsb_z_p_bi_s64"},
      {"0111"_b, "ld1rsb_z_p_bi_s32"},
      {"1000"_b, "ld1sw_z_p_ai_d"},
      {"1001"_b, "ldff1sw_z_p_ai_d"},
      {"1010"_b, "ld1sw_z_p_bz_d_64_scaled"},
      {"1011"_b, "ldff1sw_z_p_bz_d_64_scaled"},
    },
  },

  { "_zyjjgs",
    {23, 22, 20, 19, 18},
    { {"00000"_b, "orr_z_zi"},
      {"01000"_b, "eor_z_zi"},
      {"10000"_b, "and_z_zi"},
      {"11000"_b, "dupm_z_i"},
      {"xx1xx"_b, "cpy_z_o_i"},
    },
  },

  { "_zylnnn",
    {30},
    { {"0"_b, "cbz_64_compbranch"},
    },
  },

  { "_zytrsq",
    {30},
    { {"0"_b, "tbz_only_testbranch"},
    },
  },

  { "_zyzzhm",
    {23, 20, 19, 18, 17, 16},
    { {"000001"_b, "frint32x_asimdmisc_r"},
    },
  },

  { "_zzgrjz",
    {18, 17},
    { {"0x"_b, "ld3_asisdlsep_r3_r"},
      {"10"_b, "ld3_asisdlsep_r3_r"},
      {"11"_b, "ld3_asisdlsep_i3_i"},
    },
  },

  { "_zzhgng",
    {30, 23, 22, 13, 12, 11, 10},
    { {"1000000"_b, "sha1c_qsv_cryptosha3"},
      {"1000001"_b, "dup_asisdone_only"},
      {"1000100"_b, "sha1p_qsv_cryptosha3"},
      {"1001000"_b, "sha1m_qsv_cryptosha3"},
      {"1001100"_b, "sha1su0_vvv_cryptosha3"},
      {"1010111"_b, "fmulx_asisdsamefp16_only"},
      {"1011001"_b, "fcmeq_asisdsamefp16_only"},
      {"1011111"_b, "frecps_asisdsamefp16_only"},
      {"1111111"_b, "frsqrts_asisdsamefp16_only"},
    },
  },

  { "_zzrqlh",
    {30, 23, 22, 11, 10},
    { {"00000"_b, "_ygpjrl"},
      {"01000"_b, "csel_32_condsel"},
      {"01001"_b, "csinc_32_condsel"},
      {"01100"_b, "_hggmnk"},
      {"01101"_b, "_sllkpt"},
      {"01110"_b, "_mgsvlj"},
      {"01111"_b, "_kyyzks"},
      {"10000"_b, "_zrvlnx"},
      {"11000"_b, "csinv_32_condsel"},
      {"11001"_b, "csneg_32_condsel"},
      {"11100"_b, "_ghmzhr"},
      {"11101"_b, "_gnqjhz"},
      {"11110"_b, "_mmmjkx"},
    },
  },

  { "_zzvxvh",
    {23, 22, 11, 10},
    { {"0001"_b, "pmul_z_zz"},
      {"xx00"_b, "mul_z_zz"},
      {"xx10"_b, "smulh_z_zz"},
      {"xx11"_b, "umulh_z_zz"},
    },
  },

  { "Root",
    {31, 29, 28, 27, 26, 25, 24, 21, 15, 14},
    { {"00000000xx"_b, "_qzjnpr"},
      {"0000100000"_b, "_rzzxsn"},
      {"0000100001"_b, "_xvppmm"},
      {"0000100010"_b, "_ptsjnr"},
      {"0000100011"_b, "_nlpmvl"},
      {"0000100100"_b, "_ljljkv"},
      {"0000100101"_b, "_kktglv"},
      {"0000100110"_b, "_ppnssm"},
      {"0000100111"_b, "_ztyqrj"},
      {"0000101000"_b, "_rnqtmt"},
      {"0000101001"_b, "_njgxlz"},
      {"0000101010"_b, "_mpvsng"},
      {"0000101011"_b, "_qlxksl"},
      {"0000101100"_b, "_mhrjvp"},
      {"0000101101"_b, "_pgjjsz"},
      {"0000101110"_b, "_yppyky"},
      {"0000101111"_b, "_yjmngt"},
      {"000100000x"_b, "_vmjgmg"},
      {"000100001x"_b, "_ytvxsl"},
      {"0001000101"_b, "_yvhnlk"},
      {"0001000111"_b, "_xryzqs"},
      {"000101000x"_b, "_vjqsqs"},
      {"000101010x"_b, "_phvnqh"},
      {"000101100x"_b, "_pphhym"},
      {"00010111xx"_b, "_qsygjs"},
      {"0001100000"_b, "_jxrlyh"},
      {"0001100001"_b, "_yqsgrt"},
      {"0001100010"_b, "_kpyqyv"},
      {"0001101000"_b, "_zkttzl"},
      {"0001101001"_b, "_llqjlh"},
      {"0001101010"_b, "_xhvtjg"},
      {"0001101011"_b, "_xylmmp"},
      {"0001101100"_b, "_vzzvlr"},
      {"0001101101"_b, "_sjlrxn"},
      {"0001101110"_b, "_xrhhjz"},
      {"0001101111"_b, "_ygnypk"},
      {"0001110000"_b, "_xjghst"},
      {"0001110001"_b, "_xxyklv"},
      {"0001110010"_b, "_rtgkkg"},
      {"0001110100"_b, "_hqnxvt"},
      {"0001110101"_b, "_hmxlny"},
      {"0001110110"_b, "_txsmts"},
      {"0001110111"_b, "_mtnpmr"},
      {"0001111000"_b, "_ttstyt"},
      {"0001111001"_b, "_krhrrr"},
      {"0001111010"_b, "_xhltxn"},
      {"0001111011"_b, "_ymznlj"},
      {"0001111100"_b, "_kkgzst"},
      {"0001111101"_b, "_gvjgyp"},
      {"0001111110"_b, "_mjqvxq"},
      {"0001111111"_b, "_spjjkg"},
      {"0010001xxx"_b, "_vppthj"},
      {"0010010xxx"_b, "_qzzlhq"},
      {"001001100x"_b, "_zjslnr"},
      {"001001110x"_b, "_jpxgqh"},
      {"0010011x1x"_b, "_gkhhjm"},
      {"0010100xxx"_b, "_jyxszq"},
      {"0010110xxx"_b, "_xqhgkk"},
      {"00101x1xxx"_b, "_zkqtrj"},
      {"0011000xxx"_b, "_qkyjhg"},
      {"00110010xx"_b, "_yjxshz"},
      {"0011010000"_b, "_zzrqlh"},
      {"0011010001"_b, "_qsrlql"},
      {"001101001x"_b, "_tnrrjk"},
      {"001101100x"_b, "_pnxgrg"},
      {"001101101x"_b, "_ytsghm"},
      {"0011100xxx"_b, "_srmhjk"},
      {"0011110000"_b, "_zzhgng"},
      {"0011110001"_b, "_zvqghy"},
      {"001111001x"_b, "_hnzzkj"},
      {"0011110100"_b, "_qntssm"},
      {"0011110101"_b, "_mrqqlp"},
      {"0011110110"_b, "_nxyhyv"},
      {"0011110111"_b, "_qtknlp"},
      {"0011111000"_b, "_gszlvl"},
      {"0011111001"_b, "_mlnqrm"},
      {"0011111010"_b, "_yvygml"},
      {"0011111011"_b, "_xhxrnt"},
      {"0011111100"_b, "_grqnlm"},
      {"0011111101"_b, "_ktnjrx"},
      {"0011111110"_b, "_gkpzhr"},
      {"0011111111"_b, "_mpyhkm"},
      {"0100100000"_b, "_yyyshx"},
      {"0100100001"_b, "_mylphg"},
      {"0100100010"_b, "_nsjhhg"},
      {"0100100011"_b, "_rhhrhg"},
      {"0100100100"_b, "_ymhgxg"},
      {"0100100101"_b, "_nvkthr"},
      {"0100100110"_b, "_phthqj"},
      {"0100100111"_b, "_kyjxrr"},
      {"0100101000"_b, "_gtvhmp"},
      {"0100101001"_b, "_pppsmg"},
      {"0100101010"_b, "_zgysvr"},
      {"0100101011"_b, "_shqygv"},
      {"0100101100"_b, "_lpsvyy"},
      {"0100101101"_b, "_nqkhrv"},
      {"0100101110"_b, "_tkjtgp"},
      {"0100101111"_b, "_htqpks"},
      {"0101000xxx"_b, "_vpkptr"},
      {"0101001xxx"_b, "_vmjzyk"},
      {"010101000x"_b, "_gmrxlp"},
      {"010101010x"_b, "_jmgkrl"},
      {"010101100x"_b, "_qhgtvk"},
      {"01010111xx"_b, "_rxpspy"},
      {"0101100xxx"_b, "_qhtqrj"},
      {"0101101xxx"_b, "_vnpqrh"},
      {"0101110000"_b, "_vpykkg"},
      {"0101110001"_b, "_xrxvpr"},
      {"0101110010"_b, "_zglksl"},
      {"0101110011"_b, "_gtjskz"},
      {"0101110100"_b, "_qntygx"},
      {"0101110101"_b, "_kxprqm"},
      {"0101110110"_b, "_qxtvzy"},
      {"0101110111"_b, "_mstthg"},
      {"0101111000"_b, "_qmqmpj"},
      {"0101111001"_b, "_rhttgj"},
      {"0101111010"_b, "_jqnhrj"},
      {"0101111011"_b, "_nlqglq"},
      {"0101111100"_b, "_vtxyxz"},
      {"0101111101"_b, "_pqtjgx"},
      {"0101111110"_b, "_snjpvy"},
      {"0101111111"_b, "_spzgkt"},
      {"0110001xxx"_b, "_plktrh"},
      {"0110010xxx"_b, "_xtqmyj"},
      {"0110011xxx"_b, "_lzpykk"},
      {"0110100xxx"_b, "_mtzgpn"},
      {"0110101xxx"_b, "_tvgvvq"},
      {"01110000xx"_b, "_zxspnk"},
      {"0111000100"_b, "_zqmmsk"},
      {"0111000101"_b, "_nmzyvt"},
      {"0111000110"_b, "_vvhzhv"},
      {"0111000111"_b, "_sltqpy"},
      {"0111001xxx"_b, "_qzsthq"},
      {"0111010000"_b, "_zsyggq"},
      {"0111010001"_b, "_hngpgx"},
      {"011101001x"_b, "_njxtpv"},
      {"01111000xx"_b, "_kpmvkn"},
      {"0111100101"_b, "_jhytlg"},
      {"0111100111"_b, "_rksxpn"},
      {"01111001x0"_b, "_trlhgn"},
      {"0111101xxx"_b, "_jxtgtx"},
      {"0111110000"_b, "_tnhmpx"},
      {"0111110010"_b, "_sqjpsl"},
      {"0111110100"_b, "_sjnxky"},
      {"0111110101"_b, "_kykymg"},
      {"0111110110"_b, "_pxzkjy"},
      {"0111110111"_b, "_tjktkm"},
      {"0111111000"_b, "_hhkhkk"},
      {"0111111001"_b, "_nxmjvy"},
      {"0111111010"_b, "_vkvgnm"},
      {"0111111011"_b, "_tssqsr"},
      {"0111111100"_b, "_mthzvm"},
      {"0111111101"_b, "_nlgqsk"},
      {"0111111110"_b, "_gvykrp"},
      {"0111111111"_b, "_sjzsvv"},
      {"0x10000xxx"_b, "adr_only_pcreladdr"},
      {"1000100000"_b, "_lspzrv"},
      {"1000100001"_b, "_kxvvkq"},
      {"1000100010"_b, "_sxpvym"},
      {"1000100011"_b, "_vkrkks"},
      {"1000100100"_b, "_xvnyxq"},
      {"1000100101"_b, "_gtxpgx"},
      {"1000100110"_b, "_vlrhpy"},
      {"1000100111"_b, "_ymhkrx"},
      {"1000101000"_b, "_zrmgjx"},
      {"1000101001"_b, "_qqyryl"},
      {"1000101010"_b, "_hgxtqy"},
      {"1000101011"_b, "_yytvxh"},
      {"1000101100"_b, "_ptslzg"},
      {"1000101101"_b, "_ytkjxx"},
      {"1000101110"_b, "_zxtzmv"},
      {"1000101111"_b, "_kgmqkh"},
      {"100100000x"_b, "_jhqlkv"},
      {"100100001x"_b, "_lxgltj"},
      {"1001000100"_b, "_hxzlmm"},
      {"1001000101"_b, "_vllqmp"},
      {"1001000110"_b, "_tlstgz"},
      {"1001000111"_b, "_mrmpgh"},
      {"10010100xx"_b, "_rzkmny"},
      {"10010101xx"_b, "_jggvph"},
      {"10010110xx"_b, "_nhkstj"},
      {"10010111xx"_b, "_jsygzs"},
      {"100111000x"_b, "_gmsgqz"},
      {"1001110010"_b, "_grrjlh"},
      {"1001110011"_b, "_jhkglp"},
      {"100111010x"_b, "_qytrjj"},
      {"1001110110"_b, "_qsqqxg"},
      {"1001110111"_b, "_kypqpy"},
      {"1010001xxx"_b, "_vsvtqz"},
      {"1010010xxx"_b, "_vqzlzt"},
      {"10100110xx"_b, "_xxpqgg"},
      {"10100111xx"_b, "_rgjqzs"},
      {"10101000xx"_b, "_qmrgkn"},
      {"10101001xx"_b, "_jkxlnq"},
      {"1010101000"_b, "_ggvztl"},
      {"1010101001"_b, "_xlhjhx"},
      {"101010101x"_b, "_nqgqjh"},
      {"1010101100"_b, "_qsrtzz"},
      {"1010101110"_b, "_tzzzxz"},
      {"10101011x1"_b, "_lhmlrj"},
      {"1010110000"_b, "_kkmxxx"},
      {"1010110100"_b, "_ltvrrg"},
      {"1010111000"_b, "_mqkjxj"},
      {"1010111100"_b, "_pmrngh"},
      {"101011xx10"_b, "_hsjynv"},
      {"101011xxx1"_b, "_kmhtqp"},
      {"1011000xxx"_b, "_ylhxlt"},
      {"10110010xx"_b, "_gkxgsn"},
      {"1011001100"_b, "_xzmjxk"},
      {"1011001110"_b, "_ppqkym"},
      {"10110011x1"_b, "_xzyxnr"},
      {"1011010000"_b, "_xyljvp"},
      {"1011010001"_b, "_sxnkrh"},
      {"101101001x"_b, "_klthpn"},
      {"101101100x"_b, "_xnsrny"},
      {"101101101x"_b, "_htppjj"},
      {"101101110x"_b, "_rmmmjj"},
      {"101101111x"_b, "_txnqzy"},
      {"1011100xxx"_b, "_gmvtss"},
      {"10111100xx"_b, "_gnxgxs"},
      {"1011110100"_b, "_zjgvyp"},
      {"1100100000"_b, "_sjtrhm"},
      {"1100100001"_b, "_hzkglv"},
      {"1100100010"_b, "_qrygny"},
      {"1100100011"_b, "_tjzqnp"},
      {"1100100100"_b, "_yqvqtx"},
      {"1100100101"_b, "_ngttyj"},
      {"1100100110"_b, "_kqzmtr"},
      {"1100100111"_b, "_qpvgnh"},
      {"1100101000"_b, "_tpkslq"},
      {"1100101001"_b, "_ympyng"},
      {"1100101010"_b, "_ytvtqn"},
      {"1100101011"_b, "_qvsypn"},
      {"1100101100"_b, "_lqmksm"},
      {"1100101101"_b, "_mkskxj"},
      {"1100101110"_b, "_knkjnz"},
      {"1100101111"_b, "_hxnmsl"},
      {"1101000xxx"_b, "_shrsxr"},
      {"1101001xxx"_b, "_xhkgqh"},
      {"11010100xx"_b, "_rmxjsn"},
      {"11010101xx"_b, "_mvzvpk"},
      {"11010110xx"_b, "_ysjqhn"},
      {"11010111xx"_b, "_lpkqzl"},
      {"1101100xxx"_b, "_zpzghs"},
      {"1101101xxx"_b, "_gmrxqq"},
      {"1110001xxx"_b, "_jlqjzr"},
      {"1110010xxx"_b, "_qgmngg"},
      {"1110011xxx"_b, "_vlrrtz"},
      {"1110100xxx"_b, "_zylnnn"},
      {"1110101xxx"_b, "_yjjrgg"},
      {"11110000xx"_b, "_qhtrnn"},
      {"1111000100"_b, "_lrqkvp"},
      {"1111000101"_b, "_pvkmmv"},
      {"1111000110"_b, "_lxmyjh"},
      {"1111000111"_b, "_vgrhsz"},
      {"1111001xxx"_b, "_vqvqhp"},
      {"1111010000"_b, "_yjsjvt"},
      {"1111010010"_b, "_yzzlxs"},
      {"11110100x1"_b, "_vkhhkk"},
      {"11111000xx"_b, "_xrhmtg"},
      {"11111001xx"_b, "_xprlgy"},
      {"1111101xxx"_b, "_hjgylh"},
      {"1x10000xxx"_b, "adrp_only_pcreladdr"},
      {"x110110xxx"_b, "_zytrsq"},
      {"x110111xxx"_b, "_kxsysq"},
    },
  },
};
// clang-format on

}  // namespace aarch64
}  // namespace vixl
